## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Eu_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Eu_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Eu_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-eu.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: basque (eu)
% encoding: ec
%
% This file has been auto-generated from hyph-eu.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"F1="F1
\patterns{
1ba
1be
1bo
1bi
1bu
1ca
1ce
1co
1ci
1cu
1da
1de
1do
1di
1du
1fa
1fe
1fo
1fi
1fu
1ga
1ge
1go
1gi
1gu
1ja
1je
1jo
1ji
1ju
1ka
1ke
1ko
1ki
1ku
1la
1le
1lo
1li
1lu
1ma
1me
1mo
1mi
1mu
1na
1ne
1no
1ni
1nu
1^^f1a
1^^f1e
1^^f1o
1^^f1i
1^^f1u
1pa
1pe
1po
1pi
1pu
1qa
1qe
1qo
1qi
1qu
1ra
1re
1ro
1ri
1ru
1sa
1se
1so
1si
1su
1ta
1te
1to
1ti
1tu
1va
1ve
1vo
1vi
1vu
1wa
1we
1wo
1wi
1wu
1xa
1xe
1xo
1xi
1xu
1ya
1ye
1yo
1yi
1yu
1za
1ze
1zo
1zi
1zu
1l2la
1l2le
1l2lo
1l2li
1l2lu
1r2ra
1r2re
1r2ro
1r2ri
1r2ru
1t2sa
1t2se
1t2so
1t2si
1t2su
1t2xa
1t2xe
1t2xo
1t2xi
1t2xu
1t2za
1t2ze
1t2zo
1t2zi
1t2zu
1b2la
1b2le
1b2lo
1b2li
1b2lu
1b2ra
1b2re
1b2ro
1b2ri
1b2ru
1d2ra
1d2re
1d2ro
1d2ri
1d2ru
1f2la
1f2le
1f2lo
1f2li
1f2lu
1f2ra
1f2re
1f2ro
1f2ri
1f2ru
1g2la
1g2le
1g2lo
1g2li
1g2lu
1g2ra
1g2re
1g2ro
1g2ri
1g2ru
1k2la
1k2le
1k2lo
1k2li
1k2lu
1k2ra
1k2re
1k2ro
1k2ri
1k2ru
1p2la
1p2le
1p2lo
1p2li
1p2lu
1p2ra
1p2re
1p2ro
1p2ri
1p2ru
1t2ra
1t2re
1t2ro
1t2ri
1t2ru
su2b2r
su2b2l
}
\egroup

