## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Fur 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Fur::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Fur> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/tex/hyph-fur.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% hyph-fur.tex
%
% Friulan hyphenation patterns
%
% This file is part of the hyph-utf8 package.
% For more information see
%
%    http://tug.org/tex-hyphen
%
%------------------------------------------------------------------------------
%
%% Copyright 2012 Claudio Beccari
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either
% version 1.3 of this license or (at your option) any later
% version. The latest version of this license is in
%        http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions
% of LaTeX version 2003/12/01 or later.
%
% This work has the LPPL maintenance status "maintained".
%
% The Current Maintainer of this work is Claudio Beccari
% e-mail:  claudio dot beccari at gmail dot com
%
% This work consists of the single file hyph-fur.tex.
%
% \versionnumber{1.1}   \versiondate{2012/04/10}
%
% These hyphenation patterns for the Friulan language are supposed to comply
% with the common spelling of the Friulan (Furlan) language as fixed by the
% Regional Law N.15/96 dated November 6, 1996 and its following amendments.
% They were initially obtained by merging the consonantic endings to the Italian
% patterns and adding the necessary patterns for the special Friulan digraphs
% used in this language and for the \c{c} consonant. The common Latin roots
% of both languages helped a lot in this adaptation.
% Digraphs: cj, gj, gl, gn, sj, ss.
%
% ChangeLog:
% - 2012-01-14 - First release 1.0
% - 2012-02-10 - Version 1.1. Fix inconsistencies.
%%
\patterns{% some revision might be necessary to handle more vocalic elisions
.'2s2
.'sj2
2'2
2'.
2b'
2c'
2cj'
2cj'.
2ç'
2d'
2f'
2g'
2h'
2j'
2k'
2l'.
2l''
2m'
2n'
.'n2
2p'
2q'
2r'
4s'.
4s''
2st'
2t'.
2t''
2v'.
2v''
2w'
2x'
2z'.
2z''
%%%%%%%%%%%%%%%%%%%%
.a3p2n
.anti1
.anti3m2n
.bio1
.ca4p3s
.circu2m1
.co2n3j
.cuintri1
.co1o2p
.di2s3
.di2s4ch3oc
.e2x1e
.ex2tra3
.fran2k3
.free3
.li3p2sa
.narco1
.opto1
.orto3p2
.para1
.plu2s3q
.poli3p2
.pre1
.p2s
.re1ac
.re1i2scr
.tran2s3ac
.tran2s3c
.tran2s3d
.tran2s3l
.tran2s3n
.tran2s3p
.tran2s3r
.tran2s3t
.su2b3j
.su2b3lu
.su2b3r
.wa2g3n
.wel2t1
a1ia
a1ie
a1io
a1iu
a1uo
a1ya
2at.
e1iu
e2w
o1ia
o1ie
o1io
o1iu
1b
2bb
2bc
2bd
2bf
2bm
2bn
2bp
2bs
2bt
2bv
b2l
b2r
2b.
1c
2cb
2cc
2cd
2cf
c2j
2cj.
2ck
2cm
2cn
2cq
2cs
2ct
2cz
2chh
c2h
2ch.
2chb
ch2r
2chn
c2l
c2r
2c.
.c2
1ç
2ç.
2çs.
1d
2db
2dd
2dg
d2h
2dl
2dm
2dn
2dp
d2r
2ds
2dt
2dv
2dw
2d.
.d2
1f
2fb
2fg
2ff
2fn
f2l
f2r
2fs
2ft
2f.
1g
2gb
2gd
2gf
2gg
g2h
g2j
g2l
2gm
g2n
2gn.
2gp
g2r
2gs
2gt
2gv
2gw
2gz
2gh2t
2g.
1h
2hb
2hd
2hh
hi3p2n
h2l
2hm
2hn
2hr
2hv
2h.
1j
2j.
1k
2kg
2kf
k2h
2kk
k2l
2km
k2r
2ks
2kt
2k.
1l
2lb
2lc
2ld
2l3f2
2lg
l2h
l2j
2lk
2ll
2lm
2ln
2lp
2lq
2lr
2ls
2lt
2lv
2lw
2lz
2l.
1m
2mb
2mc
2mf
2ml
2mm
2mn
2mp
2mq
2mr
2ms
2mt
2mv
2mw
2m.
1n
2nb
2nc
2nd
2nf
2ng
2nk
2nl
2nm
2nn
2np
2nq
2nr
2ns
n2s.
n2s3fer
2nt
n2t.
2nv
2nz
n2g3n
2nheit
2n.
1p
2pd
p2h
p2l
2pn
3p2ne
2pp
p2r
2ps
3p2sic
2pt
2pz
2p.
1q
2qq
2q.
1r
2rb
2rc
2rç
2rç.
2rd
2rf
r2h
2rg
2rk
2rl
2rm
2rn
2rp
2rq
2rr
2rs
2rt
r2t2s3
2rv
2rx
2rw
2rz
2r.
.s2
1s
2sc
.s2c
2s1ç
.s2ç
2s1cj
.s2cj
2sch2
.s2ch
2sd
.s2d
2sf
.s2f
2sg
.s2g
s2j
2sj.
2sl
.s2l
2sm
.s2m
2sn
.s2n
2sp
.s2p
2s1p2n
2sq
.s2q
2sr
.s2r
s2s % 
2s4s3m
2st
2s2t.
.s2t
2s2tb
2s2tc
2s2td
2s2tf
2s2tm
2s2tn
2s2tp
2s2ts
2s2tt
2s2tv
2sv
.s2v
2sz
2s2ç.
2scj.
2s.
1t
2tb
2tc
2tç
t2ç.
2tcj
t2cj.
2td
2tf
t2g
t2h
t2l
2tm
2tn
2tp
t2r
2t2s
2tt
t2t3m
t2t3s
2tv
2tw
t2z
2tzk
tz2s
2t.
2ts.
1v
2vc
v2l
v2r
2vs.
2vv
2v.
1w
w2h
wa2r
2w1y
2w.
1x
2xb
2xc
2xf
2xh
2xm
2xp
2xt
2xw
2x.
y1ou
y1i
1z
2zb
2zd
2zl
2zn
2zp
2zr
2zs
2zt
2zv
2zz
2z.
.z2
}                          % Pattern end


