## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Quote_uk 0;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Quote_uk::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Quote_uk> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/quote/hyph-quote-uk.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
\bgroup
\lccode`\’=`\’
\patterns{
2в’3
2м’3
2н’3
2р’3
6’
.б’8
.в’8
.д’8
.з’8
.м’8
.н’8
.п’8
.р’8
.т’8
.ф’8
.ш’8
.вб6’6
.вв6’6
.вм6’6
.вп6’6
.зв6’6
.зм6’6
.сп6’6
.бе4з’3
.від’3
неві4д’3
.пере4д’3
.під’3
.ро4з’3
.чере4з’3
ооб’3
об’3
од’3
на4д’3
до3в’4є
за3в’4є
зі3в’4є
обі3в’4є
по3в’4є
уі3в’4є
з3в’4я
по3в’4я
від3в’4я
за3в’4я
зі3в’4я
на3в’4я
непо3в’4я
об3в’4я
при3в’4я
під3в’4я
у3в’4я
з3м’4я
зі3м’4я
у3м’4я
в3м’4я
но3м’4я
за3м’4я
на3м’4я
об3м’4я
пере3м’4я
по3м’4я
при3м’4я
піді3м’4я
су3м’4я
до3в’4ю
за3в’4ю
зі3в’4ю
на3в’4ю
по3в’4ю
уі3в’4ю
інтер3в’4ю
3з4в4’яз
3о4б’єдн
3о4б’єкт
’ї4в
’ї4з
’ї4д
’ї4ж
’ї4л
’ї4м
’ї4с
’ї4х
б’4єть
3в’4яз
3з’4ясо
3м’4якш
3м’4ят
ро4з’5єдн
з’4єдн
з’я4в
роз’я4сн
роз’я4р
.’-8
-а8’8
8а8’-
-б8’8
8б8’-
-в8’8
8в8’-
-г8’8
8г8’-
-ґ8’8
8ґ8’-
-д8’8
8д8’-
-е8’8
8е8’-
-є8’8
8є8’-
-ж8’8
8ж8’-
-з8’8
8з8’-
-и8’8
8и8’-
-і8’8
8і8’-
-ї8’8
8ї8’-
-й8’8
8й8’-
-к8’8
8к8’-
-л8’8
8л8’-
-м8’8
8м8’-
-н8’8
8н8’-
-о8’8
8о8’-
-п8’8
8п8’-
-р8’8
8р8’-
-с8’8
8с8’-
-т8’8
8т8’-
-у8’8
8у8’-
-ф8’8
8ф8’-
-х8’8
8х8’-
-ц8’8
8ц8’-
-ч8’8
8ч8’-
-ш8’8
8ш8’-
-щ8’8
8щ8’-
-ь8’8
8ь8’-
-ю8’8
8ю8’-
-я8’8
8я8’-
-’8а8
8’8а-
-’8б8
8’8б-
-’8в8
8’8в-
-’8г8
8’8г-
-’8ґ8
8’8ґ-
-’8д8
8’8д-
-’8е8
8’8е-
-’8є8
8’8є-
-’8ж8
8’8ж-
-’8з8
8’8з-
-’8и8
8’8и-
-’8і8
8’8і-
-’8ї8
8’8ї-
-’8й8
8’8й-
-’8к8
8’8к-
-’8л8
8’8л-
-’8м8
8’8м-
-’8н8
8’8н-
-’8о8
8’8о-
-’8п8
8’8п-
-’8р8
8’8р-
-’8с8
8’8с-
-’8т8
8’8т-
-’8у8
8’8у-
-’8ф8
8’8ф-
-’8х8
8’8х-
-’8ц8
8’8ц-
-’8ч8
8’8ч-
-’8ш8
8’8ш-
-’8щ8
8’8щ-
-’8ь8
8’8ь-
-’8ю8
8’8ю-
-’8я8
8’8я-
-’8’8
8’8’-
}
\egroup

