## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Fr_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Fr_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Fr_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-fr.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: french (fr)
% encoding: ec
%
% This file has been auto-generated from hyph-fr.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"E0="E0
\lccode"E2="E2
\lccode"E7="E7
\lccode"E8="E8
\lccode"E9="E9
\lccode"EA="EA
\lccode"EE="EE
\lccode"EF="EF
\lccode"F4="F4
\lccode"FB="FB
\lccode"F7="F7
\patterns{
2'2
.a4
'a4
.^^e24
'^^e24
ab2h
.ab3r^^e9a
'ab3r^^e9a
ad2h
a1^^e82dre
.ae3s4ch
'ae3s4ch
1alcool
a2l1algi
.amino1a2c
'amino1a2c
.ana3s4tr
'ana3s4tr
1a2nesth^^e9si
.anti1a2
'anti1a2
.anti1e2
'anti1e2
.anti1^^e92
.anti2enne
'anti2enne
'anti1^^e92
.anti1s2
'anti1s2
.apo2s3ta
'apo2s3ta
apo2s3tr
archi1^^e92pis
.as2ta
'as2ta
a2s3tro
1ba
1b^^e2
.bai2se3main
1be
1b^^e9
1b^^e8
1b^^ea
4be.
4bes.
2bent.
1bi
1b^^ee
.bi1a2c
.bi1a2t
.bi1au
.bio1a2
.bi2s1a2
.bi1u2
1b2l
4ble.
4bles.
2blent.
1bo
1b^^f4
1b2r
4bre.
4bres.
2brent.
1bu
1b^^fb
1by
1^^e7
1ca
1c^^e2
ca3ou3t2
1ce
1c^^e9
1c^^e8
1c^^ea
4ce.
4ces.
2cent.
ja3cent.
ac3cent.
^^e93cent.
munifi3cent.
r^^e9ti3cent.
privatdo3cent.
inno3cent.
es3cent.
acquies4cent.
is3cent.
immis4cent.
.ch4
1c2h
4ch.
2chb
4che.
4ches.
2chent.
.ch^^e82vre3feuille
2chg
ch2l
4chle.
4chles.
chlo2r3a2c
chlo2r3^^e92t
2chm
2chn
2chp
ch2r
4chre.
4chres.
2chs
2cht
2chw
1ci
1c^^ee
.ci2s1alp
1c2k
4ck.
2ckb
4cke.
4ckes.
2ckent.
2ckf
2ckg
2ck3h
2ckp
2cks
2ckt
1c2l
4cle.
4cles.
2clent.
1co
1c^^f4
co1acc
co1acq
co1a2d
co1ap
co1ar
co1assoc
co1assur
co1au
co1ax
1c^^f7
co1^^e92
co1ef
co1en
co1ex
.con4
.cons4
.contre1s2c
.contre3ma^^eetre
co2nurb
.co1o2
.co2o3lie
1c2r
4cre.
4cres.
2crent.
1cu
1c^^fb
1cy
.cul4
1d'
1da
1d^^e2
.dacryo1a2
d1d2h
1de
1d^^e9
1d^^e8
1d^^ea
4de.
4des.
2dent.
d^^e9ca3dent.
^^e93dent.
cci3dent.
inci3dent.
confi3dent.
tri3dent.
dissi3dent.
chien3dent.
.ar3dent.
impu3dent.
pru3dent.
.d^^e91a2
.d^^e91io
.d^^e91o2
.d^^e92s
.d^^e93s2a3cr
.d^^e9s2a3m
.d^^e93s2a3tell
.d^^e93s2astr
.d^^e93s2c
.d^^e92s1^^e92
.d^^e93s2^^e93gr
.d^^e93s2ensib
.d^^e93s2ert
.d^^e93s2exu
.d^^e92s1i2
.d^^e93s2i3d
.d^^e93s2i3gn
.d^^e93s2i3li
.d^^e93s2i3nen
.d^^e93s2invo
.d^^e93s2i3r
.d^^e93s2ist
.d^^e93s2o3d^^e9
.d^^e92s1^^f7
.d^^e93s2o3l
.d^^e93s2o3pil
.d^^e93s2orm
.d^^e93s2orp
.d^^e93s2oufr
.d^^e93s2p
.d^^e93s2t
.d^^e92s1u2n
3d2hal
3d2houd
1di
1d^^ee
di2s3cop
.di1a2c^^e9
.di1a2cid
.di1ald
.di1a2mi
.di1a2tom
.di1e2n
.di2s3h
2dlent.
1do
1d^^f4
1d2r
4dre.
4dres.
2drent.
d1s2
1du
1d^^fb
1dy
.dy2s3
.dy2s1a2
.dy2s1i2
.dy2s1o2
.dy2s1u2
.e4
'e4
.^^ea4
'^^ea4
.^^e94
'^^e94
.^^e84
'^^e84
^^e9d2hi
1^^e92drie
1^^e92drique
1^^e92lectr
1^^e92l^^e9ment
.en1a2
'en1a2
1^^e92nerg
e2n1i2vr
.en1o2
'en1o2
^^e9pi2s3cop
^^e9pi3s4cope
e2s3cop
.eu2r1a2
'eu2r1a2
eu1s2tat
extra1
extra2c
extra2i
1fa
1f^^e2
1fe
1f^^e9
1f^^e8
1f^^ea
4fe.
4fes.
2fent.
1fi
1f^^ee
1f2l
4fle.
4fles.
2flent.
1fo
1f^^f4
1f2r
4fre.
4fres.
2frent.
f1s2
1fu
1f^^fb
1fy
1ga
1g^^e2
1ge
1g^^e9
1g^^e8
1g^^ea
4ge.
4ges.
2gent.
r^^e93gent.
entre3gent.
indi3gent.
dili3gent.
intelli3gent.
indul3gent.
tan3gent.
rin3gent.
contin3gent.
.ar3gent.
'ar3gent.
ser3gent.
ter3gent.
r^^e9sur3gent.
1g2ha
1g2he
1g2hi
1g2ho
1g2hy
1gi
1g^^ee
1g2l
4gle.
4gles.
2glent.
1g2n
'a2g3nat
.a2g3nat
a2g3nos
co2g3niti
'i2g3n^^e9
.i2g3n^^e9
'i2g3ni
.i2g3ni
.ma2g3nicide
.ma2g3nificat
.ma2g3num
o2g3nomoni
o2g3nosi
.pro2g3nath
pu2g3nable
pu2g3nac
.sta2g3n
.syn2g3nath
wa2g3n
4gne.
4gnes.
2gnent.
1go
1g^^f4
1g2r
4gre.
4gres.
2grent.
1gu
1g^^fb
g1s2
4gue.
4gues.
2guent.
.on3guent.
'on3guent.
1gy
1ha
1h^^e2
1he
1h^^e9
1h^^e8
1h^^ea
h^^e9mi1^^e9
h^^e9mo1p2t
4he.
4hes.
1hi
1h^^ee
1ho
1h^^f4
1hu
1h^^fb
1hy
hypera2
hypere2
hyper^^e92
hyperi2
hypero2
hypers2
hype4r1
hyperu2
hypo1a2
hypo1e2
hypo1^^e92
hypo1i2
hypo1o2
hypo1s2
hypo1u2
.i4
'i4
.^^ee4
'^^ee4
i1algi
i1arthr
i1^^e82dre
il2l
cil3l
rcil4l
ucil4l
vacil4l
gil3l
hil3l
lil3l
l3lion
mil3l
mil4let
^^e9mil4l
semil4l
rmil4l
armil5l
capil3l
papil3la
papil3le
papil3li
papil3lom
pupil3l
piril3l
thril3l
cyril3l
ibril3l
pusil3l
.stil3l
distil3l
instil3l
fritil3l
boutil3l
vanil3lin
vanil3lis
vil3l
avil4l
chevil4l
uevil4l
uvil4l
xil3l
1informat
.in1a2
'in1a2
.in2a3nit
'in2a3nit
.in2augur
'in2augur
.in1e2
'in1e2
.in1^^e92
'in1^^e92
.in2effab
'in2effab
.in2^^e93lucta
'in2^^e93lucta
.in2^^e93narra
'in2^^e93narra
.in2ept
'in2ept
.in2er
'in2er
.in2exora
'in2exora
.in1i2
'in1i2
.in2i3miti
'in2i3miti
.in2i3q
'in2i3q
.in2i3t
'in2i3t
.in1o2
'in1o2
.in2o3cul
'in2o3cul
.in2ond
'in2ond
.in1s2tab
'in1s2tab
'inte4r3
.intera2
'intera2
.intere2
'intere2
.inter^^e92
'inter^^e92
.interi2
'interi2
.intero2
'intero2
.inte4r3
.interu2
'interu2
.inters2
'inters2
.in1u2
'in1u2
.in2uit
'in2uit
.in2u3l
'in2u3l
io1a2ct
i1oxy
i1s2tat
1j
2jk
4je.
4jes.
2jent.
1ka
1k^^e2
1ke
1k^^e9
1k^^e8
1k^^ea
4ke.
4kes.
2kent.
1k2h
4kh.
.kh4
1ki
1k^^ee
1ko
1k^^f4
1k2r
1ku
1k^^fb
1ky
1la
1l^^e2
1l^^e0
la2w3re
1le
1l^^e9
1l^^e8
1l^^ea
4le.
4les.
2lent.
.ta3lent.
iva3lent.
^^e9quiva4lent.
monova3lent.
polyva3lent.
re3lent.
.do3lent.
indo3lent.
inso3lent.
turbu3lent.
succu3lent.
f^^e9cu3lent.
trucu3lent.
opu3lent.
corpu3lent.
ru3lent.
sporu4lent.
1li
1l^^ee
1lo
1l^^f4
l1s2t
1lu
1l^^fb
1ly
1ma
1m^^e2
.ma2c3k
.macro1s2c
.ma2l1a2dres
.ma2l1a2dro
.ma2l1ais^^e9
.ma2l1ap
.ma2l1a2v
.ma2l1en
.ma2l1int
.ma2l1oc
.ma2l1o2d
.ma2r1x
1me
1m^^e9
1m^^e8
1m^^ea
.m^^e92g1oh
.m^^e92sa
.m^^e93san
.m^^e92s1es
.m^^e92s1i
.m^^e92s1u2s
.m^^e9ta1s2ta
4me.
4mes.
^^e22ment.
da2ment.
fa2ment.
amalga2ment.
cla2ment.
ra2ment.
temp^^e9ra3ment.
ta2ment.
testa3ment.
qua2ment.
^^e82ment.
car^^ea2ment.
diaphrag2ment.
ryth2ment.
ai2ment.
rai3ment.
ab^^ee2ment.
^^e9ci2ment.
vidi2ment.
subli2ment.
^^e9li2ment.
reli2ment.
mi2ment.
ani2ment.
veni2ment.
ri2ment.
d^^e9tri3ment.
nutri3ment.
inti2ment.
esti2ment.
l2ment.
flam2ment.
gram2ment.
.gem2ment.
om2ment.
.com3ment.
^^f42ment.
slalo2ment.
chro2ment.
to2ment.
ar2ment.
.sar3ment.
er2ment.
antifer3ment.
.ser3ment.
fir2ment.
or2ment.
as2ment.
au2ment.
^^e9cu2ment.
fu2ment.
hu2ment.
fichu3ment.
llu2ment.
plu2ment.
bou2ment.
bru2ment.
su2ment.
tu2ment.
1mi
1m^^ee
.milli1am
1m2n^^e9mo
1m2n^^e8s
1m2n^^e9si
1mo
1m^^f4
1m^^f7
.mono1a2
.mono1e2
.mono1^^e92
.mono1i2
.mono1^^ef2d^^e9
.mono1o2
.mono1u2
.mono1s2
mon2t3r^^e9al
m1s2
1mu
1m^^fb
1my
moye2n1^^e22g
1na
1n^^e2
1ne
1n^^e9
1n^^e8
1n^^ea
4ne.
4nes.
2nent.
r^^e9ma3nent.
imma3nent.
perma3nent.
.^^e9mi3nent.
pr^^e9^^e9mi3nent.
pro^^e9mi3nent.
sur^^e9mi3nent.
immi3nent.
conti3nent.
perti3nent.
absti3nent.
1ni
1n^^ee
1no
1n^^f4
1n^^f7
.no2n1obs
1nu
1n^^fb
n3s2at.
n3s2ats.
n1x
1ny
.o4
'o4
'^^f44
.^^f44
o2b3long
1octet
o1d2l
o1^^e82dre
o1ioni
ombud2s3
omni1s2
o1s2tas
o1s2tat
o1s2t^^e9ro
o1s2tim
o1s2tom
o1s2trad
o1s2tratu
o1s2triction
.oua1ou
'oua1ou
.ovi1s2c
'ovi1s2c
oxy1a2
1pa
1p^^e2
pal^^e9o1^^e92
.pa2n1a2f
.pa2n1a2m^^e9
.pa2n1a2ra
.pa2n1is
.pa2n1o2ph
.pa2n1opt
.pa2r1a2che
.pa2r1a2ch^^e8
.para1s2
.pa2r3h^^e9
1pe
1p^^e9
1p^^e8
1p^^ea
4pe.
4pes.
2pent.
re3pent.
.ar3pent.
'ar3pent.
ser3pent.
.pen2ta
per3h
p^^e92nul
.pe4r
.per1a2
.per1e2
.per1^^e92
.per1i2
.per1o2
.per1u2
p^^e91r2^^e92q
.p^^e9ri1os
.p^^e9ri1s2
.p^^e9ri2s3s
.p^^e9ri2s3ta
.p^^e9ri1u2
1p2h
.ph4
4ph.
.phalan3s2t
4phe.
4phes.
2phent.
ph2l
4phle.
4phles.
2phn
photo1s2
ph2r
4phre.
4phres.
2phs
2pht
3ph2tal^^e9
3ph2tis
1pi
1p^^ee
1p2l
4ple.
4ples.
2plent.
.pluri1a
1p2n^^e9
1p2neu
1po
1p^^f4
po1astre
poly1a2
poly1e2
poly1^^e92
poly1^^e82
poly1i2
poly1o2
poly1s2
poly1u2
.pon2tet
.pos2t3h
.pos2t1in
.pos2t1o2
.pos2t3r
.post1s2
1p2r
4pre.
4pres.
2prent.
.pr^^e91a2
.pr^^e92a3la
.pr^^e92au
.pr^^e91^^e92
.pr^^e91e2
.pr^^e91i2
.pr^^e91o2
.pr^^e91u2
.pr^^e91s2
.pro1^^e92
.pro1s2c^^e9
pro2s3tat
.prou3d2h
1p2sych
.psycho1a2n
1p2t^^e8r
1p2t^^e9r
1pu
.pud1d2l
1p^^fb
1py
1q
4que.
4ques.
2quent.
^^e93quent.
^^e9lo3quent.
grandilo3quent.
1ra
1r^^e2
radio1a2
1re
1r^^e9
1r^^e8
1r^^ea
.r^^e91a2
.r^^e92a3le
.r^^e92a3lis
.r^^e92a3lit
.r^^e92aux
.r^^e91^^e92
.r^^e91e2
.r^^e92el
.r^^e92er
.r^^e92^^e8r
.r^^e91i2
.r^^e92i3fi
.r^^e91o2
.re1s2
.re2s3cap
.re2s3cisi
.re2s3ciso
.re2s3cou
.re2s3cri
.re2s3pect
.re2s3pir
.re2s3plend
.re2s3pons
.re2s3quil
.re2s3s
.re2s3t
.re3s4tab
.re3s4tag
.re3s4tand
.re3s4tat
.re3s4t^^e9n
.re3s4t^^e9r
.re3s4tim
.re3s4tip
.re3s4toc
.re3s4top
.re3s4tr
.re4s5trein
.re4s5trict
.re4s5trin
.re3s4tu
.re3s4ty
.r^^e9u2
.r^^e92uss
.r^^e9tro1a2
4re.
4res.
2rent.
.pa3rent.
appa3rent.
transpa3rent.
^^e93rent.
tor3rent.
cur3rent.
1r2h
4rhe.
4rhes.
2r3heur
2r3hydr
1ri
1r^^ee
1ro
1r^^f4
1ru
1r^^fb
1ry
1sa
1s^^e2
.sch4
1s2caph
1s2cl^^e9r
1s2cop
1s2ch
e2s3ch
i2s3ch^^e9
i2s3chia
i2s3chio
4sch.
4sche.
4sches.
2schs
1se
1s^^e9
1s^^e8
1s^^ea
sesqui1a2
4se.
4ses.
2sent.
ab3sent.
pr^^e93sent.
.res3sent.
.seu2le
.sh4
1s2h
4sh.
4she.
4shes.
2shent.
2shm
2s3hom
2shr
2shs
1si
1s^^ee
1s2lav
1s2lov
1so
1s^^f4
1s^^f7
1s2patia
1s2perm
1s2por
1s2ph^^e8r
1s2ph^^e9r
1s2piel
1s2piros
1s2tandard
1s2tein
st^^e9r^^e9o1s2
1s2tigm
1s2tock
1s2tomos
1s2troph
1s2tructu
1s2tyle
1su
1s^^fb
.su2b1a2
.su3b2alt
.su2b1^^e92
.su3b2^^e93r
.su2b1in
.su2b3limin
.su2b3lin
.su2b3lu
sub1s2
.su2b1ur
supero2
supe4r1
supers2
.su2r1a2
su3r2ah
.su3r2a3t
.su2r1e2
.su3r2eau
.su3r2ell
.su3r2et
.su2r1^^e92
.su2r3h
.su2r1i2m
.su2r1inf
.su2r1int
.su2r1of
.su2r1ox
1sy
1ta
1t^^e2
1t^^e0
tachy1a2
tchin3t2
1te
1t^^e9
1t^^e8
1t^^ea
t^^e9l^^e91e2
t^^e9l^^e91i2
t^^e9l^^e91o2b
t^^e9l^^e91o2p
t^^e9l^^e91s2
4te.
4tes.
2tent.
.la3tent.
.pa3tent.
comp^^e93tent.
^^e9ni3tent.
m^^e9con3tent.
omnipo3tent.
ventripo3tent.
^^e9quipo3tent.
impo3tent.
mit3tent.
.th4
1t2h
4th.
4the.
4thes.
thermo1s2
2t3heur
2thl
2thm
2thn
th2r
4thre.
4thres.
2ths
1ti
1t^^ee
1to
1t^^f4
1t2r
tran2s1a2
tran3s2act
tran3s2ats
tran2s3h
tran2s1o2
tran2s3p
tran2s1u2
4tre.
4tres.
2trent.
.tri1a2c
.tri1a2n
.tri1a2t
.tri1o2n
t1t2l
1tu
1t^^fb
tung2s3
1ty
.u4
'u4
.^^fb4
'^^fb4
uni1o2v
uni1a2x
u2s3tr
1va
1v^^e2
1ve
1v^^e9
1v^^e8
1v^^ea
v^^e9lo1s2ki
4ve.
4ves.
2vent.
conni3vent.
.sou3vent.
1vi
1v^^ee
1vo
1v^^f4
vol2t1amp
1v2r
4vre.
4vres.
2vrent.
1vu
1v^^fb
1vy
1wa
1we
4we.
4wes.
2went.
1wi
1wo
1wu
1w2r
2xent.
.y4
'y4
y1asth
y1s2tom
y1algi
1za
1ze
1z^^e9
1z^^e8
4ze.
4zes.
2zent.
privatdo3zent.
1zi
1zo
1zu
1zy
}
\egroup

