## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Ro_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Ro_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Ro_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-ro.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: romanian (ro)
% encoding: ec
%
% This file has been auto-generated from hyph-ro.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"EE="EE
\lccode"A0="A0
\lccode"B3="B3
\lccode"B5="B5
\patterns{
.a3ic
.a4n3is
.a2z
.cre1
.de2aj
.de2z1
.g4
.i2a
.i2e
.i3^^b5
.i4u3
.i3v
.^^ee4m
.n2
.ni2
.p4
.pre3^^b3
.s4
.^^b34
.u4i
.u5ni
.z2
a1
2ac^^a0
achi5
a3e
afo3
a3i2a
a3i2e
a3il
ai3s2
a3iu
alie6
2alt
a2m
a2n
2an.
a5n2e
ani2e
ani3^^b34
an4s
2anu
an2z
ao2g
ati4a
2atr
a5t4u
2a^^b5a
2a^^b5^^a0
2au
a3ua
a3ud
a3ug
a3ul
a3un
a3ur
a3us
a3ute
a3u2^^b5
a3uz
2^^a01
^^a03i
^^a0i2e
^^a02m2
^^a0nu3
^^a0rgi5
^^a03^^b3
^^a04^^b33t
^^a02ti.
^^a0ti4e
^^a03u
^^a03v
^^a02zi
1b
2b.
ba2^^b5
b^^a0nu5
2bc
2bd
bi2a.
bi2at
bi2e
3bii
b2l
3b4lim
b4lu
bo1
bo3ric
2bs
2bt
2b^^b5
b^^b5i4ne.
bu3
1c
4c.
ca3ut
c^^a02c
c^^a0tu5
2cc
ce2a
ce2^^b5
2chi.
2ci.
ci3ale
ci2o
cis2
ci3sp
ciza2
c4l
2cm
2c5n
copia2t^^a0
co2^^b5
2cs
2ct
2c^^b5
cu3im
3cul
cu2^^b5
2cv
1d
4d.
da4m
da2^^b5
2dc
de4sc
dez3in
di2an
dia2t^^a0
2dj
2dm
2d1n
do4il
3du
e1ac
e1aj
e1al
e1a^^b3
e1at
ea2^^b5
e1av
ebu5i
2ec
eci2a
ecla2re
edi4ulu
e3e
ee2a
1efa
e1h
e3i2a
e3i2e
e3ii
e3il
e3im
e3in
e3i2o
e3i3s2
e3it
e3i4u
e1^^ee
2el
e2m
emon5
2en
e5ne
e1o1
e3on
e1r
2era
2er^^a0
2erc
2e2s
es3co
es5ti
2e^^b3
e3^^b3i
etan4^^b5
2e^^b5
e3u
eu5^^b3
1evit
e2x
2ez
ez^^a05
ezi3a
e2z1o
1f4
2f.
3fa
3f^^a0^^b3
2fi.
fi3e
3fo
2ft
f5tu
1g2
2g.
g^^a03^^b5
2ghi.
2gi.
g4l
2g3m
2g3n
go5n
3gu3
2g3v
2h.
2hi.
hi2a
hi3c
hi4u
2h1n
2i1
4i.
3i2ac
ia3g4
i2ai
i2a^^b3
ia2^^b5
i3c^^a0
i2ed
i3ia
i3ie
i3ii
i3il
i3in
i3ir
i3it
iitu2r^^a0
i2^^ee
4ila
i3le
i3lo
imateri6
i2n
i4n1ed
in2g^^a0
in^^b5i4i
3inv
i3od
i3oni
io2^^b5
ip^^a05
i2s
is3f
4isp
i^^b33t
i5ti
i^^b5i2a
i3^^b5i2o
i3ua
i3ul
i3um
i3und
i3unu
i3us
i3ut
iz3v
^^ee2
^^ee3d
^^ee3e
^^ee3lo
^^eena3
^^een5^^b3
^^ee3ri
^^ee3r^^ee
^^eer5^^b3
^^ee^^b33t
^^ee3t
^^ee4ti
^^ee3^^b5
^^ee4^^b5i
^^ee5^^b5ii
^^ee3z
1j
2j.
2jd
2ji.
ji2^^b5
2jl
j4u
ju3t
1k
1l
4l.
lara^^b5i2
l^^a02ti
l^^a0tu5
2lb
2lc
2ld
le2a
2lf
2lg
4li.
li3a
li3e
li3o
2lm
2l5n
2lp
2ls
2l3^^b3
2lt
2l^^b5
3lu
2lv
1m
2m.
3ma
3m^^a0
2mb
mbl^^een3
3me
me2z
2mf
3mi
4mi.
mi2^^b5
3m^^ee
2m1n
3mo
mon4
2mp
2m3s2
2mt
2m^^b5
3mu
mu2^^b5
2mv
4n.
3na
4n1ad
na3in
3n^^a0
2nc
n2cis
n2ciz
2nd
3ne
ne1ab
ne1an
ne1ap
4nef
4n1eg
ne3s2
4nevi
4n1ex
2ng
ng3^^a0t
3ni
4ni.
ni3ez
3n^^ee
n3j
n1n
3no
no4^^b3
n1r
2n3s2
ns3f
n4s^^ee
ns3po
n3^^b32
n4^^b3i
2nt
n5ti
n5t4u
2n^^b5
5nu
nu3a
nu3^^a0
nu5m
nu3s2
2nz
o1ag
o2al
o2bi.
2oca
ocu5i
2od
odi2a
o3e
o3i2
oiecti2
oi3s2p
omedi2e.
om4n
2on
o1o
opi3e
opla2
oplagi2
o1ra
o1r^^a0
or2c
o1re
o1ri
o2ric
o1r^^ee
o1ro
or2te.
o1ru
os5ti
o3^^b3i
ota^^b5i4
o5ti
ot3od
o3u
1p2
2p.
3pa
p^^a0r3^^b5
2p3c
pec^^b5i2
pe2^^b5
2pi.
pi2e
pi3e.
pi3ez
pi3o
pi2^^b5
pi2z
p4l
po4^^b3
po2^^b5
2p3s
2p3^^b3
2p3t
2p3^^b5
p4^^b5i.
pu3b4
puri2e
pu4^^b3
4r.
2rb
2rc
2rd
r2e
re2bi
recizi2
re3s2cr
re4^^b3i
2rf
2rg
2r1h
4ri.
ri3a
ri4ali
ri3e^^b5
ri3ez
ri5mi
2ri3un
ri3v
2rk
2rl
2rm
2r1n
rna2^^b5
rografi6
2rp
2r1r
2rs2
r3sp
r3st
2r3^^b3
2rt
rtua2le
2r^^b5
ru3il
ru3sp
2rv
2rz
1s
4s.
5sa
5s^^a0
s^^a04m
s^^a04^^b3
2sc
4sc.
3s2co
3se
se2a
se4e.
ses2
se3sp
se4^^b3
4s2f
5sf^^ee
3si
si3p
3s^^ee
3s4l
4sm
s1n
3so
so3ric
2sp
2st
sto3
5su
su2^^b5
2^^b3
4^^b3.
3^^b3a
^^b3a2^^b5
3^^b3^^a02
3^^b3e
1^^b3i
4^^b3i.
5^^b3ii
5^^b3il
3^^b3in
3^^b3^^ee
4^^b35n
^^b3nu5
3^^b3o
^^b32p
^^b32ti
4^^b3ti.
4^^b33tr
3^^b3u
1t2
4t.
ta3ut
2t3c
2t3d
te2a
te5ni
teri6al^^a0
te3s2p
2t3f
4ti.
ti3a
ti3e
3tii.
3til
3tin
ti2^^b5
2t^^ee.
t4l
2t3m
3tol
3tor
to2to
3tru.
3trul
3truo
4t3s2
2t3t
tu3a
tu3im
4t3un
tu4^^b3
4t3z
1^^b5
2^^b5.
3^^b5a
3^^b5^^a0
^^b5e2^^b5
2^^b5i.
3^^b5ia
^^b5i3a.
3^^b5ie
3^^b5ii
3^^b5il
^^b5i2^^b5
3^^b5iu
^^b5u3
^^b5u5i
2u1
6u.
u2a.
u2ad
u3au
u^^a03
u^^a0s2
u2bia
u2b3l
u2b1o
ub3s2
u3e
4ugu
u3i2a
u3i2e
u3in
u3ir
u3is
u3it
u3i2^^b5
u3iz
u2l
u3la
u3l^^a0
u3le
u3lii
u3l^^ee
u3lo
umi5r
ur2z
u2s
us2pr
u4st
u3^^b3
u4^^b3t
u2to
3utor
u3ui
u3um
1v
2v.
ve5ni
ve2^^b5
ve2z
2vi.
vi2^^b5
2v1n
vorbito2
3vr
1x
2x.
3xa
3x^^a0
3xe
xe2z
3xi
3xo
3xu
1z
2z.
za2^^b5
2zb
2z2g
2zi.
zi2an
zi2ar
3zii
3zil
z4m
2z1n
3z2ol
3zon
zu2^^b5
2z2v
z3v^^a0
}
\egroup

