## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Fi_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Fi_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Fi_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-fi.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: finnish (fi)
% encoding: ec
%
% This file has been auto-generated from hyph-fi.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"E4="E4
\lccode"F6="F6
\patterns{
1ba
1be
1bi
1bo
1bu
1by
1da
1de
1di
1do
1du
1dy
1d^^e4
1d^^f6
1fa
1fe
1fi
1fo
1fu
1fy
1ga
1ge
1gi
1go
1gu
1gy
1g^^e4
1g^^f6
1ha
1he
1hi
1ho
1hu
1hy
1h^^e4
1h^^f6
1ja
1je
1ji
1jo
1ju
1jy
1j^^e4
1j^^f6
1ka
1ke
1ki
1ko
1ku
1ky
1k^^e4
1k^^f6
1la
1le
1li
1lo
1lu
1ly
1l^^e4
1l^^f6
1ma
1me
1mi
1mo
1mu
1my
1m^^e4
1m^^f6
1na
1ne
1ni
1no
1nu
1ny
1n^^e4
1n^^f6
1pa
1pe
1pi
1po
1pu
1py
1p^^e4
1p^^f6
1ra
1re
1ri
1ro
1ru
1ry
1r^^e4
1r^^f6
1sa
1se
1si
1so
1su
1sy
1s^^e4
1s^^f6
1ta
1te
1ti
1to
1tu
1ty
1t^^e4
1t^^f6
1va
1ve
1vi
1vo
1vu
1vy
1v^^e4
1v^^f6
1st2r
^^e42y
y1a2
y1o2
o1y
^^f62y
u1y2
y1u2
^^f63a2
^^f63o2
^^e43a2
^^e43o2
^^e41u2
^^f61u2
a1^^e4
a1^^f6
o1^^e4
o1^^f6
u1^^e42
u1^^f62
^^e42^^e4
^^f62^^f6
^^e42^^f6
^^f62^^e4
aa1i2
aa1e2
aa1o2
aa1u2
ee1a2
ee1i2
ee1u2
ee1y2
ii1a2
ii1e2
ii1o2
uu1a2
uu1e2
uu1o2
uu1i2
e1aa
i1aa
o1aa
u1aa
u1ee
a1uu
i1uu
e1uu
o1uu
^^e4^^e41i
^^e4^^e41e
^^e4^^e43y
i1^^e4^^e4
e1^^e4^^e4
y1^^e4^^e4
i1^^f6^^f6
a1ei
a1oi
e1ai
i1au
y1ei
ai1a
ai1e
ai1o
ai1u
au1a
au1e
eu1a
ie1a
ie1o
ie1y
io1a2
io1e2
iu1a
iu1e
iu1o
oi1a
oi1e
oi1o
oi1u
o1ui
ou1e
ou1o
ue1a
ui1e
uo1a
uo1u
e1^^f62
^^f61e2
.^^e42
u2s
yli1o2p
ali1a2v
1sp2li
alous1
keus1
rtaus1
2s1ohje
2s1a2sia
1a2sian
1a2siat
1a2sioi
r2as
l2as
2s1o2pisk
2n1o2pet
2s1a2loi
2n1o2pist
2s1o2pist
2s1o2sa
2n1o2sa
alkei2s1
perus1
2s1i2dea.
2s1i2dean
2s1e2sity
2n1e2dus
2s1ajatu
2s1ase
2s1apu
2s1y2rit
.ydi2n1
.suu2r1a2
2s1y2hti
2n1otto
2n1oton
2n1anto
2n1anno
2n1a2jan
2n1aika
2n1o2mai
2n1y2lit
2s1a2len
2n1a2len
1a2siaka2s1
ulo2s1
2n1a2jo
2s1a2jo
b2l
1b2lo
bib3li
b2r
1b2ri
1b2ro
1b2ru
d2r
1d2ra
f2l
1f2la
f2r
1f2ra
1f2re
g2l
1g2lo
g2r
1g2ra
k2l
1k2ra
1k2re
1k2ri
1k2v
1k2va
p2l
p2r
1p2ro
c2l
q2v
1q2vi
sc2h
ts2h
ch2r
}
\egroup

