## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Tk_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Tk_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Tk_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-tk.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: turkmen (tk)
% encoding: ec
%
% This file has been auto-generated from hyph-tk.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"E4="E4
\lccode"E7="E7
\lccode"F6="F6
\lccode"FC="FC
\lccode"FD="FD
\lccode"AC="AC
\lccode"B3="B3
\lccode"BA="BA
\patterns{
1-4
^^e41b^^e4
^^e41be
^^e41bi
^^e41b^^f6
^^e41b^^fc
^^e41^^e7^^e4
^^e41^^e7e
^^e41^^e7i
^^e41^^e7^^f6
^^e41^^e7^^fc
^^e41d^^e4
^^e41de
^^e41di
^^e41d^^f6
^^e41d^^fc
^^e41f^^e4
^^e41fe
^^e41fi
^^e41f^^f6
^^e41f^^fc
^^e41g^^e4
^^e41ge
^^e41gi
^^e41g^^f6
^^e41g^^fc
^^e41h^^e4
^^e41he
^^e41hi
^^e41h^^f6
^^e41h^^fc
^^e41j^^e4
^^e41je
^^e41ji
^^e41j^^f6
^^e41j^^fc
^^e41k^^e4
^^e41ke
^^e41ki
^^e41k^^f6
^^e41k^^fc
^^e41l^^e4
^^e41le
^^e41li
^^e41l^^f6
^^e41l^^fc
^^e41m^^e4
^^e41me
^^e41mi
^^e41m^^f6
^^e41m^^fc
^^e41n^^e4
^^e41ne
^^e41ni
^^e41n^^f6
^^e41n^^fc
^^e41p^^e4
^^e41pe
^^e41pi
^^e41p^^f6
^^e41p^^fc
^^e41r^^e4
^^e41re
^^e41ri
^^e41r^^f6
^^e41r^^fc
^^e41s^^e4
^^e41se
^^e41si
^^e41s^^f6
^^e41s^^fc
^^e41t^^e4
^^e41te
^^e41ti
^^e41t^^f6
^^e41t^^fc
^^e41w^^e4
^^e41we
^^e41wi
^^e41w^^f6
^^e41w^^fc
^^e41^^fd^^e4
^^e41^^fde
^^e41^^fdi
^^e41^^fd^^f6
^^e41^^fd^^fc
^^e41z^^e4
^^e41ze
^^e41zi
^^e41z^^f6
^^e41z^^fc
^^e41^^ac^^e4
^^e41^^ace
^^e41^^aci
^^e41^^ac^^f6
^^e41^^ac^^fc
^^e41^^ba^^e4
^^e41^^bae
^^e41^^bai
^^e41^^ba^^f6
^^e41^^ba^^fc
^^e41^^b3^^e4
^^e41^^b3e
^^e41^^b3i
^^e41^^b3^^f6
^^e41^^b3^^fc
e1b^^e4
e1be
e1bi
e1b^^f6
e1b^^fc
e1^^e7^^e4
e1^^e7e
e1^^e7i
e1^^e7^^f6
e1^^e7^^fc
e1d^^e4
e1de
e1di
e1d^^f6
e1d^^fc
e1f^^e4
e1fe
e1fi
e1f^^f6
e1f^^fc
e1g^^e4
e1ge
e1gi
e1g^^f6
e1g^^fc
e1h^^e4
e1he
e1hi
e1h^^f6
e1h^^fc
e1j^^e4
e1je
e1ji
e1j^^f6
e1j^^fc
e1k^^e4
e1ke
e1ki
e1k^^f6
e1k^^fc
e1l^^e4
e1le
e1li
e1l^^f6
e1l^^fc
e1m^^e4
e1me
e1mi
e1m^^f6
e1m^^fc
e1n^^e4
e1ne
e1ni
e1n^^f6
e1n^^fc
e1p^^e4
e1pe
e1pi
e1p^^f6
e1p^^fc
e1r^^e4
e1re
e1ri
e1r^^f6
e1r^^fc
e1s^^e4
e1se
e1si
e1s^^f6
e1s^^fc
e1t^^e4
e1te
e1ti
e1t^^f6
e1t^^fc
e1w^^e4
e1we
e1wi
e1w^^f6
e1w^^fc
e1^^fd^^e4
e1^^fde
e1^^fdi
e1^^fd^^f6
e1^^fd^^fc
e1z^^e4
e1ze
e1zi
e1z^^f6
e1z^^fc
e1^^ac^^e4
e1^^ace
e1^^aci
e1^^ac^^f6
e1^^ac^^fc
e1^^ba^^e4
e1^^bae
e1^^bai
e1^^ba^^f6
e1^^ba^^fc
e1^^b3^^e4
e1^^b3e
e1^^b3i
e1^^b3^^f6
e1^^b3^^fc
i1b^^e4
i1be
i1bi
i1b^^f6
i1b^^fc
i1^^e7^^e4
i1^^e7e
i1^^e7i
i1^^e7^^f6
i1^^e7^^fc
i1d^^e4
i1de
i1di
i1d^^f6
i1d^^fc
i1f^^e4
i1fe
i1fi
i1f^^f6
i1f^^fc
i1g^^e4
i1ge
i1gi
i1g^^f6
i1g^^fc
i1h^^e4
i1he
i1hi
i1h^^f6
i1h^^fc
i1j^^e4
i1je
i1ji
i1j^^f6
i1j^^fc
i1k^^e4
i1ke
i1ki
i1k^^f6
i1k^^fc
i1l^^e4
i1le
i1li
i1l^^f6
i1l^^fc
i1m^^e4
i1me
i1mi
i1m^^f6
i1m^^fc
i1n^^e4
i1ne
i1ni
i1n^^f6
i1n^^fc
i1p^^e4
i1pe
i1pi
i1p^^f6
i1p^^fc
i1r^^e4
i1re
i1ri
i1r^^f6
i1r^^fc
i1s^^e4
i1se
i1si
i1s^^f6
i1s^^fc
i1t^^e4
i1te
i1ti
i1t^^f6
i1t^^fc
i1w^^e4
i1we
i1wi
i1w^^f6
i1w^^fc
i1^^fd^^e4
i1^^fde
i1^^fdi
i1^^fd^^f6
i1^^fd^^fc
i1z^^e4
i1ze
i1zi
i1z^^f6
i1z^^fc
i1^^ac^^e4
i1^^ace
i1^^aci
i1^^ac^^f6
i1^^ac^^fc
i1^^ba^^e4
i1^^bae
i1^^bai
i1^^ba^^f6
i1^^ba^^fc
i1^^b3^^e4
i1^^b3e
i1^^b3i
i1^^b3^^f6
i1^^b3^^fc
^^f61b^^e4
^^f61be
^^f61bi
^^f61b^^f6
^^f61b^^fc
^^f61^^e7^^e4
^^f61^^e7e
^^f61^^e7i
^^f61^^e7^^f6
^^f61^^e7^^fc
^^f61d^^e4
^^f61de
^^f61di
^^f61d^^f6
^^f61d^^fc
^^f61f^^e4
^^f61fe
^^f61fi
^^f61f^^f6
^^f61f^^fc
^^f61g^^e4
^^f61ge
^^f61gi
^^f61g^^f6
^^f61g^^fc
^^f61h^^e4
^^f61he
^^f61hi
^^f61h^^f6
^^f61h^^fc
^^f61j^^e4
^^f61je
^^f61ji
^^f61j^^f6
^^f61j^^fc
^^f61k^^e4
^^f61ke
^^f61ki
^^f61k^^f6
^^f61k^^fc
^^f61l^^e4
^^f61le
^^f61li
^^f61l^^f6
^^f61l^^fc
^^f61m^^e4
^^f61me
^^f61mi
^^f61m^^f6
^^f61m^^fc
^^f61n^^e4
^^f61ne
^^f61ni
^^f61n^^f6
^^f61n^^fc
^^f61p^^e4
^^f61pe
^^f61pi
^^f61p^^f6
^^f61p^^fc
^^f61r^^e4
^^f61re
^^f61ri
^^f61r^^f6
^^f61r^^fc
^^f61s^^e4
^^f61se
^^f61si
^^f61s^^f6
^^f61s^^fc
^^f61t^^e4
^^f61te
^^f61ti
^^f61t^^f6
^^f61t^^fc
^^f61w^^e4
^^f61we
^^f61wi
^^f61w^^f6
^^f61w^^fc
^^f61^^fd^^e4
^^f61^^fde
^^f61^^fdi
^^f61^^fd^^f6
^^f61^^fd^^fc
^^f61z^^e4
^^f61ze
^^f61zi
^^f61z^^f6
^^f61z^^fc
^^f61^^ac^^e4
^^f61^^ace
^^f61^^aci
^^f61^^ac^^f6
^^f61^^ac^^fc
^^f61^^ba^^e4
^^f61^^bae
^^f61^^bai
^^f61^^ba^^f6
^^f61^^ba^^fc
^^f61^^b3^^e4
^^f61^^b3e
^^f61^^b3i
^^f61^^b3^^f6
^^f61^^b3^^fc
^^fc1b^^e4
^^fc1be
^^fc1bi
^^fc1b^^f6
^^fc1b^^fc
^^fc1^^e7^^e4
^^fc1^^e7e
^^fc1^^e7i
^^fc1^^e7^^f6
^^fc1^^e7^^fc
^^fc1d^^e4
^^fc1de
^^fc1di
^^fc1d^^f6
^^fc1d^^fc
^^fc1f^^e4
^^fc1fe
^^fc1fi
^^fc1f^^f6
^^fc1f^^fc
^^fc1g^^e4
^^fc1ge
^^fc1gi
^^fc1g^^f6
^^fc1g^^fc
^^fc1h^^e4
^^fc1he
^^fc1hi
^^fc1h^^f6
^^fc1h^^fc
^^fc1j^^e4
^^fc1je
^^fc1ji
^^fc1j^^f6
^^fc1j^^fc
^^fc1k^^e4
^^fc1ke
^^fc1ki
^^fc1k^^f6
^^fc1k^^fc
^^fc1l^^e4
^^fc1le
^^fc1li
^^fc1l^^f6
^^fc1l^^fc
^^fc1m^^e4
^^fc1me
^^fc1mi
^^fc1m^^f6
^^fc1m^^fc
^^fc1n^^e4
^^fc1ne
^^fc1ni
^^fc1n^^f6
^^fc1n^^fc
^^fc1p^^e4
^^fc1pe
^^fc1pi
^^fc1p^^f6
^^fc1p^^fc
^^fc1r^^e4
^^fc1re
^^fc1ri
^^fc1r^^f6
^^fc1r^^fc
^^fc1s^^e4
^^fc1se
^^fc1si
^^fc1s^^f6
^^fc1s^^fc
^^fc1t^^e4
^^fc1te
^^fc1ti
^^fc1t^^f6
^^fc1t^^fc
^^fc1w^^e4
^^fc1we
^^fc1wi
^^fc1w^^f6
^^fc1w^^fc
^^fc1^^fd^^e4
^^fc1^^fde
^^fc1^^fdi
^^fc1^^fd^^f6
^^fc1^^fd^^fc
^^fc1z^^e4
^^fc1ze
^^fc1zi
^^fc1z^^f6
^^fc1z^^fc
^^fc1^^ac^^e4
^^fc1^^ace
^^fc1^^aci
^^fc1^^ac^^f6
^^fc1^^ac^^fc
^^fc1^^ba^^e4
^^fc1^^bae
^^fc1^^bai
^^fc1^^ba^^f6
^^fc1^^ba^^fc
^^fc1^^b3^^e4
^^fc1^^b3e
^^fc1^^b3i
^^fc1^^b3^^f6
^^fc1^^b3^^fc
a1ba
a1by
a1bo
a1bu
a1^^e7a
a1^^e7y
a1^^e7o
a1^^e7u
a1da
a1dy
a1do
a1du
a1fa
a1fy
a1fo
a1fu
a1ga
a1gy
a1go
a1gu
a1ha
a1hy
a1ho
a1hu
a1ja
a1jy
a1jo
a1ju
a1ka
a1ky
a1ko
a1ku
a1la
a1ly
a1lo
a1lu
a1ma
a1my
a1mo
a1mu
a1na
a1ny
a1no
a1nu
a1pa
a1py
a1po
a1pu
a1ra
a1ry
a1ro
a1ru
a1sa
a1sy
a1so
a1su
a1ta
a1ty
a1to
a1tu
a1wa
a1wy
a1wo
a1wu
a1^^fda
a1^^fdy
a1^^fdo
a1^^fdu
a1za
a1zy
a1zo
a1zu
a1^^aca
a1^^acy
a1^^aco
a1^^acu
a1^^baa
a1^^bay
a1^^bao
a1^^bau
a1^^b3a
a1^^b3y
a1^^b3o
a1^^b3u
y1ba
y1by
y1bo
y1bu
y1^^e7a
y1^^e7y
y1^^e7o
y1^^e7u
y1da
y1dy
y1do
y1du
y1fa
y1fy
y1fo
y1fu
y1ga
y1gy
y1go
y1gu
y1ha
y1hy
y1ho
y1hu
y1ja
y1jy
y1jo
y1ju
y1ka
y1ky
y1ko
y1ku
y1la
y1ly
y1lo
y1lu
y1ma
y1my
y1mo
y1mu
y1na
y1ny
y1no
y1nu
y1pa
y1py
y1po
y1pu
y1ra
y1ry
y1ro
y1ru
y1sa
y1sy
y1so
y1su
y1ta
y1ty
y1to
y1tu
y1wa
y1wy
y1wo
y1wu
y1^^fda
y1^^fdy
y1^^fdo
y1^^fdu
y1za
y1zy
y1zo
y1zu
y1^^aca
y1^^acy
y1^^aco
y1^^acu
y1^^baa
y1^^bay
y1^^bao
y1^^bau
y1^^b3a
y1^^b3y
y1^^b3o
y1^^b3u
o1ba
o1by
o1bo
o1bu
o1^^e7a
o1^^e7y
o1^^e7o
o1^^e7u
o1da
o1dy
o1do
o1du
o1fa
o1fy
o1fo
o1fu
o1ga
o1gy
o1go
o1gu
o1ha
o1hy
o1ho
o1hu
o1ja
o1jy
o1jo
o1ju
o1ka
o1ky
o1ko
o1ku
o1la
o1ly
o1lo
o1lu
o1ma
o1my
o1mo
o1mu
o1na
o1ny
o1no
o1nu
o1pa
o1py
o1po
o1pu
o1ra
o1ry
o1ro
o1ru
o1sa
o1sy
o1so
o1su
o1ta
o1ty
o1to
o1tu
o1wa
o1wy
o1wo
o1wu
o1^^fda
o1^^fdy
o1^^fdo
o1^^fdu
o1za
o1zy
o1zo
o1zu
o1^^aca
o1^^acy
o1^^aco
o1^^acu
o1^^baa
o1^^bay
o1^^bao
o1^^bau
o1^^b3a
o1^^b3y
o1^^b3o
o1^^b3u
u1ba
u1by
u1bo
u1bu
u1^^e7a
u1^^e7y
u1^^e7o
u1^^e7u
u1da
u1dy
u1do
u1du
u1fa
u1fy
u1fo
u1fu
u1ga
u1gy
u1go
u1gu
u1ha
u1hy
u1ho
u1hu
u1ja
u1jy
u1jo
u1ju
u1ka
u1ky
u1ko
u1ku
u1la
u1ly
u1lo
u1lu
u1ma
u1my
u1mo
u1mu
u1na
u1ny
u1no
u1nu
u1pa
u1py
u1po
u1pu
u1ra
u1ry
u1ro
u1ru
u1sa
u1sy
u1so
u1su
u1ta
u1ty
u1to
u1tu
u1wa
u1wy
u1wo
u1wu
u1^^fda
u1^^fdy
u1^^fdo
u1^^fdu
u1za
u1zy
u1zo
u1zu
u1^^aca
u1^^acy
u1^^aco
u1^^acu
u1^^baa
u1^^bay
u1^^bao
u1^^bau
u1^^b3a
u1^^b3y
u1^^b3o
u1^^b3u
a1bi
a1be
y1b^^e4
y1bi
y1be
o1bi
o1be
u1bi
u1be
i1ba
i1bo
e1ba
e1bo
^^e41bo
^^e41ba
^^f61ba
a1^^e7i
a1^^e7e
y1^^e7^^e4
y1^^e7i
y1^^e7e
o1^^e7i
o1^^e7e
u1^^e7i
u1^^e7e
i1^^e7a
i1^^e7o
e1^^e7a
e1^^e7o
^^e41^^e7o
^^e41^^e7a
^^f61^^e7a
a1di
a1de
y1d^^e4
y1di
y1de
o1di
o1de
u1di
u1de
i1da
i1do
e1da
e1do
^^e41do
^^e41da
^^f61da
a1fi
a1fe
y1f^^e4
y1fi
y1fe
o1fi
o1fe
u1fi
u1fe
i1fa
i1fo
e1fa
e1fo
^^e41fo
^^e41fa
^^f61fa
a1gi
a1ge
y1g^^e4
y1gi
y1ge
o1gi
o1ge
u1gi
u1ge
i1ga
i1go
e1ga
e1go
^^e41go
^^e41ga
^^f61ga
a1hi
a1he
y1h^^e4
y1hi
y1he
o1hi
o1he
u1hi
u1he
i1ha
i1ho
e1ha
e1ho
^^e41ho
^^e41ha
^^f61ha
a1ji
a1je
y1j^^e4
y1ji
y1je
o1ji
o1je
u1ji
u1je
i1ja
i1jo
e1ja
e1jo
^^e41jo
^^e41ja
^^f61ja
a1ki
a1ke
y1k^^e4
y1ki
y1ke
o1ki
o1ke
u1ki
u1ke
i1ka
i1ko
e1ka
e1ko
^^e41ko
^^e41ka
^^f61ka
a1li
a1le
y1l^^e4
y1li
y1le
o1li
o1le
u1li
u1le
i1la
i1lo
e1la
e1lo
^^e41lo
^^e41la
^^f61la
a1mi
a1me
y1m^^e4
y1mi
y1me
o1mi
o1me
u1mi
u1me
i1ma
i1mo
e1ma
e1mo
^^e41mo
^^e41ma
^^f61ma
a1ni
a1ne
y1n^^e4
y1ni
y1ne
o1ni
o1ne
u1ni
u1ne
i1na
i1no
e1na
e1no
^^e41no
^^e41na
^^f61na
a1pi
a1pe
y1p^^e4
y1pi
y1pe
o1pi
o1pe
u1pi
u1pe
i1pa
i1po
e1pa
e1po
^^e41po
^^e41pa
^^f61pa
a1ri
a1re
y1r^^e4
y1ri
y1re
o1ri
o1re
u1ri
u1re
i1ra
i1ro
e1ra
e1ro
^^e41ro
^^e41ra
^^f61ra
a1si
a1se
y1s^^e4
y1si
y1se
o1si
o1se
u1si
u1se
i1sa
i1so
e1sa
e1so
^^e41so
^^e41sa
^^f61sa
a1ti
a1te
y1t^^e4
y1ti
y1te
o1ti
o1te
u1ti
u1te
i1ta
i1to
e1ta
e1to
^^e41to
^^e41ta
^^f61ta
a1wi
a1we
y1w^^e4
y1wi
y1we
o1wi
o1we
u1wi
u1we
i1wa
i1wo
e1wa
e1wo
^^e41wo
^^e41wa
^^f61wa
a1^^fdi
a1^^fde
y1^^fd^^e4
y1^^fdi
y1^^fde
o1^^fdi
o1^^fde
u1^^fdi
u1^^fde
i1^^fda
i1^^fdo
e1^^fda
e1^^fdo
^^e41^^fdo
^^e41^^fda
^^f61^^fda
a1zi
a1ze
y1z^^e4
y1zi
y1ze
o1zi
o1ze
u1zi
u1ze
i1za
i1zo
e1za
e1zo
^^e41zo
^^e41za
^^f61za
a1^^aci
a1^^ace
y1^^ac^^e4
y1^^aci
y1^^ace
o1^^aci
o1^^ace
u1^^aci
u1^^ace
i1^^aca
i1^^aco
e1^^aca
e1^^aco
^^e41^^aco
^^e41^^aca
^^f61^^aca
a1^^bai
a1^^bae
y1^^ba^^e4
y1^^bai
y1^^bae
o1^^bai
o1^^bae
u1^^bai
u1^^bae
i1^^baa
i1^^bao
e1^^baa
e1^^bao
^^e41^^bao
^^e41^^baa
^^f61^^baa
a1^^b3i
a1^^b3e
y1^^b3^^e4
y1^^b3i
y1^^b3e
o1^^b3i
o1^^b3e
u1^^b3i
u1^^b3e
i1^^b3a
i1^^b3o
e1^^b3a
e1^^b3o
^^e41^^b3o
^^e41^^b3a
^^f61^^b3a
b1b
.b2b
b1^^e7
.b2^^e7
b1d
.b2d
b1f
.b2f
b1g
.b2g
b1h
.b2h
b1j
.b2j
b1k
.b2k
b1l
.b2l
b1m
.b2m
b1n
.b2n
b1p
.b2p
b1r
.b2r
b1s
.b2s
b1t
.b2t
b1w
.b2w
b1^^fd
.b2^^fd
b1z
.b2z
b1^^ac
.b2^^ac
b1^^ba
.b2^^ba
b1^^b3
.b2^^b3
^^e71b
.^^e72b
^^e71^^e7
.^^e72^^e7
^^e71d
.^^e72d
^^e71f
.^^e72f
^^e71g
.^^e72g
^^e71h
.^^e72h
^^e71j
.^^e72j
^^e71k
.^^e72k
^^e71l
.^^e72l
^^e71m
.^^e72m
^^e71n
.^^e72n
^^e71p
.^^e72p
^^e71r
.^^e72r
^^e71s
.^^e72s
^^e71t
.^^e72t
^^e71w
.^^e72w
^^e71^^fd
.^^e72^^fd
^^e71z
.^^e72z
^^e71^^ac
.^^e72^^ac
^^e71^^ba
.^^e72^^ba
^^e71^^b3
.^^e72^^b3
d1b
.d2b
d1^^e7
.d2^^e7
d1d
.d2d
d1f
.d2f
d1g
.d2g
d1h
.d2h
d1j
.d2j
d1k
.d2k
d1l
.d2l
d1m
.d2m
d1n
.d2n
d1p
.d2p
d1r
.d2r
d1s
.d2s
d1t
.d2t
d1w
.d2w
d1^^fd
.d2^^fd
d1z
.d2z
d1^^ac
.d2^^ac
d1^^ba
.d2^^ba
d1^^b3
.d2^^b3
f1b
.f2b
f1^^e7
.f2^^e7
f1d
.f2d
f1f
.f2f
f1g
.f2g
f1h
.f2h
f1j
.f2j
f1k
.f2k
f1l
.f2l
f1m
.f2m
f1n
.f2n
f1p
.f2p
f1r
.f2r
f1s
.f2s
f1t
.f2t
f1w
.f2w
f1^^fd
.f2^^fd
f1z
.f2z
f1^^ac
.f2^^ac
f1^^ba
.f2^^ba
f1^^b3
.f2^^b3
g1b
.g2b
g1^^e7
.g2^^e7
g1d
.g2d
g1f
.g2f
g1g
.g2g
g1h
.g2h
g1j
.g2j
g1k
.g2k
g1l
.g2l
g1m
.g2m
g1n
.g2n
g1p
.g2p
g1r
.g2r
g1s
.g2s
g1t
.g2t
g1w
.g2w
g1^^fd
.g2^^fd
g1z
.g2z
g1^^ac
.g2^^ac
g1^^ba
.g2^^ba
g1^^b3
.g2^^b3
h1b
.h2b
h1^^e7
.h2^^e7
h1d
.h2d
h1f
.h2f
h1g
.h2g
h1h
.h2h
h1j
.h2j
h1k
.h2k
h1l
.h2l
h1m
.h2m
h1n
.h2n
h1p
.h2p
h1r
.h2r
h1s
.h2s
h1t
.h2t
h1w
.h2w
h1^^fd
.h2^^fd
h1z
.h2z
h1^^ac
.h2^^ac
h1^^ba
.h2^^ba
h1^^b3
.h2^^b3
j1b
.j2b
j1^^e7
.j2^^e7
j1d
.j2d
j1f
.j2f
j1g
.j2g
j1h
.j2h
j1j
.j2j
j1k
.j2k
j1l
.j2l
j1m
.j2m
j1n
.j2n
j1p
.j2p
j1r
.j2r
j1s
.j2s
j1t
.j2t
j1w
.j2w
j1^^fd
.j2^^fd
j1z
.j2z
j1^^ac
.j2^^ac
j1^^ba
.j2^^ba
j1^^b3
.j2^^b3
k1b
.k2b
k1^^e7
.k2^^e7
k1d
.k2d
k1f
.k2f
k1g
.k2g
k1h
.k2h
k1j
.k2j
k1k
.k2k
k1l
.k2l
k1m
.k2m
k1n
.k2n
k1p
.k2p
k1r
.k2r
k1s
.k2s
k1t
.k2t
k1w
.k2w
k1^^fd
.k2^^fd
k1z
.k2z
k1^^ac
.k2^^ac
k1^^ba
.k2^^ba
k1^^b3
.k2^^b3
l1b
.l2b
l1^^e7
.l2^^e7
l1d
.l2d
l1f
.l2f
l1g
.l2g
l1h
.l2h
l1j
.l2j
l1k
.l2k
l1l
.l2l
l1m
.l2m
l1n
.l2n
l1p
.l2p
l1r
.l2r
l1s
.l2s
l1t
.l2t
l1w
.l2w
l1^^fd
.l2^^fd
l1z
.l2z
l1^^ac
.l2^^ac
l1^^ba
.l2^^ba
l1^^b3
.l2^^b3
m1b
.m2b
m1^^e7
.m2^^e7
m1d
.m2d
m1f
.m2f
m1g
.m2g
m1h
.m2h
m1j
.m2j
m1k
.m2k
m1l
.m2l
m1m
.m2m
m1n
.m2n
m1p
.m2p
m1r
.m2r
m1s
.m2s
m1t
.m2t
m1w
.m2w
m1^^fd
.m2^^fd
m1z
.m2z
m1^^ac
.m2^^ac
m1^^ba
.m2^^ba
m1^^b3
.m2^^b3
n1b
.n2b
n1^^e7
.n2^^e7
n1d
.n2d
n1f
.n2f
n1g
.n2g
n1h
.n2h
n1j
.n2j
n1k
.n2k
n1l
.n2l
n1m
.n2m
n1n
.n2n
n1p
.n2p
n1r
.n2r
n1s
.n2s
n1t
.n2t
n1w
.n2w
n1^^fd
.n2^^fd
n1z
.n2z
n1^^ac
.n2^^ac
n1^^ba
.n2^^ba
n1^^b3
.n2^^b3
p1b
.p2b
p1^^e7
.p2^^e7
p1d
.p2d
p1f
.p2f
p1g
.p2g
p1h
.p2h
p1j
.p2j
p1k
.p2k
p1l
.p2l
p1m
.p2m
p1n
.p2n
p1p
.p2p
p1r
.p2r
p1s
.p2s
p1t
.p2t
p1w
.p2w
p1^^fd
.p2^^fd
p1z
.p2z
p1^^ac
.p2^^ac
p1^^ba
.p2^^ba
p1^^b3
.p2^^b3
r1b
.r2b
r1^^e7
.r2^^e7
r1d
.r2d
r1f
.r2f
r1g
.r2g
r1h
.r2h
r1j
.r2j
r1k
.r2k
r1l
.r2l
r1m
.r2m
r1n
.r2n
r1p
.r2p
r1r
.r2r
r1s
.r2s
r1t
.r2t
r1w
.r2w
r1^^fd
.r2^^fd
r1z
.r2z
r1^^ac
.r2^^ac
r1^^ba
.r2^^ba
r1^^b3
.r2^^b3
s1b
.s2b
s1^^e7
.s2^^e7
s1d
.s2d
s1f
.s2f
s1g
.s2g
s1h
.s2h
s1j
.s2j
s1k
.s2k
s1l
.s2l
s1m
.s2m
s1n
.s2n
s1p
.s2p
s1r
.s2r
s1s
.s2s
s1t
.s2t
s1w
.s2w
s1^^fd
.s2^^fd
s1z
.s2z
s1^^ac
.s2^^ac
s1^^ba
.s2^^ba
s1^^b3
.s2^^b3
t1b
.t2b
t1^^e7
.t2^^e7
t1d
.t2d
t1f
.t2f
t1g
.t2g
t1h
.t2h
t1j
.t2j
t1k
.t2k
t1l
.t2l
t1m
.t2m
t1n
.t2n
t1p
.t2p
t1r
.t2r
t1s
.t2s
t1t
.t2t
t1w
.t2w
t1^^fd
.t2^^fd
t1z
.t2z
t1^^ac
.t2^^ac
t1^^ba
.t2^^ba
t1^^b3
.t2^^b3
w1b
.w2b
w1^^e7
.w2^^e7
w1d
.w2d
w1f
.w2f
w1g
.w2g
w1h
.w2h
w1j
.w2j
w1k
.w2k
w1l
.w2l
w1m
.w2m
w1n
.w2n
w1p
.w2p
w1r
.w2r
w1s
.w2s
w1t
.w2t
w1w
.w2w
w1^^fd
.w2^^fd
w1z
.w2z
w1^^ac
.w2^^ac
w1^^ba
.w2^^ba
w1^^b3
.w2^^b3
^^fd1b
.^^fd2b
^^fd1^^e7
.^^fd2^^e7
^^fd1d
.^^fd2d
^^fd1f
.^^fd2f
^^fd1g
.^^fd2g
^^fd1h
.^^fd2h
^^fd1j
.^^fd2j
^^fd1k
.^^fd2k
^^fd1l
.^^fd2l
^^fd1m
.^^fd2m
^^fd1n
.^^fd2n
^^fd1p
.^^fd2p
^^fd1r
.^^fd2r
^^fd1s
.^^fd2s
^^fd1t
.^^fd2t
^^fd1w
.^^fd2w
^^fd1^^fd
.^^fd2^^fd
^^fd1z
.^^fd2z
^^fd1^^ac
.^^fd2^^ac
^^fd1^^ba
.^^fd2^^ba
^^fd1^^b3
.^^fd2^^b3
z1b
.z2b
z1^^e7
.z2^^e7
z1d
.z2d
z1f
.z2f
z1g
.z2g
z1h
.z2h
z1j
.z2j
z1k
.z2k
z1l
.z2l
z1m
.z2m
z1n
.z2n
z1p
.z2p
z1r
.z2r
z1s
.z2s
z1t
.z2t
z1w
.z2w
z1^^fd
.z2^^fd
z1z
.z2z
z1^^ac
.z2^^ac
z1^^ba
.z2^^ba
z1^^b3
.z2^^b3
^^ac1b
.^^ac2b
^^ac1^^e7
.^^ac2^^e7
^^ac1d
.^^ac2d
^^ac1f
.^^ac2f
^^ac1g
.^^ac2g
^^ac1h
.^^ac2h
^^ac1j
.^^ac2j
^^ac1k
.^^ac2k
^^ac1l
.^^ac2l
^^ac1m
.^^ac2m
^^ac1n
.^^ac2n
^^ac1p
.^^ac2p
^^ac1r
.^^ac2r
^^ac1s
.^^ac2s
^^ac1t
.^^ac2t
^^ac1w
.^^ac2w
^^ac1^^fd
.^^ac2^^fd
^^ac1z
.^^ac2z
^^ac1^^ac
.^^ac2^^ac
^^ac1^^ba
.^^ac2^^ba
^^ac1^^b3
.^^ac2^^b3
^^ba1b
.^^ba2b
^^ba1^^e7
.^^ba2^^e7
^^ba1d
.^^ba2d
^^ba1f
.^^ba2f
^^ba1g
.^^ba2g
^^ba1h
.^^ba2h
^^ba1j
.^^ba2j
^^ba1k
.^^ba2k
^^ba1l
.^^ba2l
^^ba1m
.^^ba2m
^^ba1n
.^^ba2n
^^ba1p
.^^ba2p
^^ba1r
.^^ba2r
^^ba1s
.^^ba2s
^^ba1t
.^^ba2t
^^ba1w
.^^ba2w
^^ba1^^fd
.^^ba2^^fd
^^ba1z
.^^ba2z
^^ba1^^ac
.^^ba2^^ac
^^ba1^^ba
.^^ba2^^ba
^^ba1^^b3
.^^ba2^^b3
^^b31b
.^^b32b
^^b31^^e7
.^^b32^^e7
^^b31d
.^^b32d
^^b31f
.^^b32f
^^b31g
.^^b32g
^^b31h
.^^b32h
^^b31j
.^^b32j
^^b31k
.^^b32k
^^b31l
.^^b32l
^^b31m
.^^b32m
^^b31n
.^^b32n
^^b31p
.^^b32p
^^b31r
.^^b32r
^^b31s
.^^b32s
^^b31t
.^^b32t
^^b31w
.^^b32w
^^b31^^fd
.^^b32^^fd
^^b31z
.^^b32z
^^b31^^ac
.^^b32^^ac
^^b31^^ba
.^^b32^^ba
^^b31^^b3
.^^b32^^b3
^^fd2t1b
^^fd2n1b
^^fd2d1b
r2t1b
^^fd2p1b
l2p1b
l2t1b
g2t1b
n2t1b
r2k1b
r2p1b
k2t1b
r2h1b
s2t1b
l2k1b
w2p1b
n2s1b
r2s1b
l2m1b
^^fd2t1^^e7
^^fd2n1^^e7
^^fd2d1^^e7
r2t1^^e7
^^fd2p1^^e7
l2p1^^e7
l2t1^^e7
g2t1^^e7
n2t1^^e7
r2k1^^e7
r2p1^^e7
k2t1^^e7
r2h1^^e7
s2t1^^e7
l2k1^^e7
w2p1^^e7
n2s1^^e7
r2s1^^e7
l2m1^^e7
^^fd2t1d
^^fd2n1d
^^fd2d1d
r2t1d
^^fd2p1d
l2p1d
l2t1d
g2t1d
n2t1d
r2k1d
r2p1d
k2t1d
r2h1d
s2t1d
l2k1d
w2p1d
n2s1d
r2s1d
l2m1d
^^fd2t1g
^^fd2n1g
^^fd2d1g
r2t1g
^^fd2p1g
l2p1g
l2t1g
g2t1g
n2t1g
r2k1g
r2p1g
k2t1g
r2h1g
s2t1g
l2k1g
w2p1g
n2s1g
r2s1g
l2m1g
^^fd2t1j
^^fd2n1j
^^fd2d1j
r2t1j
^^fd2p1j
l2p1j
l2t1j
g2t1j
n2t1j
r2k1j
r2p1j
k2t1j
r2h1j
s2t1j
l2k1j
w2p1j
n2s1j
r2s1j
l2m1j
^^fd2t1k
^^fd2n1k
^^fd2d1k
r2t1k
^^fd2p1k
l2p1k
l2t1k
g2t1k
n2t1k
r2k1k
r2p1k
k2t1k
r2h1k
s2t1k
l2k1k
w2p1k
n2s1k
r2s1k
l2m1k
^^fd2t1l
^^fd2n1l
^^fd2d1l
r2t1l
^^fd2p1l
l2p1l
l2t1l
g2t1l
n2t1l
r2k1l
r2p1l
k2t1l
r2h1l
s2t1l
l2k1l
w2p1l
n2s1l
r2s1l
l2m1l
^^fd2t1m
^^fd2n1m
^^fd2d1m
r2t1m
^^fd2p1m
l2p1m
l2t1m
g2t1m
n2t1m
r2k1m
r2p1m
k2t1m
r2h1m
s2t1m
l2k1m
w2p1m
n2s1m
r2s1m
l2m1m
^^fd2t1n
^^fd2n1n
^^fd2d1n
r2t1n
^^fd2p1n
l2p1n
l2t1n
g2t1n
n2t1n
r2k1n
r2p1n
k2t1n
r2h1n
s2t1n
l2k1n
w2p1n
n2s1n
r2s1n
l2m1n
^^fd2t1p
^^fd2n1p
^^fd2d1p
r2t1p
^^fd2p1p
l2p1p
l2t1p
g2t1p
n2t1p
r2k1p
r2p1p
k2t1p
r2h1p
s2t1p
l2k1p
w2p1p
n2s1p
r2s1p
l2m1p
^^fd2t1s
^^fd2n1s
^^fd2d1s
r2t1s
^^fd2p1s
l2p1s
l2t1s
g2t1s
n2t1s
r2k1s
r2p1s
k2t1s
r2h1s
s2t1s
l2k1s
w2p1s
n2s1s
r2s1s
l2m1s
^^fd2t1t
^^fd2n1t
^^fd2d1t
r2t1t
^^fd2p1t
l2p1t
l2t1t
g2t1t
n2t1t
r2k1t
r2p1t
k2t1t
r2h1t
s2t1t
l2k1t
w2p1t
n2s1t
r2s1t
l2m1t
^^fd2t1^^fd
^^fd2n1^^fd
^^fd2d1^^fd
r2t1^^fd
^^fd2p1^^fd
l2p1^^fd
l2t1^^fd
g2t1^^fd
n2t1^^fd
r2k1^^fd
r2p1^^fd
k2t1^^fd
r2h1^^fd
s2t1^^fd
l2k1^^fd
w2p1^^fd
n2s1^^fd
r2s1^^fd
l2m1^^fd
^^fd2t1z
^^fd2n1z
^^fd2d1z
r2t1z
^^fd2p1z
l2p1z
l2t1z
g2t1z
n2t1z
r2k1z
r2p1z
k2t1z
r2h1z
s2t1z
l2k1z
w2p1z
n2s1z
r2s1z
l2m1z
^^fd2t1^^b3
^^fd2n1^^b3
^^fd2d1^^b3
r2t1^^b3
^^fd2p1^^b3
l2p1^^b3
l2t1^^b3
g2t1^^b3
n2t1^^b3
r2k1^^b3
r2p1^^b3
k2t1^^b3
r2h1^^b3
s2t1^^b3
l2k1^^b3
w2p1^^b3
n2s1^^b3
r2s1^^b3
l2m1^^b3
s2k1d
l1s2k
l1s2t
s1t2r
n2g1l
n1g2r
s2k1w
}
\egroup

