## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Hsb_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Hsb_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Hsb_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-hsb.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: uppersorbian (hsb)
% encoding: ec
%
% This file has been auto-generated from hyph-hsb.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"F3="F3
\lccode"A2="A2
\lccode"A3="A3
\lccode"A5="A5
\lccode"AA="AA
\lccode"AB="AB
\lccode"B0="B0
\lccode"B2="B2
\lccode"B9="B9
\lccode"BA="BA
\patterns{
8^^a5
8^^ab5
^^ab6^^a33
^^ab7^^a34a
^^ab7^^a34e
^^ab7^^a34i
^^ab7^^a34u
^^ab7^^a34o
8^^f3
3^^b22^^a2
8^^b9
1k8^^b08
1p8^^b08
1t8^^b08
a3b2a
a3b2e
a3b2^^a5
a3b2i
a3b2o
a3b2u
a3b2y
a3b2j
a3b2r
a3b2l
a3b2^^aa
a3c2a
a3c2e
a3c2o
a3c2u
a3c2y
a3c2i
a3ch2a
a3ch2e
a3ch2o
a3ch2u
a3ch2y
a3ch2i
a3^^a22a
a3^^a22e
a3^^a22i
a3^^a22o
a3^^a22u
a3^^a32a
a3^^a32e
a3^^a32^^a5
a3^^a32i
a3^^a32o
a3^^a32u
a3d2a
a3d2e
a3d2i
a3d2o
a3d2u
a3d2y
a3d2^^b92a
a3d2^^b92e
a3d2^^b92^^a5
a3d2^^b92i
a3d2^^b92o
a3d2^^b92u
a3d2^^b92y
a3dl2
a3dr2
a3f2a
a3f2e
a3f2y
a3f2o
a3f2u
a3f2i
a3f2l
a3f2r2
a1g2r2
a1g2l2
a1g2a
a1g2e
a1g2^^a5
a1g2o
a1g2u
a1g2i
a1h2a
a1h2e
a1h2^^a5
a1h2o
a1h2u
a1h2i
aj1
a1j2a
a1j2e
a1j2^^a5
a1j2i
a1j2o
a1j2u
a1k2a
a1k2e
a1k2i
a1k2u
a1k2o
a1k2r
a1k2l
a3^^aa2a
a3^^aa2e
a3^^aa2o
a3^^aa2u
a3^^aa2y
a^^aa1
a3l2a
a3l2e
a3l2^^a5
a3l2o
a3l2u
a3l2i
a3l2y
a3m2a
a3m2o
a3m2u
a3m2i
a3m2e
a3m2^^a5
a3m2y
a3m2j
a3n2a
a3n2e
a3n2^^a5
a3n2i
a3n2o
a3n2u
a3n2y
a3n2j
a3p2a
a3p2e
a3p2^^a5
a3p2i
a3p2o
a3p2u
a3p2y
a3p2j
a3p2l
a3p2r
a3r2a
a3r2e
a3r2^^a5
a3r2i
a3r2o
a3r2u
a3r2y
a3r2j
a3s2a
a3s2e
a3s2i
a3s2o
a3s2u
a3s2y
as1pek1t
a3s2t
a3^^b22a
a3^^b22e
a3^^b22^^a5
a3^^b22i
a3^^b22o
a3^^b22u
a3^^b22y
a3^^b22tap
a^^b21
a3t2a
a3t2e
a3t2i
a3t2o
a3t2u
a3t2y
a3t2r
a3t2l
a3w2a
a3w2e
a3w2^^a5
a3w2i
a2w1n
a3w2o
a3w2u
a3w2y
a3w2j
a3z2a
a3z2e
a3z2^^a5
a3z2i
a3z2o
a3z2u
a3z2y
a3^^ba2a
a3^^ba2e
a3^^ba2^^a5
a3^^ba2i
a3^^ba2o
a3^^ba2u
a2^^ba1
e3b2a
e3b2e
e3b2i
e3b2o
e3b2u
e3b2y
e3b2j
e3b2r
e3b2^^aa
e3b2l
e3c2a
e3c2e
e3c2o
e3c2u
e3c2y
e3c2i
e3ch2a
e3ch2e
e3ch2o
e3ch2u
e3ch2i
e3^^a22a
e3^^a22e
e3^^a22i
e3^^a22o
e3^^a22u
e3^^a32a
e3^^a32e
e3^^a32i
e3^^a32o
e3^^a32u
e3d2a
e3d2e
e3d2i
e3d2o
e3d2u
e3d2y
e3d2^^b92a
e3d2^^b92e
e3d2^^b92i
e3d2^^b92o
e3d2^^b92u
e3d2^^b92y
e3dl2
e3dr2
e3f2a
e3f2e
e3f2y
e3f2o
e3f2u
e3f2i
e3f2l
e3f2r2
e1g2r2
e1g2l2
e1g2a
e1g2e
e1g2o
e1g2u
e1g2i
e1h2a
e1h2o
e1h2u
e1h2i
ej1
e1j2a
e1j2e
e1j2i
e1j2o
e1j2u
e1k2a
e1k2e
e1k2i
e1k2u
e1k2o
e1k2r
e1k2l
e1^^aa2a
e1^^aa2e
e1^^aa2o
e1^^aa2u
e1^^aa2y
e^^aa1
e1l2a
e1l2e
e1l2o
e1l2u
e1l2i
e3m2a
e3m2o
e3m2u
e3m2i
e3m2e
e3m2y
e3m2j
e3n2a
e3n2e
e3n2i
e3n2o
e3n2u
e3n2y
e3n2j
e3p2a
e3p2e
e3p2i
e3p2o
e3p2u
e3p2y
e3p2j
e3p2l
e3p2r
e3r2a
e3r2e
e3r2i
e3r2o
e3r2u
e3r2y
e3r2j
er2b1s2k
e3s2a
e3s2e
e3s2i
e3s2o
e3s2u
e3s2y
e3s2t
e3^^b22a
e3^^b22e
e3^^b22i
e3^^b22o
e3^^b22u
e3^^b22y
e3^^b22tap
e^^b21
e3t2a
e3t2e
e3t2i
e3t2o
e3t2u
e3t2y
e3t2r
e3t2l
e3w2a
e3w2e
e3w2i
e3w2o
e3w2u
e3w2y
e3w2j
e3z2a
e3z2e
e3z2i
e3z2o
e3z2u
e3z2y
e3^^ba2a
e3^^ba2e
e3^^ba2i
e3^^ba2o
e3^^ba2u
e2^^ba1
^^a53b2a
^^a53b2e
^^a53b2i
^^a53b2o
^^a53b2u
^^a53b2y
^^a53b2j
^^a53b2r
^^a53b2l
^^a53c2a
^^a53c2e
^^a53c2o
^^a53c2u
^^a53c2y
^^a53ch2a
^^a53ch2e
^^a53ch2o
^^a53ch2u
^^a53ch2i
^^a53^^a22a
^^a53^^a22e
^^a53^^a22i
^^a53^^a22o
^^a53^^a22u
^^a53^^a32a
^^a53^^a32e
^^a53^^a32i
^^a53^^a32o
^^a53^^a32u
^^a53d2a
^^a53d2e
^^a53d2i
^^a53d2o
^^a53d2u
^^a53d2y
^^a53d2^^b92a
^^a53d2^^b92e
^^a53d2^^b92i
^^a53d2^^b92o
^^a53d2^^b92u
^^a53d2^^b92y
^^a53dl2
^^a53dr2
^^a53f2a
^^a53f2e
^^a53f2y
^^a53f2o
^^a53f2u
^^a53f2i
^^a53f2l
^^a53f2r2
^^a51g2r2
^^a51g2l2
^^a51g2a
^^a51g2e
^^a51g2o
^^a51g2u
^^a51g2i
^^a51h2a
^^a51h2o
^^a51h2u
^^a51h2i
^^a5j1
^^a51j2a
^^a51j2e
^^a51j2i
^^a51j2o
^^a51j2u
^^a51k2a
^^a51k2e
^^a51k2i
^^a51k2u
^^a51k2o
^^a51k2r
^^a51k2l
^^a51^^aa2a
^^a51^^aa2e
^^a51^^aa2o
^^a51^^aa2u
^^a51^^aa2y
^^a51l2a
^^a51l2e
^^a51l2o
^^a51l2u
^^a51l2i
^^a53m2a
^^a53m2o
^^a53m2u
^^a53m2i
^^a53m2e
^^a53m2y
^^a53m2j
^^a53n2a
^^a53n2e
^^a53n2i
^^a53n2o
^^a53n2u
^^a53n2y
^^a53n2j
^^a53p2a
^^a53p2e
^^a53p2i
^^a53p2o
^^a53p2u
^^a53p2y
^^a53p2j
^^a53p2l
^^a53p2r
^^a53r2a
^^a53r2e
^^a53r2i
^^a53r2o
^^a53r2u
^^a53r2y
^^a53r2j
^^a53s2a
^^a53s2e
^^a53s2i
^^a53s2o
^^a53s2u
^^a53s2y
^^a53s2t
^^a53^^b22a
^^a53^^b22e
^^a53^^b22i
^^a53^^b22o
^^a53^^b22u
^^a53^^b22y
^^a53^^b22tap
^^a5^^b21
^^a53t2a
^^a53t2e
^^a53t2i
^^a53t2o
^^a53t2u
^^a53t2y
^^a53t2r
^^a53t2l
^^a53w2a
^^a53w2e
^^a53w2i
^^a53w2o
^^a53w2u
^^a53w2y
^^a53w2j
^^a53z2a
^^a53z2e
^^a53z2i
^^a53z2o
^^a53z2u
^^a53z2y
^^a53^^ba2a
^^a53^^ba2e
^^a53^^ba2i
^^a53^^ba2o
^^a53^^ba2u
^^a52^^ba1
i3b2a
i3b2e
i3b2i
i3b2o
i3b2u
i3b2y
i3b2j
i3b2r
i3b2l
i3c2a
i3c2e
i3c2o
i3c2u
i3c2y
i3c2i
i3ch2a
i3ch2e
i3ch2o
i3ch2u
i3ch2i
i3^^a22a
i3^^a22e
i3^^a22i
i3^^a22o
i3^^a22u
i3^^a32a
i3^^a32e
i3^^a32i
i3^^a32o
i3^^a32u
i3d2a
i3d2e
i3d2i
i3d2o
i3d2u
i3d2y
i3d2^^b92a
i3d2^^b92e
i3d2^^b92i
i3d2^^b92o
i3d2^^b92u
i3d2^^b92y
i3dl2
i3dr2
i3f2a
i3f2e
i3f2y
i3f2o
i3f2u
i3f2i
i3f2l
i3f2r2
i1g2r2
i1g2l2
i1g2a
i1g2e
i1g2o
i1g2u
i1g2i
i1h2a
i1h2o
i1h2u
i1h2i
ij1
i1j2a
i1j2e
i1j2i
i1j2o
i1j2u
i1k2a
i1k2e
i1k2i
i1k2u
i1k2o
i1k2r
i1k2l
i1^^aa2a
i1^^aa2e
i1^^aa2o
i1^^aa2u
i1^^aa2y
i^^aa1
i1l2a
i1l2e
i1l2o
i1l2u
i1l2i
i3m2a
i3m2o
i3m2u
i3m2i
i3m2e
i3m2y
i3m2j
i3n2a
i3n2e
i3n2i
i3n2o
i3n2u
i3n2y
i3n2j
i3p2a
i3p2e
i3p2i
i3p2o
i3p2u
i3p2y
i3p2j
i3p2l
i3p2r
i3r2a
i3r2e
i3r2i
i3r2o
i3r2u
i3r2y
i3r2j
i3s2a
i3s2e
i3s2i
i3s2o
i3s2u
i3s2y
i3s2t
i3^^b22a
i3^^b22e
i3^^b22i
i3^^b22o
i3^^b22u
i3^^b22y
i3^^b22tap
i^^b21
i3t2a
i3t2e
i3t2i
i3t2o
i3t2u
i3t2y
i3t2r
i3t2l
i3w2a
i3w2e
i3w2i
i3w2o
i2w1n
i3w2u
i3w2y
i3w2j
i3z2a
i3z2e
i3z2i
i3z2o
i3z2u
i3z2y
i3^^ba2a
i3^^ba2e
i3^^ba2i
i3^^ba2o
i3^^ba2u
i2^^ba1
o3b2a
o3b2e
o3b2i
o3b2o
o3b2u
o3b2y
o3b2j
o3b2r
o3b2l
o3c2a
o3c2e
o3c2o
o3c2u
o3c2y
o3ch2a
o3ch2e
o3ch2o
o3ch2u
o3ch2i
o3^^a22a
o3^^a22e
o3^^a22i
o3^^a22o
o3^^a22u
o3^^a32a
o3^^a32e
o3^^a32i
o3^^a32o
o3^^a32u
o3d2a
o3d2e
o3d2i
o3d2o
o3d2u
o3d2y
o3d2^^b92a
o3d2^^b92e
o3d2^^b92i
o3d2^^b92o
o3d2^^b92u
o3d2^^b92y
o3dl2
o3dr2
o3f2a
o3f2e
o3f2y
o3f2o
o3f2u
o3f2i
o3f2l
o3f2r2
o1g2r2
o1g2l2
o1g2a
o1g2e
o1g2o
o1g2u
o1g2i
o1h2a
o1h2o
o1h2u
o1h2i
oj1
o1j2a
o1j2e
o1j2i
o1j2o
o1j2u
o1k2a
o1k2e
o1k2i
o1k2u
o1k2o
o1k2r
o1k2l
o1k2^^aa
o1^^aa2a
o1^^aa2e
o1^^aa2o
o1^^aa2u
o1^^aa2y
o^^aa1
o1l2a
o1l2e
o1l2o
o1l2u
o1l2i
o3m2a
o3m2o
o3m2u
o3m2i
o3m2e
o3m2^^a5
o3m2y
o3m2j
o3n2a
o3n2e
o3n2i
o3n2o
o3n2u
o3n2y
o3n2j
o3p2a
o3p2e
o3p2i
o3p2o
o3p2u
o3p2y
o3p2j
o3p2l
o3p2r
o3r2a
o3r2e
o3r2i
o3r2o
o3r2u
o3r2y
o3r2j
o3s2a
o3s2e
o3s2i
o3s2o
o3s2u
o3s2y
o3sled1
o3s2t
o3^^b22a
o3^^b22e
o3^^b22i
o3^^b22o
o3^^b22u
o3^^b22y
o3^^b22tap
o^^b21
o3t2a
o3t2e
o3t2i
o3t2o
o3t2u
o3t2y
o3t2r
o3t2l
o3w2a
o3w2e
o3w2^^a5
o3w2i
o2w1n
o3w2o
o3w2u
o3w2y
o3w2j
o3z2a
o3z2e
o3z2i
o3z2o
o3z2u
o3z2y
o3^^ba2a
o3^^ba2e
o3^^ba2i
o3^^ba2o
o3^^ba2u
o2^^ba1
^^f33b2a
^^f33b2e
^^f33b2i
^^f33b2o
^^f33b2u
^^f33b2y
^^f33b2j
^^f33b2r
^^f33b2l
^^f33c2a
^^f33c2e
^^f33c2o
^^f33c2u
^^f33c2y
^^f33ch2a
^^f33ch2e
^^f33ch2o
^^f33ch2u
^^f33ch2i
^^f33^^a22a
^^f33^^a22e
^^f33^^a22i
^^f33^^a22o
^^f33^^a22u
^^f33^^a32a
^^f33^^a32e
^^f33^^a32i
^^f33^^a32o
^^f33^^a32u
^^f33d2a
^^f33d2e
^^f33d2i
^^f33d2o
^^f33d2u
^^f33d2y
^^f33d2^^b92a
^^f33d2^^b92e
^^f33d2^^b92i
^^f33d2^^b92o
^^f33d2^^b92u
^^f33d2^^b92y
^^f33dl2
^^f33dr2
^^f33f2a
^^f33f2e
^^f33f2y
^^f33f2o
^^f33f2u
^^f33f2i
^^f33f2l
^^f33f2r2
^^f31g2r2
^^f31g2l2
^^f31g2a
^^f31g2e
^^f31g2o
^^f31g2u
^^f31g2i
^^f31h2a
^^f31h2o
^^f31h2u
^^f31h2i
^^f3j1
^^f31j2a
^^f31j2e
^^f31j2i
^^f31j2o
^^f31j2u
^^f31k2a
^^f31k2e
^^f31k2i
^^f31k2u
^^f31k2o
^^f31k2r
^^f31k2l
^^f31^^aa2a
^^f31^^aa2e
^^f31^^aa2o
^^f31^^aa2u
^^f31^^aa2y
^^f3^^aa1
^^f31l2a
^^f31l2e
^^f31l2o
^^f31l2u
^^f31l2i
^^f33m2a
^^f33m2o
^^f33m2u
^^f33m2i
^^f33m2e
^^f33m2y
^^f33m2j
^^f33n2a
^^f33n2e
^^f33n2i
^^f33n2o
^^f33n2u
^^f33n2y
^^f33n2j
^^f33p2a
^^f33p2e
^^f33p2i
^^f33p2o
^^f33p2u
^^f33p2y
^^f33p2j
^^f33p2l
^^f33p2r
^^f33r2a
^^f33r2e
^^f33r2i
^^f33r2o
^^f33r2u
^^f33r2y
^^f33r2j
^^f33s2a
^^f33s2e
^^f33s2i
^^f33s2o
^^f33s2u
^^f33s2y
^^f33s2t
^^f33^^b22a
^^f33^^b22e
^^f33^^b22i
^^f33^^b22o
^^f33^^b22u
^^f33^^b22y
^^f33^^b22tap
^^f3^^b21
^^f33t2a
^^f33t2e
^^f33t2i
^^f33t2o
^^f33t2u
^^f33t2y
^^f33t2r
^^f33t2l
^^f33w2a
^^f33w2e
^^f33w2i
^^f33w2o
^^f33w2u
^^f33w2y
^^f33w2j
^^f33z2a
^^f33z2e
^^f33z2i
^^f33z2o
^^f33z2u
^^f33z2y
^^f33^^ba2a
^^f33^^ba2e
^^f33^^ba2i
^^f33^^ba2o
^^f33^^ba2u
^^f32^^ba1
u3b2a
u3b2e
u3b2i
u3b2o
u3b2u
u3b2y
u3b2j
u3b2r
u3b2l
u3c2a
u3c2e
u3c2o
u3c2u
u3c2y
u3c2i
u3ch2a
u3ch2e
u3ch2o
u3ch2u
u3ch2i
u3^^a22a
u3^^a22e
u3^^a22i
u3^^a22o
u3^^a22u
u3^^a32a
u3^^a32e
u3^^a32i
u3^^a32o
u3^^a32u
u3d2a
u3d2e
u3d2i
u3d2o
u3d2u
u3d2y
u3d2^^b92a
u3d2^^b92e
u3d2^^b92i
u3d2^^b92o
u3d2^^b92u
u3d2^^b92y
u3dl2
u3dr2
u3f2a
u3f2e
u3f2y
u3f2o
u3f2u
u3f2i
u3f2l
u3f2r2
u1g2r2
u1g2l2
u1g2a
u1g2e
u1g2o
u1g2u
u1g2i
u1h2a
u1h2o
u1h2u
u1h2i
uj1
u1j2a
u1j2e
u1j2i
u1j2o
u1j2u
u1k2a
u1k2e
u1k2i
u1k2u
u1k2o
u1k2r
u1k2l
u1^^aa2a
u1^^aa2e
u1^^aa2o
u1^^aa2u
u1^^aa2y
u^^aa1
u1l2a
u1l2e
u1l2o
u1l2u
u1l2i
u3m2a
u3m2o
u3m2u
u3m2i
u3m2e
u3m2y
u3m2j
u3n2a
u3n2e
u3n2i
u3n2o
u3n2u
u3n2y
u3n2j
u3p2a
u3p2e
u3p2i
u3p2o
u3p2u
u3p2y
u3p2j
u3p2l
u3p2r
u3r2a
u3r2e
u3r2i
u3r2o
u3r2u
u3r2y
u3r2j
u3s2a
u3s2e
u3s2i
u3s2o
u3s2u
u3s2y
u3s2t
u3^^b22a
u3^^b22e
u3^^b22i
u3^^b22o
u3^^b22u
u3^^b22y
u3^^b22tap
u^^b21
u3t2a
u3t2e
u3t2i
u3t2o
u3t2u
u3t2y
u3t2r
u3t2l
u3w2a
u3w2e
u3w2i
u2w1n
u3w2o
u3w2u
u3w2y
u3w2j
u3z2a
u3z2e
u3z2i
u3z2o
u3z2u
u3z2y
u3^^ba2a
u3^^ba2e
u3^^ba2i
u3^^ba2o
u3^^ba2u
u2^^ba1
y3b2a
y3b2e
y3b2i
y3b2o
y3b2u
y3b2y
y3b2j
y3b2r
y3b2l
y3c2a
y3c2e
y3c2o
y3c2u
y3c2y
y3^^a22a
y3^^a22e
y3^^a22i
y3^^a22o
y3^^a22u
y3^^a32a
y3^^a32e
y3^^a32i
y3^^a32o
y3^^a32u
y3d2a
y3d2e
y3d2i
y3d2o
y3d2u
y3d2y
y3d2^^b92a
y3d2^^b92e
y3d2^^b92i
y3d2^^b92o
y3d2^^b92u
y3d2^^b92y
y3dl2
y3dr2
y3f2a
y3f2e
y3f2y
y3f2o
y3f2u
y3f2i
y3f2l
y3f2r2
y1g2r2
y1g2l2
y1g2a
y1g2e
y1g2o
y1g2u
y1g2i
y1h2a
y1h2o
y1h2u
y1h2i
yj1
y1j2a
y1j2e
y1j2i
y1j2o
y1j2u
y1k2a
y1k2e
y1k2i
y1k2u
y1k2o
y1k2r
y1k2l
y1^^aa2a
y1^^aa2e
y1^^aa2o
y1^^aa2u
y1^^aa2y
y^^aa1
y1l2a
y1l2e
y1l2o
y1l2u
y1l2i
y3m2a
y3m2o
y3m2u
y3m2i
y3m2e
y3m2y
y3m2j
y3n2a
y3n2e
y3n2i
y3n2o
y3n2u
y3n2y
y3n2j
y3p2a
y3p2e
y3p2i
y3p2o
y3p2u
y3p2y
y3p2j
y3p2l
y3p2r
y3r2a
y3r2e
y3r2i
y3r2o
y3r2u
y3r2y
y3r2j
y3s2a
y3s2e
y3s2i
y3s2o
y3s2u
y3s2y
y3s2t
y3^^b22a
y3^^b22e
y3^^b22i
y3^^b22o
y3^^b22u
y3^^b22y
y3^^b22tap
y^^b21
y3t2a
y3t2e
y3t2i
y3t2o
y3t2u
y3t2y
y3t2r
y3t2l
y3w2a
y3w2e
y3w2i
y3w2o
y3w2u
y3w2y
y3w2j
y3z2a
y3z2e
y3z2i
y3z2o
y3z2u
y3z2y
y3^^ba2a
y3^^ba2e
y3^^ba2i
y3^^ba2o
y3^^ba2u
y2^^ba1
.a8b7itu1r
.a8b7itu8r1n
b1b
b1ce
b1cy
b1^^a2
b1^^a3
b1d
.bjez1
.bje1z2e
b2j
b1h
b1k
b1m
b1n
b1p
b1s
b1t
b1w
b1z
b1^^ba
1ca
1ce
1co
1cu
c2h
.ch2c
ch1^^a2
ch1n
^^a31n
d1bpo4d3
4de^^ab
d1n
o^^aa1d2nj
do1s1po
do1z2na
do2z3na.
nje1do3z4na.
im1ple
1h2d
1h2lad
2h1ny
2h1nu.
2h1nje
1h2romad
.nje1z2hromad
1ka
k1c
1ku
1ki
k1n
k2nys1k
1ko
ko8n7ju3g
ko8n7jun8k1
ko8n7urb
k1s
k1t
k2tu.
kuz1^^aa
kuz1l
2k2st.
3^^aa2ha
.bo4^^aa3h
.do4^^aa3h
.do4^^aa3ho3
.po4^^aa3h
l1n
3^^aa2^^ba
.do4^^aa^^ba1n
.po4^^aa3^^ba
l1g
l1z
m1n
3m2ru.
3m2rje
3m2r^^a5
m1s
mys1l
na1
.na4d1
.nje1na4d1
.na4d2e^^ab
.nje1na4d2e^^ab
.na4d2e^^b2
.nje1na4d2e^^b2
2n1d
1ni.
n4j
1nja.
1nje.
.nje1
n1t
n2t1n
nuh1l
p4j
po1
po4d3
po4d4e1
po2m1h
po2m^^ab
praw1
p^^b0e1
p^^b0e4d3
p^^b0e5d4a
p^^b0e5d4o
p^^b0e5d4i
p^^b0e5d4u
p^^b0e5d4rast
p^^b0e5d4ras^^a2
p^^b0e4d4e3
r1b
ser2b1
ser3b2a
ser3b2e
ser3b2o
ser3b2i
ser3b2y
r1^^a2
r1^^a3
r1d
r1f
r2d^^b9.
r4j
r1m
r1n
r1p
r1w
ro2z1
ro2z2e1
s1^^a2
si1gna1l
m2la2s3ka
z1mor3s3ka
pra2s3ka
plu2s3ka
^^a2i2s3ka
wrje2s3ka
1s2k2i.
1s2k2a.
1s2k2e.
1s2k2eho.
1s2k2eje.
1s2k2ej.
1s2k2aj.
1s2k2emu.
1s2k2u.
1s2k2im.
1s2k2imaj.
1s2k2eju.
1s2k2imi.
1s2k2i2ch.
1s2c2y.
1s2c2e.
s1n
s2tat1n
4st1n
2n1stw
1^^b22to.
1^^b22li.
1^^b22^^aae.
1^^b22^^aaa.
1^^b22^^aaoj.
1^^b22o^^aa.
1^^b22^^aaaj.
1^^b22^^aaej.
^^b21
1^^b28a
1^^b28e
1^^b28^^a5
1^^b28i
1^^b28o
1^^b28u
a2^^b21nj
t1d
t1k
^^a52t3n
t1m
t1n
t1p
w4j
.wje1le3
w4n1st
.wo4b2e
wo4b3jas1n
wo4b3je^^a2
wo4b3jed1n
wo4b3j^^a5
wo4b3jim
.nje1wo4b2e1
.wo4te3
.njewo4te3
wo1zna
.wu1
wu1s2nu
wu1s2n2j2e
wu1s2ny
.za1
.za2^^ab
.za2w1k
.za2w3da
ze1z2na
z1nak
iz1na.
iz1ny.
iz1nu.
iz1nje.
iz1no
2z1p
2z1s
}
\hyphenation{
War-sza-wa
do-zna
njej-sym
njej-sy
nje-je
njej-sm^^f3j
njej-staj
njej-stej
njej-smy
njej-s^^a2e
njej-su
p^^b9ede
p^^b9e-derje
tkalc
nje^^abd^^b9
ze-tnu
ze-tnje^^b2
ze-tnje
ze-tnje-m^^f3j
ze-tnje-taj
ze-tnje-tej
ze-tnje-my
ze-tnje-^^a2e
wote-tnu
wote-tnje^^b2
wote-tnje
wote-tnje-m^^f3j
wote-tnje-taj
wote-tnje-tej
wote-tnje-my
wote-tnje-^^a2e
wo-dnjo
wo-snje
tak-rjec
}
\egroup

