## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Sh_latn_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Sh_latn_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Sh_latn_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-sh-latn.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: serbian (sh-latn)
% encoding: ec
%
% This file has been auto-generated from hyph-sh-latn.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"A2="A2
\lccode"A3="A3
\lccode"9E="9E
\lccode"B2="B2
\lccode"BA="BA
\patterns{
t2j
t2l
t2lj
t2r
t2v
d2j
d2l
d2lj
d2r
d2v
g2j
g2l
g2lj
g2r
g2v
h2j
h2l
h2lj
h2r
h2v
k2j
k2l
k2lj
k2r
k2v
2d1b
2d1c
2d1d
2d1f
2d1g
2d1h
2d1k
2d1m
2d1n
2d1p
2d1s
2d1t
2d1nj
2d1d^^ba
2d1z
2d1^^b2
2d1^^9e
2d1^^a2
2d1^^a3
2g1^^ba
2g1b
2g1c
2g1d
2g1f
2g1g
2g1h
2g1k
2g1m
2g1n
2g1p
2g1s
2g1t
2g1nj
2g1d^^ba
2g1z
2g1^^b2
2g1^^9e
2g1^^a2
2g1^^a3
2h1^^ba
2h1b
2h1c
2h1d
2h1f
2h1g
2h1h
2h1k
2h1m
2h1n
2h1p
2h1s
2h1t
2h1nj
2h1d^^ba
2h1z
2h1^^b2
2h1^^9e
2h1^^a2
2h1^^a3
2k1^^ba
2k1b
2k1c
2k1d
2k1f
2k1g
2k1h
2k1k
2k1m
2k1n
2k1p
2k1s
2k1t
2k1nj
2k1d^^ba
2k1z
2k1^^b2
2k1^^9e
2k1^^a2
2k1^^a3
2t1^^ba
2t1b
2t1c
2t1d
2t1f
2t1g
2t1h
2t1k
2t1m
2t1n
2t1p
2t1s
2t1t
2t1nj
2t1d^^ba
2t1z
2t1^^b2
2t1^^9e
2t1^^a2
2t1^^a3
2dj.
2dl.
2dlj.
2dr.
2dv.
2gj.
2gl.
2glj.
2gr.
2gv.
2hj.
2hl.
2hlj.
2hr.
2hv.
2kj.
2kl.
2klj.
2kr.
2kv.
2tj.
2tl.
2tlj.
2tr.
2tv.
p2j
p2l
p2lj
p2r
v2j
v2l
v2lj
v2r
b2j
b2l
b2lj
b2r
f2j
f2l
f2lj
f2r
m2j
m2l
m2lj
m2r
2b1^^ba
2b1b
2b1c
2b1d
2b1f
2b1g
2b1h
2b1k
2b1m
2b1n
2b1p
2b1s
2b1t
2b1v
2b1nj
2b1d^^ba
2b1z
2b1^^b2
2b1^^9e
2b1^^a2
2b1^^a3
2f1^^ba
2f1b
2f1c
2f1d
2f1f
2f1g
2f1h
2f1k
2f1m
2f1n
2f1p
2f1s
2f1t
2f1v
2f1nj
2f1d^^ba
2f1z
2f1^^b2
2f1^^9e
2f1^^a2
2f1^^a3
2m1^^ba
2m1b
2m1c
2m1d
2m1f
2m1g
2m1h
2m1k
2m1m
2m1n
2m1p
2m1s
2m1t
2m1v
2m1nj
2m1d^^ba
2m1z
2m1^^b2
2m1^^9e
2m1^^a2
2m1^^a3
2p1^^ba
2p1b
2p1c
2p1d
2p1f
2p1g
2p1h
2p1k
2p1m
2p1n
2p1p
2p1s
2p1t
2p1v
2p1nj
2p1d^^ba
2p1z
2p1^^b2
2p1^^9e
2p1^^a2
2p1^^a3
2v1^^ba
2v1b
2v1c
2v1d
2v1f
2v1g
2v1h
2v1k
2v1m
2v1n
2v1p
2v1s
2v1t
2v1v
2v1nj
2v1d^^ba
2v1z
2v1^^b2
2v1^^9e
2v1^^a2
2v1^^a3
2bj.
2bl.
2blj.
2br.
2fj.
2fl.
2flj.
2fr.
2mj.
2ml.
2mlj.
2mr.
2pj.
2pl.
2plj.
2pr.
2vj.
2vl.
2vlj.
2vr.
s2c
s2j
s2k
s2l
s2m
s2n
s2p
s2lj
s2r
s2t
s2v
s2nj
2s1^^ba
2s1b
2s1d
2s1f
2s1g
2s1h
2s1s
2s1d^^ba
2s1z
2s1^^b2
2s1^^9e
2s1^^a2
2s1^^a3
2sj.
2sk.
2sl.
2sm.
2sn.
2sp.
2slj.
2sr.
2st.
2sv.
2snj.
2sc.
z2b
z2d
z2g
z2j
z2l
z2m
z2n
z2lj
z2r
z2v
z2nj
2z1^^ba
2z1c
2z1f
2z1h
2z1k
2z1p
2z1s
2z1t
2z1d^^ba
2z1z
2z1^^b2
2z1^^9e
2z1^^a2
2z1^^a3
2zj.
2zl.
2zm.
2zn.
2zlj.
2zr.
2zv.
2znj.
2zb.
2zd.
2zg.
^^b22c
^^b22k
^^b22l
^^b22m
^^b22n
^^b22p
^^b22lj
^^b22t
^^b22v
^^b22nj
^^b22^^a2
^^b22^^a3
2^^b21^^ba
2^^b21b
2^^b21d
2^^b21f
2^^b21g
2^^b21h
2^^b21s
2^^b21d^^ba
2^^b21z
2^^b21^^b2
2^^b21^^9e
2^^b21j
2^^b21r
2^^b2k.
2^^b2l.
2^^b2m.
2^^b2n.
2^^b2p.
2^^b2lj.
2^^b2t.
2^^b2v.
2^^b2nj.
2^^b2^^a2.
2^^b2^^a3.
2^^b2c.
^^ba2b
^^ba2d
^^ba2g
^^ba2l
^^ba2m
^^ba2n
^^ba2lj
^^ba2v
^^ba2nj
^^ba2^^9e
2^^ba1^^ba
2^^ba1c
2^^ba1f
2^^ba1h
2^^ba1k
2^^ba1p
2^^ba1s
2^^ba1t
2^^ba1d^^ba
2^^ba1z
2^^ba1^^b2
2^^ba1^^a2
2^^ba1^^a3
2^^ba1j
2^^ba1r
2^^bal.
2^^bam.
2^^ban.
2^^balj.
2^^bav.
2^^banj.
2^^ba^^9e.
2^^bab.
2^^bad.
2^^bag.
c2j
c2r
c2v
2c1^^ba
2c1b
2c1c
2c1d
2c1f
2c1g
2c1h
2c1k
2c1l
2c1m
2c1n
2c1p
2c1lj
2c1s
2c1t
2c1nj
2c1d^^ba
2c1z
2c1^^b2
2c1^^9e
2c1^^a2
2c1^^a3
2cj.
2cr.
2cv.
^^a32v
2^^a31^^ba
2^^a31b
2^^a31c
2^^a31d
2^^a31f
2^^a31g
2^^a31h
2^^a31j
2^^a31k
2^^a31l
2^^a31m
2^^a31n
2^^a31p
2^^a31lj
2^^a31r
2^^a31s
2^^a31t
2^^a31nj
2^^a31d^^ba
2^^a31z
2^^a31^^b2
2^^a31^^9e
2^^a31^^a2
2^^a31^^a3
2^^a3v.
2j1^^ba
2j1b
2j1c
2j1d
2j1f
2j1g
2j1h
2j1j
2j1k
2j1l
2j1m
2j1n
2j1p
2j1lj
2j1r
2j1s
2j1t
2j1v
2j1nj
2j1d^^ba
2j1z
2j1^^b2
2j1^^9e
2j1^^a2
2j1^^a3
2l1^^ba
2l1b
2l1c
2l1d
2l1f
2l1g
2l1h
2l1k
2l1l
2l1m
2l1n
2l1p
2l1lj
2l1r
2l1s
2l1t
2l1v
2l1nj
2l1d^^ba
2l1z
2l1^^b2
2l1^^9e
2l1^^a2
2l1^^a3
2n1^^ba
2n1b
2n1c
2n1d
2n1f
2n1g
2n1h
2n1k
2n1l
2n1m
2n1n
2n1p
2n1lj
2n1r
2n1s
2n1t
2n1v
2n1nj
2n1d^^ba
2n1z
2n1^^b2
2n1^^9e
2n1^^a2
2n1^^a3
2lj1^^ba
2lj1b
2lj1c
2lj1d
2lj1f
2lj1g
2lj1h
2lj1j
2lj1k
2lj1l
2lj1m
2lj1n
2lj1p
2lj1lj
2lj1r
2lj1s
2lj1t
2lj1v
2lj1nj
2lj1d^^ba
2lj1z
2lj1^^b2
2lj1^^9e
2lj1^^a2
2lj1^^a3
2r1^^ba
2r1b
2r1c
2r1d
2r1f
2r1g
2r1h
2r1j
2r1k
2r1l
2r1m
2r1n
2r1p
2r1lj
2r1r
2r1s
2r1t
2r1v
2r1nj
2r1d^^ba
2r1z
2r1^^b2
2r1^^9e
2r1^^a2
2r1^^a3
2nj1^^ba
2nj1b
2nj1c
2nj1d
2nj1f
2nj1g
2nj1h
2nj1j
2nj1k
2nj1l
2nj1m
2nj1n
2nj1p
2nj1lj
2nj1r
2nj1s
2nj1t
2nj1v
2nj1nj
2nj1d^^ba
2nj1z
2nj1^^b2
2nj1^^9e
2nj1^^a2
2nj1^^a3
2d^^ba1^^ba
2d^^ba1b
2d^^ba1c
2d^^ba1d
2d^^ba1f
2d^^ba1g
2d^^ba1h
2d^^ba1j
2d^^ba1k
2d^^ba1l
2d^^ba1m
2d^^ba1n
2d^^ba1p
2d^^ba1lj
2d^^ba1r
2d^^ba1s
2d^^ba1t
2d^^ba1v
2d^^ba1nj
2d^^ba1d^^ba
2d^^ba1z
2d^^ba1^^b2
2d^^ba1^^9e
2d^^ba1^^a2
2d^^ba1^^a3
2^^9e1^^ba
2^^9e1b
2^^9e1c
2^^9e1d
2^^9e1f
2^^9e1g
2^^9e1h
2^^9e1j
2^^9e1k
2^^9e1l
2^^9e1m
2^^9e1n
2^^9e1p
2^^9e1lj
2^^9e1r
2^^9e1s
2^^9e1t
2^^9e1v
2^^9e1nj
2^^9e1d^^ba
2^^9e1z
2^^9e1^^b2
2^^9e1^^9e
2^^9e1^^a2
2^^9e1^^a3
2^^a21^^ba
2^^a21b
2^^a21c
2^^a21d
2^^a21f
2^^a21g
2^^a21h
2^^a21j
2^^a21k
2^^a21l
2^^a21m
2^^a21n
2^^a21p
2^^a21lj
2^^a21r
2^^a21s
2^^a21t
2^^a21v
2^^a21nj
2^^a21d^^ba
2^^a21z
2^^a21^^b2
2^^a21^^9e
2^^a21^^a2
2^^a21^^a3
.h2
.j2
.k2
.l2
.m2
.n2
.p2
.lj2
.r2
.s2
.t2
.v2
.nj2
.d^^ba2
.z2
.^^b22
.^^9e2
.^^a22
.^^a32
.^^ba2
.b2
.c2
.d2
.f2
.g2
o3a
o3e
o3i
o3o
o3u
u3a
u3e
u3i
u3o
u3u
a3a
a3e
a3i
a3o
a3u
e3a
e3e
e3i
e3o
e3u
i3a
i3e
i3i
i3o
i3u
2a1
2e1
2i1
2o1
2u1
2skb
2skc
2skd
2skf
2skg
2skh
2skk
2skm
2skn
2skp
2sks
2skt
2sknj
2skd^^ba
2skz
2sk^^b2
2sk^^9e
2sk^^a2
2sk^^a3
2sk^^ba
2stb
2stc
2std
2stf
2stg
2sth
2stk
2stm
2stn
2stp
2sts
2stt
2stnj
2std^^ba
2stz
2st^^b2
2st^^9e
2st^^a2
2st^^a3
2st^^ba
2^^b2kb
2^^b2kc
2^^b2kd
2^^b2kf
2^^b2kg
2^^b2kh
2^^b2kk
2^^b2km
2^^b2kn
2^^b2kp
2^^b2ks
2^^b2kt
2^^b2knj
2^^b2kd^^ba
2^^b2kz
2^^b2k^^b2
2^^b2k^^9e
2^^b2k^^a2
2^^b2k^^a3
2^^b2k^^ba
2^^b2tb
2^^b2tc
2^^b2td
2^^b2tf
2^^b2tg
2^^b2th
2^^b2tk
2^^b2tm
2^^b2tn
2^^b2tp
2^^b2ts
2^^b2tt
2^^b2tnj
2^^b2td^^ba
2^^b2tz
2^^b2t^^b2
2^^b2t^^9e
2^^b2t^^a2
2^^b2t^^a3
2^^b2t^^ba
2spb
2spc
2spd
2spf
2spg
2sph
2spk
2spm
2spn
2spp
2sps
2spt
2spv
2spnj
2spd^^ba
2spz
2sp^^b2
2sp^^9e
2sp^^a2
2sp^^a3
2sp^^ba
2svb
2svc
2svd
2svf
2svg
2svh
2svk
2svm
2svn
2svp
2svs
2svt
2svv
2svnj
2svd^^ba
2svz
2sv^^b2
2sv^^9e
2sv^^a2
2sv^^a3
2sv^^ba
2^^b2pb
2^^b2pc
2^^b2pd
2^^b2pf
2^^b2pg
2^^b2ph
2^^b2pk
2^^b2pm
2^^b2pn
2^^b2pp
2^^b2ps
2^^b2pt
2^^b2pv
2^^b2pnj
2^^b2pd^^ba
2^^b2pz
2^^b2p^^b2
2^^b2p^^9e
2^^b2p^^a2
2^^b2p^^a3
2^^b2p^^ba
2^^b2vb
2^^b2vc
2^^b2vd
2^^b2vf
2^^b2vg
2^^b2vh
2^^b2vk
2^^b2vm
2^^b2vn
2^^b2vp
2^^b2vs
2^^b2vt
2^^b2vv
2^^b2vnj
2^^b2vd^^ba
2^^b2vz
2^^b2v^^b2
2^^b2v^^9e
2^^b2v^^a2
2^^b2v^^a3
2^^b2v^^ba
2^^badb
2^^badc
2^^badd
2^^badf
2^^badg
2^^badh
2^^badk
2^^badm
2^^badn
2^^badp
2^^bads
2^^badt
2^^badnj
2^^badd^^ba
2^^badz
2^^bad^^b2
2^^bad^^9e
2^^bad^^a2
2^^bad^^a3
2^^bagb
2^^bagc
2^^bagd
2^^bagf
2^^bagg
2^^bagh
2^^bagk
2^^bagm
2^^bagn
2^^bagp
2^^bags
2^^bagt
2^^bagnj
2^^bagd^^ba
2^^bagz
2^^bag^^b2
2^^bag^^9e
2^^bag^^a2
2^^bag^^a3
2^^bag^^ba
2zdb
2zdc
2zdd
2zdf
2zdg
2zdh
2zdk
2zdm
2zdn
2zdp
2zds
2zdt
2zdnj
2zdd^^ba
2zdz
2zd^^b2
2zd^^9e
2zd^^a2
2zd^^a3
2zgb
2zgc
2zgd
2zgf
2zgg
2zgh
2zgk
2zgm
2zgn
2zgp
2zgs
2zgt
2zgnj
2zgd^^ba
2zgz
2zg^^b2
2zg^^9e
2zg^^a2
2zg^^a3
2zg^^ba
2^^bavb
2^^bavc
2^^bavd
2^^bavf
2^^bavg
2^^bavh
2^^bavk
2^^bavm
2^^bavn
2^^bavp
2^^bavs
2^^bavt
2^^bavv
2^^bavnj
2^^bavd^^ba
2^^bavz
2^^bav^^b2
2^^bav^^9e
2^^bav^^a2
2^^bav^^a3
2^^bav^^ba
2^^babb
2^^babc
2^^babd
2^^babf
2^^babg
2^^babh
2^^babk
2^^babm
2^^babn
2^^babp
2^^babs
2^^babt
2^^babv
2^^babnj
2^^babd^^ba
2^^babz
2^^bab^^b2
2^^bab^^9e
2^^bab^^a2
2^^bab^^a3
2^^bab^^ba
2zvb
2zvc
2zvd
2zvf
2zvg
2zvh
2zvk
2zvm
2zvn
2zvp
2zvs
2zvt
2zvv
2zvnj
2zvd^^ba
2zvz
2zv^^b2
2zv^^9e
2zv^^a2
2zv^^a3
2zv^^ba
2zbb
2zbc
2zbd
2zbf
2zbg
2zbh
2zbk
2zbm
2zbn
2zbp
2zbs
2zbt
2zbv
2zbnj
2zbd^^ba
2zbz
2zb^^b2
2zb^^9e
2zb^^a2
2zb^^a3
2zb^^ba
2^^bamb
2^^bamc
2^^bamd
2^^bamf
2^^bamg
2^^bamh
2^^bamk
2^^bamm
2^^bamn
2^^bamp
2^^bams
2^^bamt
2^^bamv
2^^bamnj
2^^bamd^^ba
2^^bamz
2^^bam^^b2
2^^bam^^9e
2^^bam^^a2
2^^bam^^a3
2^^bam^^ba
2smb
2smc
2smd
2smf
2smg
2smh
2smk
2smm
2smn
2smp
2sms
2smt
2smv
2smnj
2smd^^ba
2smz
2sm^^b2
2sm^^9e
2sm^^a2
2sm^^a3
2sm^^ba
2zmb
2zmc
2zmd
2zmf
2zmg
2zmh
2zmk
2zmm
2zmn
2zmp
2zms
2zmt
2zmv
2zmnj
2zmd^^ba
2zmz
2zm^^b2
2zm^^9e
2zm^^a2
2zm^^a3
2zm^^ba
2^^b2mb
2^^b2mc
2^^b2md
2^^b2mf
2^^b2mg
2^^b2mh
2^^b2mk
2^^b2mm
2^^b2mn
2^^b2mp
2^^b2ms
2^^b2mt
2^^b2mv
2^^b2mnj
2^^b2md^^ba
2^^b2mz
2^^b2m^^b2
2^^b2m^^9e
2^^b2m^^a2
2^^b2m^^a3
2^^b2m^^ba
2scb
2scc
2scd
2scf
2scg
2sch
2sck
2scl
2scm
2scn
2scp
2sclj
2scr
2scs
2sct
2scnj
2scd^^ba
2scz
2sc^^b2
2sc^^9e
2sc^^a2
2sc^^a3
2sc^^ba
2^^b2cb
2^^b2cc
2^^b2cd
2^^b2cf
2^^b2cg
2^^b2ch
2^^b2ck
2^^b2cl
2^^b2cm
2^^b2cn
2^^b2cp
2^^b2clj
2^^b2cr
2^^b2cs
2^^b2ct
2^^b2cnj
2^^b2cd^^ba
2^^b2cz
2^^b2c^^b2
2^^b2c^^9e
2^^b2c^^a2
2^^b2c^^a3
2^^b2c^^ba
2^^b2^^a3b
2^^b2^^a3c
2^^b2^^a3d
2^^b2^^a3f
2^^b2^^a3g
2^^b2^^a3h
2^^b2^^a3j
2^^b2^^a3k
2^^b2^^a3l
2^^b2^^a3m
2^^b2^^a3n
2^^b2^^a3p
2^^b2^^a3lj
2^^b2^^a3r
2^^b2^^a3s
2^^b2^^a3t
2^^b2^^a3nj
2^^b2^^a3d^^ba
2^^b2^^a3z
2^^b2^^a3^^b2
2^^b2^^a3^^9e
2^^b2^^a3^^a2
2^^b2^^a3^^a3
2^^b2^^a3^^ba
2hvb
2hvc
2hvd
2hvf
2hvg
2hvh
2hvk
2hvm
2hvn
2hvp
2hvs
2hvt
2hvnj
2hvd^^ba
2hvz
2hv^^b2
2hv^^9e
2hv^^a2
2hv^^a3
2hv^^ba
2^^ba3vl
2^^ba3vlj
2c3vl
2c3vlj
2z3vl
2z3vlj
2^^b23vl
2^^b23vlj
2^^a33vl
2^^a33vlj
2^^a33vj
2s3vlj
2d3vl
2d3vlj
2d3vr
2k3vj
2k3vl
2k3vlj
2t3vj
2t3vl
2t3vlj
2g3vj
2g3vl
2g3vlj
2g3vr
2h3vj
2h3vl
2h3vlj
2h3vr
2^^ba3mj
2^^ba3ml
2^^ba3mlj
2^^ba3mr
2z3ml
2z3mr
2^^b23mj
2^^b23ml
2^^b23mlj
2^^b23cj
2^^b23cv
2^^b23^^a3v
2^^b23tj
2^^b23tl
2^^b23tlj
2s3tl
2s3kj
2s3klj
2^^b23pj
2^^b23pl
2^^b23plj
2^^ba3dj
2^^ba3dl
2^^ba3dlj
2^^ba3dv
2^^ba3gj
2^^ba3gl
2^^ba3glj
2^^ba3gr
2^^ba3gv
2z3dl
2z3dlj
2z3dv
2z3gj
2z3glj
2^^ba3bj
2^^ba3bl
2^^ba3blj
2^^ba3br
2z3blj
.a4e2ro
.be4o
.bi4o
.ge4o
.za3g2n
.za3t2ka
.iza3g2n
.iza3t2k
.iz3g2n
.izd2no
.izd2nu
.izd2na
.izr2k
.ist2k
.nag2n
.nag2nj
.na3d2nev
.na3d2ni^^a3
.na3d2nic
.na3t2kah
.na3t2kam
.na3t2kasm
.na3t2kast
.oda3g2n
.oda3d2n
.od3g2n
.od3m2n
.o3t2kah
.o3t2kam
.o3t2kasm
.o3t2kast
.po3g2n
.po3d2nev
.po3m2n
.po3m2nj
.po3r2v
.po3r2^^9e
.po3t2kah
.po3t2kam
.po3t2kat
.po3t2kav
.pred3m2n
.pred3m2nj
.pre3t2kah
.pre3t2kam
.pre3t2kat
.pro3g2n
.pro3t2ki
.pro3t2ka
.raza3g2n
.raz3g2n
.raz3d2ni
.raza3t2ka
.u3g2mi
.u3g2n
.uza3t2ka
3h2teti
3h2tjeti
3h2tel
3h2tev
3h2tenj
3h2tjel
3h2tjev
3h2tjenj
3g2degod.
3g2djegod.
3g2dekak
3g2dekad
3g2djekak
3g2djekad
ni3g2de.
ne3g2de.
ni3g2dje.
ne3g2dje.
3b2det
3b2denj
3b2djet
3b2djenj
3g2mil
3g2milj
3g2miz
3g2nos
3g2noz
3g2noj
3g2naj
3g2nezd
3g2nijezd
3g2ne^^ba^^9e
3g2nije^^ba^^9e
3g2nev
3g2njev
3g2njav
3g2njes
3g2njet
3g2nje^^a3
3g2njil
3g2njio
3g2njilj
3g2njit
3g2njur
3k2nez
3k2ne^^ba
3k2nji^^ba
3k2njig
3m2no^^ba
3m2nog
3m2na^^ba
3p2sik
3p2si^^a3
3p2sov
3p2suj
3r2^^9ea
3s2fer
3t2mast
3t2mul
3t2muo
3t2mulj
3t2mur
3c2miz
3c2mak
3c2ma^^a3
3c2mok
3^^a32lan
3^^a32lanj
3r2je
4r3jem
4r3je.
.be2z3j
.be2z3l
.be2z3m
.be2z3n
.be2z3lj
.be2z3r
.be2z3v
.be2z3nj
.be2z3b
.be2z3d
.be2z3g
.be2z3i
.be2z3o
.be2z3u
.be2z3alkohol
.be2z3atomsk
.be3z4bedn
.be3z4beda
.be3z4bjedn
.be3z4bjeda
.be3z4beli
.be3z4bol
.be3z4vu^^a3n
.be3z4vu^^a3a
.be3z4istan
.be3z4isten
.be3z4jak
.be3z4ja^^a3
.be3z4lobn
.be3z4loba
.be3z4na^^a3aj
.be3z4ra^^a3n
.be3z4ra^^a3a
.be3z4up
.be3z4ub
.be2s3c
.be2s3k
.be2s3p
.be2s3t
.be3s4krupul
.be3s4pokojn
.be3s4pokoja
.be3s4porn
.be3s4pora
.be3s4tvar
.be3s4tid
.be3s4tija
.be3s4tilu
.be3s4tilj
.be3s4trana
.be3s4tras
.bes4tseler
.be2^^b23^^a2
.be2^^b23^^a3
.va2n3evr
.va2n3ustav
.i2z3b
.i2z3d
.i2z3g
.i2z3j
.i2z3l
.i2z3m
.i2z3n
.i2z3lj
.i2z3r
.i2z3v
.i2z3nj
.i2z3i
.i2z3o
.i2z3u
.i2z3bija
.i2z3biva
.i2z3vedi
.i2z3vedn
.i2z3vedb
.i2z3vede
.i2z3daj
.i2z3aba
.i2z3aka
.i2z3anal
.i3z4bav
.i3z4bi^^a3kava
.i3z4bleu^^b2an
.i3z4bojak
.i3z4bojk
.i3z4vali
.i3z4valu
.i3z4vala
.i3z4vale
.i3z4valji
.i3z4vi^^bad
.i3z4viiskr
.i3z4vija
.i3z4vijen
.i3z4vin
.i3z4vir
.i3z4vinj
.i3z4vitop
.i3z4vjed
.i3z4vojac
.i3z4vojc
.i3z4vor
.i3z4gomet
.i3z4gred
.i3z4grn
.i3z4grt
.i3z4drav
.i3z4i^^9e
.i3z4id
.i3z4imi
.i3z4je^^balj
.i3z4loz
.i3z4lo^^ba
.i3z4log
.i3z4lopa^^a2
.i3z4nim
.i3z4noj
.iz4oanem
.iz4oanom
.iz4obat
.iz4obron
.iz4ogam
.iz4ogeo
.iz4oglos
.iz4ogon
.iz4ograf
.iz4odim
.iz4odin
.iz4odoz
.iz4oklin
.iz4okolon
.i3z4olat
.i3z4olac
.i3z4olir
.i3z4olov
.iz4oleks
.iz4oluks
.iz4omer
.iz4ometr
.iz4omorf
.iz4onef
.iz4onom
.iz4opat
.iz4oper
.iz4ople
.iz4opol
.iz4opsef
.iz4orah
.iz4osei
.iz4osint
.iz4osist
.iz4oskel
.iz4oskop
.iz4ostaz
.iz4oste
.iz4otah
.iz4otal
.iz4oter
.iz4oton
.iz4otop
.iz4otro
.iz4ofon
.iz4ofot
.iz4ohal
.iz4ohaz
.iz4ohel
.iz4ohij
.iz4ohim
.iz4ohit
.iz4ohips
.iz4ohor
.iz4ohro
.i3z4rael
.i3z4railj
.i3z4ra^^a3i
.i3z4un
.i3z4up^^a3
.i2s3c
.i2s3k
.i2s3p
.i2s3t
.i3s4kak
.i3s4kat
.i3s4kanj
.i3s4kariot
.i3s4kvas
.i3s4kvr^^a3
.i3s4kin
.i3s4kita
.i3s4konsk
.i3s4ko^^a3
.i3s4kram
.i3s4krit
.i3s4kri^^b2
.i3s4kri^^a3
.i3s4kric
.i3s4krat
.i3s4kren
.i3s4krenj
.i3s4kroj
.i3s4krsn
.i3s4krsa
.i3s4kuplja
.i3s4lam
.i3s4lab
.i3s4le^^9e
.i3s4led
.i3s4lije^^9e
.i3s4lijed
.i3s4lje^^9e
.i3s4ljed
.i3s4lik
.i3s4lin
.i3s4lov
.i3s4lu^^b2
.i3s4lu^^ba
.i3s4me
.i3s4mije
.i3s4mje
.i3s4pav
.i3s4paljiv
.i3s4pira
.i3s4plit
.i3s4pli^^a2
.i3s4pokoj
.i3s4polin
.i3s4pon
.i3s4porav
.i3s4pravi
.i3s4pravk
.i3s4pravn
.i3s4pravlj
.i3s4prava
.i3s4pup^^a3
.i3s4pur
.i3s4red
.i3s4rk
.i3s4tavi
.i3s4tavlj
.i3s4takn
.i3s4tam
.i3s4tar
.i3s4tas
.i3s4ta^^a2
.i3s4tin
.i3s4tir
.i3s4tic
.i3s4tifan
.i3s4tok
.i3s4tori
.i3s4to^^a3n
.i3s4to^^a3nj
.i3s4to^^a3a
.i3s4trav
.i3s4trad
.i3s4tran
.i3s4tri^^a2
.i3s4tri^^ba
.i3s4tric
.i3s4trug
.i3s4tup
.i3s4uk
.i3s4us
.i3s4ut
.i3s4u^^b2
.i2^^ba3^^9e
.i2^^b23^^a2
.i2^^b23^^a3
.iz3be2z3obr
.iz3be2z3um
.iz3va2n3evr
.na2d3l
.na2d3lj
.na2d3v
.na3d4val
.na3d4vesi
.na3d4vest
.na3d4vij
.na3d4vit
.na3d4vla
.na3d4voje
.na3d4vor
.na2d3igr
.na2d3in^^ba
.na2d3ina
.na2d3isk
.na2d3jah
.na2d3ja^^a3
.na2d3jek
.na2d3jez
.na2d3je^^a3
.na2d3jun
.na3d4lan
.na3d4le^^b2
.na3d4le^^ba
.na2d3ora
.na2d3oso
.na2d3ose
.na2d3osje
.na2d3ofi
.na2d3o^^a3
.na2d3ran
.na2d3ra^^a3
.na2d3rast
.na2d3ra^^b2^^a2
.na2d3real
.na2d3rep
.na2d3ruk
.na2d3ru^^a3
.na2d3rug
.na2d3udar
.na2d3um
.na2d3u^^a3
.na2j3a
.na2j3e
.na2j3i
.na2j3o
.na2j3u
.na3j4avi
.na3j4avlj
.na3j4ava
.na3j4ave
.na3j4adi
.na3j4ada
.na3j4ade
.na3j4a^^bai
.na3j4azi
.na3j4ako
.na3j4aka
.na3j4alo
.na3j4ami
.na3j4aml
.na3j4amn
.na3j4ari
.na3j4arm
.na3j4arc
.na3j4ati
.na3j4auk
.na3j4ah
.na3j4a^^b2
.na3j4edi
.na3j4edn
.na3j4edr
.na3j4eda
.na3j4e^^bai
.na3j4e^^bau
.na3j4e^^bae
.na3j4ezn
.na3j4ezd
.na3j4esti
.na3j4etk
.na3j4ec
.na3j4uri
.na3j4uren
.o2b3j
.o2b3lj
.o2b3r
.obe2z3b
.obe2z3d
.obe2z3g
.obe2z3j
.obe2z3l
.obe2z3m
.obe2z3n
.obe2z3o
.obe2z3lj
.obe2z3r
.obe2z3u
.obe2z3v
.obe3z4vij
.obe3z4nan
.obe3z4nanj
.obe3z4na^^a3
.obe3z4ub
.obe2s3c
.obe2s3k
.obe2s3p
.obe2s3t
.obe3s4tan
.obe3s4tij
.obe3s4tran
.obe2^^b23^^a2
.obe2^^b23^^a3
.o2b3igr
.o2b3istin
.o2b3istinj
.o3b4jek
.o3b4jer
.o3b4jesi
.o3b4jet
.o3b4je^^b2
.o2b3laj
.o2b3lam
.o2b3lak^^b2
.o2b3lask
.o2b3lep
.o2b3let
.o2b3le^^a2
.o2b3le^^ba
.o2b3leg
.o2b3lijep
.o2b3lijet
.o2b3lije^^ba
.o2b3lijeg
.o2b3leden
.o2b3liv
.o2b3lizat
.o2b3lizav
.o2b3lizi
.o2b3list
.o2b3loka
.o2b3luk
.o2b3lu^^a3
.o3b4ljan
.o3b4ljut
.o3b4ljuz
.o2b3oru
.o3b4ra^^bae
.o3b4razi
.o3b4razn
.o3b4razo
.o3b4razu
.o3b4raza
.o3b4razd
.o3b4ramb
.o3b4ran
.o3b4ranj
.o3b4rat
.o3b4ra^^a2
.o3b4ra^^b2n
.o3b4ra^^b2^^a3
.o3b4rv
.o3b4r^^9e
.o3b4rem
.o3b4res
.o3b4re^^9e
.o3b4re^^a3
.o3b4re^^ba
.o3b4rec
.o3b4red
.o3b4reti
.o3b4retn
.o3b4rij
.o3b4ris
.o3b4rit
.o3b4riv
.o3b4ri^^a3
.o3b4ric
.o3b4rk
.o3b4rl
.o3b4rn
.o3b4rlj
.o3b4rs
.o3b4rt
.o3b4r^^b2
.o3b4r^^a3
.o3b4rok
.o3b4ron
.o3b4ronj
.o3b4ro^^a2
.o3b4ro^^a3
.o3b4rova
.o3b4rovc
.o3b4ruk
.o3b4run
.o3b4rus
.o3b4runj
.o3b4ru^^b2
.o3b4ru^^a3
.o2b3ubo^^ba
.o2b3uz
.o2b3u^^ba
.o2b3ud
.o2b3umi
.o2b3umj
.o2b3umr
.o2b3ume
.o2d3j
.o2d3l
.o2d3lj
.o2d3r
.o2d3v
.o2d3arg
.o3d4vaj
.o3d4va^^ba
.o3d4vesn
.o3d4vest
.o3d4vesa
.o3d4vikav
.o3d4vikn
.o3d4vis
.o3d4vi^^a2
.o3d4voj
.o2d3igr
.o2d3i2z3v
.o2d3i2z3d
.o2d3isk
.o2d3isti
.o3d4jel
.o3d4jen
.o3d4jev
.o3d4je^^a2
.o3d4laz
.o3d4la^^ba
.o3d4lag
.o3d4laka
.o3d4luk
.o3d4lu^^a3
.o2d3ozd
.o2d3ozg
.o2d3ok
.o2d3onl
.o2d3ono
.o2d3onu
.o2d3ond
.o3d4rani
.o3d4rano
.o3d4ranu
.o3d4rana
.o3d4rane
.o3d4raz
.o3d4ra^^a2
.o3d4ra^^ba
.o3d4rapi
.o3d4raplj
.o3d4rapa
.o3d4ra^^a3i
.o3d4rven
.o3d4rvenj
.o3d4rve^^a3
.o3d4rem
.o3d4ren
.o3d4ret
.o3d4re^^9e
.o3d4red
.o3d4rl
.o3d4rn
.o3d4rp
.o3d4rlj
.o3d4rt
.o3d4r^^ba
.o3d4rin
.o3d4rinj
.o3d4ri^^b2
.o3d4ri^^a3
.o3d4rib
.o3d4ric
.o3d4ron
.o3d4ronj
.o3d4ru^^ba
.o3d4rug
.o2d3uvi
.o2d3uve
.o2d3uzi
.o2d3uzl
.o2d3uzd
.o2d3uze
.o2d3uk
.o2d3ul
.o2d3um
.o2d3u^^a3
.po2d3adm
.po2d3varij
.po2d3vez
.po2d3ve^^a3
.po2d3ve^^ba
.po2d3vik
.po2d3vil
.po2d3vir
.po2d3vinj
.po2d3vlas
.po2d3vla^^b2
.po2d3voz
.po2d3vo^^9e
.po2d3vo^^ba
.po2d3vod
.po2d3vrat
.po2d3vra^^a2
.po2d3vr^^a2
.po2d3vr^^ba
.po2d3vrg
.po2d3vris
.po2d3vrs
.po2d3vu^^a2
.po2d3igr
.po2d3izv
.po2d3j
.po3d4jen
.po3d4je^^a3
.po2d3lakat
.po2d3lakt
.po2d3lep
.po2d3let
.po2d3le^^a2
.po2d3le^^ba
.po2d3leg
.po2d3liz
.po2d3lijep
.po2d3lijet
.po2d3lije^^a2
.po2d3lije^^ba
.po2d3lijeg
.po2d3list
.po2d3lok
.po2d3lom
.po2d3lup
.po2d3lu^^a3
.po2d3lu^^ba
.po2d3ljut
.po2d3okn
.po2d3o^^b2
.po2d3o^^a3
.po2d3of
.po2d3ravn
.po2d3ravnj
.po2d3rad
.po2d3ra2z3d
.po2d3razr
.po2d3razu
.po2d3ram
.po2d3ran
.po2d3ras
.po2d3ranj
.po2d3rep
.po2d3res
.po2d3rez
.po2d3rik
.po2d3rit
.po2d3ron
.po2d3rov
.po2d3ro^^ba
.po2d3ruk
.po2d3rub
.po2d3ru^^a3i
.po2d3ru^^a3n
.po2d3ru^^a3a
.po2d3upla
.po2d3usm
.po2d3usn
.pre2d3j
.pre2d3v
.pre3d4vaj
.pre3d4var
.pre3d4vest
.pre3d4voji
.pre3d4voja
.pre3d4voje
.pre3d4vor
.pre3d4vos
.pre3d4jen
.pre2d3igr
.pre2d3id
.pre2d3izb
.pre2d3ispi
.pre2d3isto
.pre2d3istr
.pre2d3obj
.pre2d3odre
.pre2d3okus
.pre2d3osv
.pre2d3ose
.pre2d3osje
.pre2d3rat
.pre2d3ra^^a3
.pre2d3rad
.pre2d3ru^^a3
.pre2d3ube^^9e
.pre2d3ubije^^9e
.pre2d3ubje^^9e
.pre2d3uver
.pre2d3uvjer
.pre2d3uvjet
.pre2d3ugov
.pre2d3udar
.pre2d3upis
.pre2d3uslo
.proti2v3akc
.proti2v3otr
.proti2v3of
.proti2v3r
.proti2v3us
.proti2v3ud
.ra2^^ba3^^9e
.ra2z3b
.ra2z3d
.ra2z3e
.ra2z3g
.ra2z3i
.ra2z3j
.ra2z3l
.ra2z3m
.ra2z3n
.ra2z3lj
.ra2z3r
.ra2z3v
.ra2z3nj
.ra2z3anal
.ra3z4ban
.ra3z4bar
.ra3z4bau
.ra3z4bad
.ra3z4ba^^b2ur
.ra3z4boj
.ra3z4bor
.ra3z4val
.ra3z4vede
.ra3z4vest
.ra3z4vigo
.ra3z4viju
.ra3z4vija
.ra3z4vije
.ra3z4vit
.ra3z4vi^^a2
.ra3z4voj
.ra3z4von
.ra3z4vrat
.ra3z4vra^^a2
.ra3z4vrt
.ra3z4vr^^a2
.ra3z4ga^^9e
.ra3z4grt
.ra3z4ev
.ra3z4ij
.ra3z4il
.ra3z4in
.ra3z4ir
.ra3z4it
.ra3z4iz
.ra3z4i^^9e
.ra3z4i^^a2
.ra3z4id
.ra3z4laz
.ra3z4lag
.ra3z4lik
.ra3z4li^^a3
.ra3z4loz
.ra3z4lo^^ba
.ra3z4log
.ra3z4met
.ra3z4me^^a2
.ra3z4mrsk
.ra3z4nat
.ra2z3obl
.ra2z3obr
.ra2z3oba
.ra2z3od
.ra2z3orat
.ra2z3orav
.ra2z3ort
.ra2z3oru
.ra2z3ot
.ra3z4red
.ra3z4rok
.ra3z4ro^^a3
.ra2z3uve
.ra2z3udi
.ra2z3uda
.ra2z3udb
.ra2z3uzi
.ra2z3uzd
.ra2z3uze
.ra2z3ular
.ra2z3umr
.ra2s3c
.ra2s3k
.ra2s3p
.ra2s3t
.ra3s4kak
.ra3s4kand
.ra3s4kin
.ra3s4klap
.ra3s4klanj
.ra3s4klad
.ra3s4klon
.ra3s4klopi
.ra3s4kloplj
.ra3s4klopa
.ra3s4ko^^b2
.ra3s4krop
.ra3s4paj
.ra3s4pav
.ra3s4peti
.ra3s4peto
.ra3s4peta
.ra3s4pete
.ra3s4piku
.ra3s4pinj
.ra3s4plin
.ra3s4plinj
.ra3s4pn
.ra3s4polo^^ba
.ra3s4pon
.ra3s4por
.ra3s4prav
.ra3s4prem
.ra3s4r^^9e
.ra3s4rd
.ra3s4re
.ra3s4taj
.ra3s4tan
.ra3s4tat
.ra3s4tav
.ra3s4tenj
.ra3s4til
.ra3s4tir
.ra3s4tis
.ra3s4tit
.ra3s4tinj
.ra3s4toj
.ra3s4trel
.ra3s4tret
.ra3s4troj
.ra3s4trt
.ra3s4tup
.ra3s4tur
.ra3s4tu^^a2
.ra4s5tur^^a3
.ra2^^b23^^a2
.ra2^^b23^^a3
.ra3^^b24^^a2enj
.ra3^^b24^^a3i^^a2
.u2z3b
.u2z3d
.u2z3g
.u2z3i
.u2z3j
.u2z3l
.u2z3m
.u2z3n
.u2z3lj
.u2z3r
.u2z3v
.u2z3nj
.u3z4bor
.u3z4van
.u3z4vat
.u3z4vi^^ba
.u3z4vijo
.u3z4viju
.u3z4vija
.u3z4vije
.u3z4voj
.u3z4dic
.u2z3igr
.u2z3inat
.u2z3iskr
.u3z4lan
.u3z4lat
.u3z4lim
.u3z4lit
.u3z4li^^a2
.u3z4lic
.u3z4lov
.u3z4ludob
.u3z4nak
.u3z4na^^a3
.u3z4neve
.u3z4nevje
.u3z4ni^^a3
.u3z4nic
.u3z4noj
.u2z3obest
.u2z3obijest
.u2z3orat
.u2z3orav
.u2z3oho
.u3z4ret
.u3z4rev
.u3z4rijet
.u3z4rijev
.u3z4rn
.u3z4rnj
.u3z4roko
.u3z4roku
.u3z4roka
.u3z4ro^^a3
.u3z4ruj
.u2z3ugar
.u2s3c
.u2s3k
.u2s3p
.u3s4kak
.u3s4kla^^9e
.u3s4klad
.u3s4ko
.u4s5kom
.u4s5kov
.u4s5ko^^b2
.u4s5koko
.u4s5kolu
.u4s5kole
.u4s5kopa
.u4s5kora
.u4s5kosi
.u4s5kotr
.u3s4kup
.u3s4pav
.u3s4palo
.u3s4peh
.u3s4pel
.u3s4pem
.u3s4pet
.u3s4pev
.u3s4pe^^b2
.u3s4pjeh
.u3s4pjel
.u3s4pjem
.u3s4pjet
.u3s4pjev
.u3s4pje^^b2
.u3s4pent
.u3s4pija
.u3s4pije
.u3s4piju^^b2
.u3s4piku^^b2
.u3s4pon
.u3s4pori
.u3s4pora
.u3s4poren
.u3s4porenj
.u3s4pore^^a3
.u3s4posob
.u3s4premi
.u3s4prema
.u3s4rk
.u3s4rn
.u3s4rp
.u3s4rlj
.u3s4rt
.u3s4r^^9e
.u3s4r^^ba
.u3s4ra
.u3s4rd
.u3s4re
.u3s4rijed
.u2s3talas
.u2s3tara
.u2s3tvr^^9e
.u2s3tvrd
.u2s3ter
.u2s3te^^a2
.u2s3teg
.u2s3tov
.u2s3traj
.u2s3tral
.u2s3trg
.u2s3trep
.u2s3tres
.u2s3treb
.u2s3trk
.u2s3trn
.u2s3trp
.u2s3tr^^a2
.u2s3tr^^a3
.u2s3tum
.u2s3tur
.u2s3tu^^a2
.u2^^b23^^a2
.u2^^b23^^a3
.a2b3alij
.a2b3anac
.a2b3evak
.a2b3erac
.a2b3erir
.a2b3irit
.a2b3ju
.a2b3la
.a2b3leg
.a2b3lep
.a2b3lok
.a2b3lu
.a2b3orig
.a2b3reak
.a2b3rog
.a2b3uzus
.a2d3erac
.a2d3verb
.a2d3j
.a2d3lat
.a2d3ren
.a2d3rog
.a3g2nos
.a3g2noz
.a2nabap
.a2nabaz
.a2nabat
.a2nabio
.a2nabol
.a2nagen
.a2nagno
.a2n3ago
.a2nagra
.a2nadem
.a2nadipl
.a2nadoz
.a2n3a4e2ro
.a2nakal
.a2nakam
.a2nakat
.a2nakef
.a2nakla
.a2nakli
.a2nakoj
.a2n3akuz
.a2n3alg
.a2n3ald
.a2nalep
.a2naliz
.a2nalis
.a2nalit
.a2n3amert
.a2namne
.a2n3andr
.a2naneo
.a2n3ant
.a2napla
.a2naple
.a2napne
.a2napno
.a2napro
.a2napti
.a2n3apto
.a2nart
.a2n3arh
.a2nasar
.a2nasei
.a2naspaz
.a2nasta
.a2nastig
.a2nastom
.a2natim
.a2natom
.a2natoc
.a2natre
.a2natri
.a2natro
.a2nafaz
.a2n3afij
.a2nafila
.a2nafon
.a2n3afrod
.a2nakol
.a2nakron
.a2nakru
.a2n3alfa
.a2nafor
.a2nahor
.a2nahro
.a2n3eger
.a2n3ekl
.a2n3ekum
.a2n3elek
.a2n3ener
.a2n3epi
.a2neor
.a2n3erg
.a2n3erit
.a2n3este
.a2n3idr
.a2n3izog
.a2n3izom
.a2n3izur
.a2n3irid
.a2n3ovar
.a2n3oks
.a2n3opis
.a2n3orh
.a2n3oft
.a2n3org
.di2s3akor
.di2s3junk
.di2s3kval
.di2s3kont
.di2s3kord
.di2s3kre
.di2s3kri
.di2s3kur
.di2s3lo
.di2s3orij
.di2s3parit
.di2s3poz
.di2s3pon
.di2s3prop
.di2s3ton
.di2s3trak
.i2n3abrup
.i2n3adek
.i2n3akur
.i2n3akce
.i2n3amor
.i2n3anic
.i2n3aplik
.i2n3apst
.i2n3art
.i2n3augur
.i2n3aura
.i2n3afek
.i2n3evid
.i2n3eg
.i2n3ed
.i2n3ekv
.i2n3eks
.i2n3elig
.i2n3epc
.i2n3efek
.i2n3obl
.i2nogen
.i2nokor
.i2n3okup
.i2n3oper
.i2n3opor
.i2n3opse
.i2n3ofic
.i2n3umbr
.i2n3unda
.i2n3unk
.i2n3util
.inte2r3i
.inte2r3o
.inte2r3u
.inte2r3a
.inte2r3e
.inte3r4egn
.inte3r4esi
.inte3r4esn
.inte3r4eso
.inte3r4esu
.inte3r4esa
.inte3r4ese
.inte3r4e^^bad^^ba
.inte3r4ije
.inte2r3je
.inte3r4ogat
.juri2s3k
.juri2s3p
.nu2z3bel
.nu2z3bilj
.nu2z3ljub
.nu2z3re
.nu2z3rje
.nu2z3u^^ba
.nu2s3pos
.nu2s3pro
.po2st3egz
.po2st3indu
.po2st3lim
.po2st3onk
.po2st3oper
.su2b3a
.su2b3l
.su3b4a^^b2
.su2b3inv
.su2b3junk
.su2b3oks
.su2b3rep
.su2b3rog
.su2b3ord
.supe2r3i
.supe2r3o
.supe2r3u
.supe2r3a
.supe2r3e
.supe3r4ior
.tran2s3a
.tran2s3c
.tran2s3e
.tran2s3k
.tran2s3l
.tran2s3m
.tran2s3n
.tran2s3o
.tran2s3p
.tran2s3t
.tran2s3u
.tran2s3v
.tran2s3nj
.tran3s4ep
.tran3s4kri
.tran3s4um
.tran3s4ud
.a2n3jon
.i2n3jek
.i2n3jur
.i2n3just
.o2d3^^baal
.o2d3^^baalj
.o2d3^^bai
.o2d3^^bav
.o2d3^^bae
.pre2d3^^bai
.pre2d3^^bae
.na2d3^^badr
.na2d3^^banj
.na2d3^^bae
.na2d3^^baanj
.na2d3^^bair
.na2d3^^baiv
.na2d3^^baup
l2j
n2j
d2^^ba
2d^^ba.
}
\hyphenation{
na-dno
na-tka
na-tka-ti
na-tka-^^b2e
o-dno
o-tka
o-tka-ti
o-tka-^^b2e
po-dno
po-dne
po-tki
po-tku
po-tka
po-tke
u-dno
i-gde
i-gdje
svu-gde
sve-gde
svu-gdje
sve-gdje
po-ne-gde
po-ne-gdje
i-zbi
i-zba
i-zbe
i-zbi-ci
i-zbi-ca
i-zbi-ce
i-zvit
i-zim
izo-ba-ri
izo-ba-ru
izo-ba-ra
izo-ba-re
i-skok
i-sko-ku
i-sko-ka
i-skon
i-sko-ni
i-sko-nu
i-sko-na
i-skri
i-skru
i-skra
i-skre
i-skrav
i-spod
i-spo-da
i-stri
i-stro
i-stru
i-stra
i-stre
na-ji
na-jo
na-ju
na-ja
na-je
na-jam
na-jest
o-braz
o-bret
o-dvi-ka
o-dran
o-dra-ti
pre-dvoj
ra-zmi
ra-zmo
ra-zmu
ra-zma
ra-zme
ra-zni
ra-zno
ra-znu
ra-zna
ra-zne
ra-sklop
ra-spe-lo
ra-spe-lu
ra-spe-la
ra-spe-^^a2u
ra-spe-^^a2a
ra-spe-^^a2e
ra-sti
ra-stu
ra-sta
ra-ste
ra-stom
ra-ster
ra-^^b2^^a2i
ra-^^b2^^a2o
ra-^^b2^^a2u
ra-^^b2^^a2a
ra-^^b2^^a2e
u-zni
u-zno
u-zna
u-znik
u-zrok
u-ski
u-sko
u-sku
u-ska
u-ske
us-kos
u-spio
u-speo
u-spor
u-^^b2^^a2u
u-^^b2^^a2a
u-^^b2^^a2e
in-te-res
tran-su
tran-sa
tran-som
}
\egroup

