## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Ca_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Ca_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Ca_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-ca.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: catalan (ca)
% encoding: ec
%
% This file has been auto-generated from hyph-ca.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"E0="E0
\lccode"E7="E7
\lccode"E8="E8
\lccode"E9="E9
\lccode"ED="ED
\lccode"EF="EF
\lccode"F2="F2
\lccode"F3="F3
\lccode"FA="FA
\lccode"FC="FC
\patterns{
1ba
1be
1bi
1bo
1bu
1ca
1ce
1ci
1co
1cu
1da
1de
1di
1do
3du
1fa
1fe
1fi
1fo
1fu
1ga
1ge
1gi
1go
1gu
1ha
1he
1hi
1ho
1hu
1ja
1je
1ji
1jo
1ju
1la
1le
1li
1lo
1lu
1ma
1me
1mi
1mo
1mu
1na
1ne
3ni
1no
1nu
1pa
3pe
3pi
3po
1pu
1qu
1ra
1re
1ri
1ro
1ru
1sa
1se
1si
1so
1su
1ta
1te
1ti
1to
1tu
1va
1ve
1vi
1vo
1vu
1xa
1xe
1xi
1xo
1xu
1za
1ze
1zi
1zo
1zu
1b^^e9
1b^^ed
1b^^f3
1b^^fa
1b^^e0
1b^^e8
1b^^f2
1c^^e9
1c^^ed
1c^^f3
1c^^fa
1c^^e0
1c^^e8
1c^^f2
1^^e7o
1^^e7a
1^^e7u
1^^e7^^f3
1^^e7^^fa
1^^e7^^e0
1^^e7^^f2
1d^^e9
1d^^ed
1d^^f3
1d^^fa
1d^^e0
1d^^e8
1d^^f2
1f^^e9
1f^^ed
1f^^f3
1f^^fa
1f^^e0
1f^^e8
1f^^f2
1g^^e9
1g^^ed
1g^^f3
1g^^fa
1g^^e0
1g^^e8
1g^^f2
1g^^fc
1h^^e9
1h^^ed
1h^^f3
1h^^fa
1h^^e0
1h^^e8
1h^^f2
1j^^e9
1j^^ed
1j^^f3
1j^^fa
1j^^e0
1j^^e8
1j^^f2
1l^^e9
1l^^ed
1l^^f3
1l^^fa
1l^^e0
1l^^e8
1l^^f2
1m^^e9
1m^^ed
1m^^f3
1m^^fa
1m^^e0
1m^^e8
1m^^f2
1n^^e9
1n^^ed
1n^^f3
1n^^fa
1n^^e0
1n^^e8
1n^^f2
1p^^e9
1p^^ed
1p^^f3
1p^^fa
1p^^e0
1p^^e8
1p^^f2
1q^^fc
1r^^e9
1r^^ed
1r^^f3
1r^^fa
1r^^e0
1r^^e8
1r^^f2
1s^^e9
1s^^ed
1s^^f3
1s^^fa
1s^^e0
1s^^e8
1s^^f2
1t^^e9
1t^^ed
1t^^f3
1t^^fa
1t^^e0
1t^^e8
1t^^f2
1v^^e9
1v^^ed
1v^^f3
1v^^fa
1v^^e0
1v^^e8
1v^^f2
1x^^e9
1x^^ed
1x^^f3
1x^^fa
1x^^e0
1x^^e8
1x^^f2
1z^^e9
1z^^ed
1z^^f3
1z^^fa
1z^^e0
1z^^e8
1z^^f2
3l2la
1l2le
1l2li
3l2lo
1l2lu
1b2la
1b2le
1b2li
1b2lo
1b2lu
1b2ra
1b2re
1b2ri
1b2ro
1b2ru
1c2la
1c2le
1c2li
1c2lo
1c2lu
1c2ra
1c2re
1c2ri
1c2ro
1c2ru
1d2ra
1d2re
1d2ri
1d2ro
1d2ru
1f2la
1f2le
1f2li
1f2lo
1f2lu
1f2ra
1f2re
1f2ri
1f2ro
1f2ru
1g2la
1g2le
1g2li
1g2lo
1g2lu
1g2ra
1g2re
1g2ri
1g2ro
1g2ru
1p2la
1p2le
1p2li
1p2lo
1p2lu
1p2ra
1p2re
1p2ri
1p2ro
1p2ru
1t2ra
1t2re
1t2ri
1t2ro
1t2ru
1n2ya
1n2ye
1n2yi
1n2yo
1n2yu
1l2l^^e9
1l2l^^ed
1l2l^^f3
1l2l^^fa
1l2l^^e0
1l2l^^e8
1l2l^^f2
1b2l^^e9
1b2l^^ed
1b2l^^f3
1b2l^^fa
1b2l^^e0
1b2l^^e8
1b2l^^f2
1b2r^^e9
1b2r^^ed
1b2r^^f3
1b2r^^fa
1b2r^^e0
1b2r^^e8
1b2r^^f2
1c2l^^e9
1c2l^^ed
1c2l^^f3
1c2l^^fa
1c2l^^e0
1c2l^^e8
1c2l^^f2
1c2r^^e9
1c2r^^ed
1c2r^^f3
1c2r^^fa
1c2r^^e0
1c2r^^e8
1c2r^^f2
1d2r^^e9
1d2r^^ed
1d2r^^f3
1d2r^^fa
1d2r^^e0
1d2r^^e8
1d2r^^f2
1f2l^^e9
1f2l^^ed
1f2l^^f3
1f2l^^fa
1f2l^^e0
1f2l^^e8
1f2l^^f2
1f2r^^e9
1f2r^^ed
1f2r^^f3
1f2r^^fa
1f2r^^e0
1f2r^^e8
1f2r^^f2
1g2l^^e9
1g2l^^ed
1g2l^^f3
1g2l^^fa
1g2l^^e0
1g2l^^e8
1g2l^^f2
1g2r^^e9
1g2r^^ed
1g2r^^f3
1g2r^^fa
1g2r^^e0
1g2r^^e8
1g2r^^f2
1p2l^^e9
1p2l^^ed
1p2l^^f3
1p2l^^fa
1p2l^^e0
1p2l^^e8
1p2l^^f2
1p2r^^e9
1p2r^^ed
1p2r^^f3
1p2r^^fa
1p2r^^e0
1p2r^^e8
1p2r^^f2
1t2r^^e9
1t2r^^ed
1t2r^^f3
1t2r^^fa
1t2r^^e0
1t2r^^e8
1t2r^^f2
1n2y^^e9
1n2y^^ed
1n2y^^f3
1n2y^^fa
1n2y^^e0
1n2y^^e8
1n2y^^f2
a1a
a1e
a1o
e1a
e1e
e1o
i1a
i1e
i1o
o1a
o1e
o1o
u1a
u1e
u1o
a1^^e9
a1^^ed
a1^^f3
a1^^fa
a1^^e0
a1^^e8
a1^^f2
a1^^ef
a1^^fc
e1^^e9
e1^^ed
e1^^f3
e1^^fa
e1^^e0
e1^^e8
e1^^f2
e1^^ef
e1^^fc
i1^^e9
i1^^ed
i1^^f3
i1^^fa
i1^^e0
i1^^e8
i1^^f2
i1^^ef
i1^^fc
o1^^e9
o1^^ed
o1^^f3
o1^^fa
o1^^e0
o1^^e8
o1^^f2
o1^^ef
o1^^fc
u1^^e9
u1^^ed
u1^^f3
u1^^fa
u1^^e0
u1^^e8
u1^^f2
u1^^ef
u1^^fc
^^e91a
^^e91e
^^e91o
^^e91^^ef
^^e91^^fc
^^ed1a
^^ed1e
^^ed1o
^^ed1^^ef
^^ed1^^fc
^^f31a
^^f31e
^^f31o
^^f31^^ef
^^f31^^fc
^^fa1a
^^fa1e
^^fa1o
^^fa1^^ef
^^fa1^^fc
^^e01a
^^e01e
^^e01o
^^e01^^ef
^^e01^^fc
^^e81a
^^e81e
^^e81o
^^e81^^ef
^^e81^^fc
^^f21a
^^f21e
^^f21o
^^f21^^ef
^^f21^^fc
^^ef1a
^^ef1e
^^ef1o
^^ef1^^e9
^^ef1^^ed
^^ef1^^f3
^^ef1^^fa
^^ef1^^e0
^^ef1^^e8
^^ef1^^f2
^^ef1i
^^fc1a
^^fc1e
^^fc1o
^^fc1^^e9
^^fc1^^ed
^^fc1^^f3
^^fc1^^fa
^^fc1^^e0
^^fc1^^e8
^^fc1^^f2
a1i2a
a1i2e
a1i2o
a1i2u
a1u2a
a1u2e
a1u2i
a1u2o
a1u2u
e1i2a
e1i2e
e1i2o
e1i2u
e1u2a
e1u2e
e1u2i
e1u2o
e1u2u
i1i2a
i1i2e
i1i2o
i1i2u
i1u2a
i1u2e
i1u2i
i1u2o
i1u2u
o1i2a
o1i2e
o1i2o
o1i2u
o1u2a
o1u2e
o1u2o
o1u2i
o1u2u
u1i2a
u1i2e
u1i2o
u1i2u
u1u2a
u1u2e
u1u2i
u1u2o
u1u2u
a1i2^^e9
a1i2^^ed
a1i2^^f3
a1i2^^fa
a1i2^^e0
a1i2^^e8
a1i2^^f2
a1u2^^e9
a1u2^^ed
a1u2^^f3
a1u2^^fa
a1u2^^e0
a1u2^^e8
a1u2^^f2
e1i2^^e9
e1i2^^ed
e1i2^^f3
e1i2^^fa
e1i2^^e0
e1i2^^e8
e1i2^^f2
e1u2^^e9
e1u2^^ed
e1u2^^f3
e1u2^^fa
e1u2^^e0
e1u2^^e8
e1u2^^f2
i1i2^^e9
i1i2^^ed
i1i2^^f3
i1i2^^fa
i1i2^^e0
i1i2^^e8
i1i2^^f2
i1u2^^e9
i1u2^^ed
i1u2^^f3
i1u2^^fa
i1u2^^e0
i1u2^^e8
i1u2^^f2
o1i2^^e9
o1i2^^ed
o1i2^^f3
o1i2^^fa
o1i2^^e0
o1i2^^e8
o1i2^^f2
o1u2^^e9
o1u2^^ed
o1u2^^f3
o1u2^^fa
o1u2^^e0
o1u2^^e8
o1u2^^f2
u1i2^^e9
u1i2^^ed
u1i2^^f3
u1i2^^fa
u1i2^^e0
u1i2^^e8
u1i2^^f2
u1u2^^e9
u1u2^^ed
u1u2^^f3
u1u2^^fa
u1u2^^e0
u1u2^^e8
u1u2^^f2
^^e91i2a
^^e91i2e
^^e91i2o
^^e91i2u
^^e91u2a
^^e91u2e
^^e91u2o
^^e91u2i
^^e91u2u
^^ed1i2a
^^ed1i2e
^^ed1i2o
^^ed1i2u
^^ed1u2a
^^ed1u2e
^^ed1u2o
^^ed1u2i
^^ed1u2u
^^f31i2a
^^f31i2e
^^f31i2o
^^f31i2u
^^f31u2a
^^f31u2e
^^f31u2o
^^f31u2i
^^f31u2u
^^fa1i2a
^^fa1i2e
^^fa1i2o
^^fa1i2u
^^fa1u2a
^^fa1u2e
^^fa1u2o
^^fa1u2i
^^fa1u2u
^^e01i2a
^^e01i2e
^^e01i2o
^^e01i2u
^^e01u2a
^^e01u2e
^^e01u2o
^^e01u2i
^^e01u2u
^^e81i2a
^^e81i2e
^^e81i2o
^^e81i2u
^^e81u2a
^^e81u2e
^^e81u2o
^^e81u2i
^^e81u2u
^^f21i2a
^^f21i2e
^^f21i2o
^^f21i2u
^^f21u2a
^^f21u2e
^^f21u2o
^^f21u2i
^^f21u2u
^^ef1i2a
^^ef1i2e
^^ef1i2o
^^ef1i2^^e9
^^ef1i2^^ed
^^ef1i2^^f3
^^ef1i2^^fa
^^ef1i2^^e0
^^ef1i2^^e8
^^ef1i2^^f2
^^ef1i2u
^^ef1u2a
^^ef1u2e
^^ef1u2o
^^ef1u2^^e9
^^ef1u2^^ed
^^ef1u2^^f3
^^ef1u2^^fa
^^ef1u2^^e0
^^ef1u2^^e8
^^ef1u2^^f2
^^ef1u2i
^^ef1u2u
^^fc1i2a
^^fc1i2e
^^fc1i2o
^^fc1i2^^e9
^^fc1i2^^ed
^^fc1i2^^f3
^^fc1i2^^fa
^^fc1i2^^e0
^^fc1i2^^e8
^^fc1i2^^f2
^^fc1i2u
^^fc1u2a
^^fc1u2e
^^fc1u2o
^^fc1u2^^e9
^^fc1u2^^ed
^^fc1u2^^f3
^^fc1u2^^fa
^^fc1u2^^e0
^^fc1u2^^e8
^^fc1u2^^f2
^^fc1u2i
^^fc1u2u
.hi2a
.hi2e
.hi2o
.hi2u
.hu2a
.hu2e
.hu2i
.hu2o
.i2^^e8
.i2^^f2
.u2^^e8
.u2^^f2
.hi2^^e9
.hi2^^f3
.hi2^^fa
.hi2^^e0
.hi2^^e8
.hi2^^f2
.hu2^^e9
.hu2^^ed
.hu2^^f3
.hu2^^e0
.hu2^^e8
.hu2^^f2
gu2a
gu2e
gu2i
gu2o
qu2a
qu2e
qu2i
qu2o
gu2^^e9
gu2^^ed
gu2^^f3
gu2^^e0
gu2^^e8
gu2^^f2
qu2^^e9
qu2^^ed
qu2^^f3
qu2^^e0
qu2^^e8
qu2^^f2
g^^fc2e
g^^fc2^^e9
g^^fc2^^ed
g^^fc2^^e8
g^^fc2i
q^^fc2e
q^^fc2^^e9
q^^fc2^^ed
q^^fc2^^e8
q^^fc2i
a1isme.
e1isme.
i1isme.
o1isme.
u1isme.
a1ista.
e1ista.
i1ista.
o1ista.
u1ista.
a1um.
e1um.
i1um.
o1um.
u1um.
.antihi2
.be2n
.be2s
.bi2s
.ca2p
.ce2l
.cla2r
.co2ll
.co2n
.co2r
.de2s
.di2s
.en3a
.hipe2r
.hiperm2n
.in3ac
.in3ad
.in3ap
.in3es
.in3o
.inte2r
.ma2l
.mal1t2hus
.pa2n
.pe2r
.pe3ri
.pos2t
.psa2l
.rebe2s
.re2d
.su2b
.sub3o
.subde2s
.supe2r
.tran2s
g2no
p2si
p2se
p2neu
g2n^^f2
p2s^^ed
.ch2
.th2
ein1s2tein
ru1t2herford
ni2etz1sc2he
3exp
3nef
3nei
3pr
3ser
a3ne
a3ri
bi3se
des3ag
des3ar
des3av
des3enc
e3ism
e3le
e3rio
e3ris
es3aco
es3af
es3ap
es3arr
es3as
es3int
ig3n
in3ex
n3si
o3ro
qui3e
s3emp
s3esp
sub3a
ui3et
o3gn^^f2
}
\hyphenation{
cu-rie
cu-ries
gei-sha
gei-shes
goua-che
goua-ches
hip-py
hip-pies
hob-by
hob-bies
jeep
jeeps
joule
joules
klee-nex
klee-nexs
lar-ghet-ti
lar-ghet-to
lied
lieder
nos-al-tres
ro-yal-ties
ro-yal-ty
vos-al-tres
whis-ky
whis-kies
}
\egroup

