## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Hr_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Hr_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Hr_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-hr.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: croatian (hr)
% encoding: ec
%
% This file has been auto-generated from hyph-hr.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"A2="A2
\lccode"A3="A3
\lccode"9E="9E
\lccode"B2="B2
\lccode"BA="BA
\patterns{
a1a2
a1e2
a1i2
a1o2
a1u2
e1a2
e1e2
e1i2
e1o2
e1u2
i1a2
i1e2
i1i2
i1o2
i1u2
o1a2
o1e2
o1i2
o1o2
o1u2
u1a2
u1e2
u1i2
u1o2
u1u2
a1ba
a1be
a1bi
a1bo
a1bu
a1ca
a1ce
a1ci
a1co
a1cu
a1^^a3a
a1^^a3e
a1^^a3i
a1^^a3o
a1^^a3u
a1^^a2a
a1^^a2e
a1^^a2i
a1^^a2o
a1^^a2u
a1da
a1de
a1di
a1do
a1du
a1d^^baa
a1d^^bae
a1d^^bai
a1d^^bao
a1d^^bau
a1^^9ea
a1^^9ee
a1^^9ei
a1^^9eo
a1^^9eu
a1fa
a1fe
a1fi
a1fo
a1fu
a1ga
a1ge
a1gi
a1go
a1gu
a1ha
a1he
a1hi
a1ho
a1hu
a1ja
a1je
a1ji
a1jo
a1ju
a1ka
a1ke
a1ki
a1ko
a1ku
a1la
a1le
a1li
a1lo
a1lu
a1lja
a1lje
a1lji
a1ljo
a1lju
a1ma
a1me
a1mi
a1mo
a1mu
a1na
a1ne
a1ni
a1no
a1nu
a1nja
a1nje
a1nji
a1njo
a1nju
a1pa
a1pe
a1pi
a1po
a1pu
a1ra
a1re
a1ri
a1ro
a1ru
a1sa
a1se
a1si
a1so
a1su
a1^^b2a
a1^^b2e
a1^^b2i
a1^^b2o
a1^^b2u
a1ta
a1te
a1ti
a1to
a1tu
a1va
a1ve
a1vi
a1vo
a1vu
a1za
a1ze
a1zi
a1zo
a1zu
a1^^baa
a1^^bae
a1^^bai
a1^^bao
a1^^bau
e1ba
e1be
e1bi
e1bo
e1bu
e1ca
e1ce
e1ci
e1co
e1cu
e1^^a3a
e1^^a3e
e1^^a3i
e1^^a3o
e1^^a3u
e1^^a2a
e1^^a2e
e1^^a2i
e1^^a2o
e1^^a2u
e1da
e1de
e1di
e1do
e1du
e1d^^baa
e1d^^bae
e1d^^bai
e1d^^bao
e1d^^bau
e1^^9ea
e1^^9ee
e1^^9ei
e1^^9eo
e1^^9eu
e1fa
e1fe
e1fi
e1fo
e1fu
e1ga
e1ge
e1gi
e1go
e1gu
e1ha
e1he
e1hi
e1ho
e1hu
e1ja
e1je
e1ji
e1jo
e1ju
e1ka
e1ke
e1ki
e1ko
e1ku
e1la
e1le
e1li
e1lo
e1lu
e1lja
e1lje
e1lji
e1ljo
e1lju
e1ma
e1me
e1mi
e1mo
e1mu
e1na
e1ne
e1ni
e1no
e1nu
e1nja
e1nje
e1nji
e1njo
e1nju
e1pa
e1pe
e1pi
e1po
e1pu
e1ra
e1re
e1ri
e1ro
e1ru
e1sa
e1se
e1si
e1so
e1su
e1^^b2a
e1^^b2e
e1^^b2i
e1^^b2o
e1^^b2u
e1ta
e1te
e1ti
e1to
e1tu
e1va
e1ve
e1vi
e1vo
e1vu
e1za
e1ze
e1zi
e1zo
e1zu
e1^^baa
e1^^bae
e1^^bai
e1^^bao
e1^^bau
i1ba
i1be
i1bi
i1bo
i1bu
i1ca
i1ce
i1ci
i1co
i1cu
i1^^a3a
i1^^a3e
i1^^a3i
i1^^a3o
i1^^a3u
i1^^a2a
i1^^a2e
i1^^a2i
i1^^a2o
i1^^a2u
i1da
i1de
i1di
i1do
i1du
i1d^^baa
i1d^^bae
i1d^^bai
i1d^^bao
i1d^^bau
i1^^9ea
i1^^9ee
i1^^9ei
i1^^9eo
i1^^9eu
i1fa
i1fe
i1fi
i1fo
i1fu
i1ga
i1ge
i1gi
i1go
i1gu
i1ha
i1he
i1hi
i1ho
i1hu
i1ja
i1je
i1ji
i1jo
i1ju
i1ka
i1ke
i1ki
i1ko
i1ku
i1la
i1le
i1li
i1lo
i1lu
i1lja
i1lje
i1lji
i1ljo
i1lju
i1ma
i1me
i1mi
i1mo
i1mu
i1na
i1ne
i1ni
i1no
i1nu
i1nja
i1nje
i1nji
i1njo
i1nju
i1pa
i1pe
i1pi
i1po
i1pu
i1ra
i1re
i1ri
i1ro
i1ru
i1sa
i1se
i1si
i1so
i1su
i1^^b2a
i1^^b2e
i1^^b2i
i1^^b2o
i1^^b2u
i1ta
i1te
i1ti
i1to
i1tu
i1va
i1ve
i1vi
i1vo
i1vu
i1za
i1ze
i1zi
i1zo
i1zu
i1^^baa
i1^^bae
i1^^bai
i1^^bao
i1^^bau
o1ba
o1be
o1bi
o1bo
o1bu
o1ca
o1ce
o1ci
o1co
o1cu
o1^^a3a
o1^^a3e
o1^^a3i
o1^^a3o
o1^^a3u
o1^^a2a
o1^^a2e
o1^^a2i
o1^^a2o
o1^^a2u
o1da
o1de
o1di
o1do
o1du
o1d^^baa
o1d^^bae
o1d^^bai
o1d^^bao
o1d^^bau
o1^^9ea
o1^^9ee
o1^^9ei
o1^^9eo
o1^^9eu
o1fa
o1fe
o1fi
o1fo
o1fu
o1ga
o1ge
o1gi
o1go
o1gu
o1ha
o1he
o1hi
o1ho
o1hu
o1ja
o1je
o1ji
o1jo
o1ju
o1ka
o1ke
o1ki
o1ko
o1ku
o1la
o1le
o1li
o1lo
o1lu
o1lja
o1lje
o1lji
o1ljo
o1lju
o1ma
o1me
o1mi
o1mo
o1mu
o1na
o1ne
o1ni
o1no
o1nu
o1nja
o1nje
o1nji
o1njo
o1nju
o1pa
o1pe
o1pi
o1po
o1pu
o1ra
o1re
o1ri
o1ro
o1ru
o1sa
o1se
o1si
o1so
o1su
o1^^b2a
o1^^b2e
o1^^b2i
o1^^b2o
o1^^b2u
o1ta
o1te
o1ti
o1to
o1tu
o1va
o1ve
o1vi
o1vo
o1vu
o1za
o1ze
o1zi
o1zo
o1zu
o1^^baa
o1^^bae
o1^^bai
o1^^bao
o1^^bau
u1ba
u1be
u1bi
u1bo
u1bu
u1ca
u1ce
u1ci
u1co
u1cu
u1^^a3a
u1^^a3e
u1^^a3i
u1^^a3o
u1^^a3u
u1^^a2a
u1^^a2e
u1^^a2i
u1^^a2o
u1^^a2u
u1da
u1de
u1di
u1do
u1du
u1d^^baa
u1d^^bae
u1d^^bai
u1d^^bao
u1d^^bau
u1^^9ea
u1^^9ee
u1^^9ei
u1^^9eo
u1^^9eu
u1fa
u1fe
u1fi
u1fo
u1fu
u1ga
u1ge
u1gi
u1go
u1gu
u1ha
u1he
u1hi
u1ho
u1hu
u1ja
u1je
u1ji
u1jo
u1ju
u1ka
u1ke
u1ki
u1ko
u1ku
u1la
u1le
u1li
u1lo
u1lu
u1lja
u1lje
u1lji
u1ljo
u1lju
u1ma
u1me
u1mi
u1mo
u1mu
u1na
u1ne
u1ni
u1no
u1nu
u1nja
u1nje
u1nji
u1njo
u1nju
u1pa
u1pe
u1pi
u1po
u1pu
u1ra
u1re
u1ri
u1ro
u1ru
u1sa
u1se
u1si
u1so
u1su
u1^^b2a
u1^^b2e
u1^^b2i
u1^^b2o
u1^^b2u
u1ta
u1te
u1ti
u1to
u1tu
u1va
u1ve
u1vi
u1vo
u1vu
u1za
u1ze
u1zi
u1zo
u1zu
u1^^baa
u1^^bae
u1^^bai
u1^^bao
u1^^bau
b1b
b1c
b1^^a3
b1^^a2
b1d
b1d^^ba
b1^^9e
b1f
b1g
b1h
1bj
2bj.
b1k
1bl
2bl.
2b1lj
b1m
b1n
b1nj
b1p
1br
2br.
b1s
b1^^b2
b1t
1bv
2bv.
b1z
b1^^ba
c1b
c1c
c1^^a3
c1^^a2
c1d
c1d^^ba
c1^^9e
c1f
c1g
c1h
1cj
2cj.
c1k
1cl
2cl.
2c1lj
c1m
c1n
c1nj
c1p
1cr
2cr.
c1s
c1^^b2
c1t
1cv
2cv.
c1z
c1^^ba
^^a31b
^^a31c
^^a31^^a3
^^a31^^a2
^^a31d
^^a31d^^ba
^^a31^^9e
^^a31f
^^a31g
^^a31h
1^^a3j
2^^a3j.
^^a31k
1^^a3l
2^^a3l.
2^^a31lj
^^a31m
^^a31n
^^a31nj
^^a31p
1^^a3r
2^^a3r.
^^a31s
^^a31^^b2
^^a31t
1^^a3v
2^^a3v.
^^a31z
^^a31^^ba
^^a21b
^^a21c
^^a21^^a3
^^a21^^a2
^^a21d
^^a21d^^ba
^^a21^^9e
^^a21f
^^a21g
^^a21h
^^a21j
^^a21k
1^^a2l
2^^a2l.
2^^a21lj
^^a21m
^^a21n
^^a21nj
^^a21p
1^^a2r
2^^a2r.
^^a21s
^^a21^^b2
^^a21t
1^^a2v
2^^a2v.
^^a21z
^^a21^^ba
d1b
d1c
d1^^a3
d1^^a2
d1d
d2^^ba
d1^^9e
d1f
2d1g
d1h
1dj
2dj.
d1k
2d1l
2d1lj
d1m
d1n
d1nj
d1p
1dr
2dr.
d1s
d1^^b2
d1t
1dv
2dv.
d1z
d^^ba1b
d^^ba1c
d^^ba1^^a3
d^^ba1^^a2
d^^ba1d
d^^ba1d^^ba
d^^ba1^^9e
d^^ba1f
d^^ba1g
d^^ba1h
1d^^baj
2d^^baj.
d^^ba1k
1d^^bal
2d^^bal.
2d^^ba1lj
d^^ba1m
d^^ba1n
d^^ba1nj
d^^ba1p
1d^^bar
2d^^bar.
d^^ba1s
d^^ba1^^b2
d^^ba1t
1d^^bav
2d^^bav.
d^^ba1z
d^^ba1^^ba
^^9e1b
^^9e1c
^^9e1^^a3
^^9e1^^a2
^^9e1d
^^9e1d^^ba
^^9e1^^9e
^^9e1f
^^9e1g
^^9e1h
1^^9ej
2^^9ej.
^^9e1k
1^^9el
2^^9el.
2^^9e1lj
^^9e1m
^^9e1n
^^9e1nj
^^9e1p
1^^9er
2^^9er.
^^9e1s
^^9e1^^b2
^^9e1t
1^^9ev
2^^9ev.
^^9e1z
^^9e1^^ba
f1b
f1c
f1^^a3
f1^^a2
f1d
f1d^^ba
f1^^9e
f1f
f1g
f1h
1fj
2fj.
f1k
1fl
2fl.
2f1lj
f1m
f1n
f1nj
f1p
1fr
2fr.
f1s
f1^^b2
f1t
1fv
2fv.
f1z
f1^^ba
g1b
g1c
g1^^a3
g1^^a2
g1d
g1d^^ba
g1^^9e
g1f
g1g
g1h
1gj
2gj.
g1k
1gl
2gl.
2g1lj
g1m
g1n
g1nj
g1p
1gr
2gr.
g1s
g1^^b2
g1t
1gv
2gv.
g1z
g1^^ba
h1b
h1c
h1^^a3
h1^^a2
h1d
h1d^^ba
h1^^9e
h1f
h1g
h1h
1hj
2hj.
h1k
1hl
2hl.
2h1lj
h1m
h1n
h1nj
h1p
1hr
2hr.
h1s
h1^^b2
h1t
1hv
2hv.
h1z
h1^^ba
j1b
j1c
j1^^a3
j1^^a2
j1d
j1d^^ba
j1^^9e
j1f
j1g
j1h
j1j
j1k
j1l
2j1lj
j1m
j1n
j1nj
j1p
j1r
j1s
j1^^b2
j1t
j1v
j1z
j1^^ba
k1b
k1c
k1^^a3
k1^^a2
k1d
k1d^^ba
k1^^9e
k1f
k1g
k1h
1kj
2kj.
k1k
k1l
1k2lj
2klj.
k1m
k1n
k1nj
k1p
1kr
2kr.
k1s
k1^^b2
k1t
k1v
k1z
k1^^ba
l1b
l1c
l1^^a3
l1^^a2
l1d
l1d^^ba
l1^^9e
l1f
l1g
l1h
l1k
l1l
2l1lj
l1m
l1n
l1nj
l1p
l1r
l1s
l1^^b2
l1t
l1v
l1z
l1^^ba
lj1b
lj1c
lj1^^a3
lj1^^a2
lj1d
lj1d^^ba
lj1^^9e
lj1f
lj1g
lj1h
lj1k
1ljl
2ljl.
lj1lj
lj1m
lj1n
lj1nj
lj1p
1ljr
2ljr.
lj1s
lj1^^b2
lj1t
1ljv
2ljv.
lj1z
lj1^^ba
m1b
m1c
m1^^a3
m1^^a2
m1d
m1d^^ba
m1^^9e
m1f
m1g
m1h
1mj
2mj.
m1k
1ml
2ml.
2m1lj
m1m
m1n
m1nj
m1p
1mr
2mr.
m1s
m1^^b2
m1t
1mv
2mv.
m1z
m1^^ba
n1b
n1c
n1^^a3
n1^^a2
n1d
n1d^^ba
n1^^9e
n1f
n1g
n1h
2nj.
n1k
1nl
2nl.
2n1lj
n1m
n1n
n1nj
n1p
n1r
n1s
n1^^b2
n1t
1nv
2nv.
n1z
n1^^ba
nj1b
nj1c
nj1^^a3
nj1^^a2
nj1d
nj1d^^ba
nj1^^9e
nj1f
nj1g
nj1h
1njj
2njj.
nj1k
1njl
2njl.
2nj1lj
nj1m
nj1n
nj1nj
nj1p
1njr
2njr.
nj1s
nj1^^b2
nj1t
1njv
2njv.
nj1z
nj1^^ba
p1b
p1c
p1^^a3
p1^^a2
p1d
p1d^^ba
p1^^9e
p1f
p1g
2p1h
1pj
2pj.
p1k
1pl
2pl.
2p1lj
p1m
p1n
p1nj
p1p
1pr
2pr.
p1s
p1^^b2
p1t
1pv
2pv.
p1z
p1^^ba
r1b
r1c
r1^^a3
r1^^a2
r1d
r1d^^ba
r1^^9e
r1f
r1g
r1h
r1j
r1k
r1l
2r1lj
r1m
r1n
r1nj
r1p
r1r
r1s
r1^^b2
r1t
r1v
r1z
r1^^ba
1sb
2sb.
s1c
1s^^a3
2s^^a3.
1s^^a2
2s^^a2.
1sd
2sd.
1sd^^ba
2sd^^ba.
1s^^9e
2s^^9e.
1sf
2sf.
1sg
2sg.
1sh
2sh.
1sj
2sj.
1sk
2sk.
s1l
1slj
2slj.
1sm
2sm.
s1n
2sn.
1snj
2snj.
s1p
1sr
2sr.
1ss
2ss.
1s^^b2
2s^^b2.
s1t
2st.
1sv
2sv.
1sz
2sz.
1s^^ba
2s^^ba.
1^^b2b
2^^b2b.
^^b21c
^^b21^^a3
^^b21^^a2
1^^b2d
2^^b2d.
1^^b2d^^ba
2^^b2d^^ba.
1^^b2^^9e
2^^b2^^9e.
1^^b2f
2^^b2f.
1^^b2g
2^^b2g.
1^^b2h
2^^b2h.
1^^b2j
2^^b2j.
1^^b2k
2^^b2k.
^^b21l
2^^b21lj
1^^b2m
2^^b2m.
^^b21n
2^^b21nj
1^^b2p
2^^b2p.
1^^b2r
2^^b2r.
1^^b2s
2^^b2s.
1^^b2^^b2
2^^b2^^b2.
1^^b2t
2^^b2t.
1^^b2v
2^^b2v.
1^^b2z
2^^b2z.
1^^b2^^ba
2^^b2^^ba.
t1b
t1c
t1^^a3
t1^^a2
t1d
t1d^^ba
t1^^9e
t1f
t1g
t1h
1tj
2tj.
t1k
1tl
2tl.
2t1lj
t1m
t1n
t1nj
t1p
1tr
2tr.
t1s
t1^^b2
t1t
1tv
2tv.
t1z
t1^^ba
v1b
v1c
v1^^a3
v1^^a2
v1d
v1d^^ba
v1^^9e
v1f
v1g
v1h
v1j
1v2je
vj.
v1k
v1l
2v1lj
v1m
v1n
v1nj
v1p
1vr
v1s
v1^^b2
v1t
v1v
v1z
v1^^ba
z1b
1zc
2zc.
1z^^a3
2z^^a3.
1z^^a2
2z^^a2.
z1d
1zd^^ba
2zd^^ba.
1z^^9e
2z^^9e.
1zf
2zf.
z1g
1zh
2zh.
1zj
2zj.
1zk
2zk.
z1l
2z1lj
z1m
z1n
1znj
2znj.
1zp
2zp.
z1r
z1s
1z^^b2
2z^^b2.
1zt
2zt.
1zv
2zv.
1zz
2zz.
1z^^ba
2z^^ba.
^^ba1b
2^^bab.
1^^bac
2^^bac.
1^^ba^^a3
2^^ba^^a3.
1^^ba^^a2
2^^ba^^a2.
1^^bad
2^^bad.
1^^bad^^ba
2^^bad^^ba.
1^^ba^^9e
2^^ba^^9e.
1^^baf
2^^baf.
1^^bag
2^^bag.
1^^bah
2^^bah.
^^ba1j
1^^bak
2^^bak.
1^^bal
2^^bal.
^^ba1lj
1^^bam
2^^bam.
^^ba1n
2^^ban.
2^^ba1nj
1^^bap
2^^bap.
1^^bar
2^^bar.
1^^bas
2^^bas.
1^^ba^^b2
2^^ba^^b2.
1^^bat
2^^bat.
1^^bav
2^^bav.
1^^baz
2^^baz.
1^^ba^^ba
2^^ba^^ba.
2d1vj
2d1vr
z1g2nj
^^a21s2t
d1s2m
j1z2g
r2n1t
r2z1n
m2p1t
2d1vl
r2t1c
r2n1c
r2^^a31k
2s1hr
z1v2l
2z1vr
r2k1n
r2c1n
r2h1nj
s2p1n
j1s2l
r2d1n
.zg2
r2d^^ba1b
2^^b21tv
r2t1s
n2t1s
2s1kr
r2n1k
d1^^b22k
d1s2p
r2t1m
1r2je
k2s1p
t1s2t
l2m1s
r2h1k
j1s2t
s1v2l
r2p1c
t1k2l
s1k2l
n2t1n
2d1ja
2rt.
z1r2j
d1s2t
n2k1c
r2t1k
r2g1n
r2h1t
.na2j1
.be2z1
.iz1
.is1
.ne2o3
r2t1n
r2v1n
r1s2t
n2s1t
l2f1t
}
\egroup

