## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Lt_l7x 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Lt_l7x::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Lt_l7x> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-lt.l7x.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: lithuanian (lt)
% encoding: l7x
%
% This file has been auto-generated from hyph-lt.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"E0="E0
\lccode"E8="E8
\lccode"EB="EB
\lccode"E6="E6
\lccode"E1="E1
\lccode"F0="F0
\lccode"FB="FB
\lccode"F8="F8
\lccode"FE="FE
\patterns{
.ap1
.api1
.ap3r
.arbi1
.arti1
.as3p
.at1
.ata1
.at3r
.a^^f03v
.dina1
.ek3r
.i2^^f03
.i^^f0i2
.kirti1
.nu1
.nusi1
.pie2^^e8
.sam1
.sida1
.sk4
.st4
.su5kr
.te3s2
.uk3
.u2^^f03
.u^^fe1
.^^e1s4
.^^f0ven1
a1a2
a1b
a1c
a2ch
a1d
a4dra
a1e
ae2l
a1f
2a1g
a4gr
ag3ra
a5grio
a5gro
a1h
a5inf
ai4sk
ai4tr
a1j
a1k
ak2l
ak2vi
a2k^^ebt
a1l
a3li
a5lo1
a3ly
a3l^^eb
a3l^^fb
a1m
a1n
an3k2l
an4sk
an4tr
a2o
a1p
ap1a4k
ap3ei
ap3i2m
ap3l
a3pr
ap3s2
a1r
ar1eit
a4rg
ari4s
a1s
asi1
asi5s
a4sk
as3kl
a3sl
as2mi
as2mu
a5s4n
a4stu
a1t
at3aug
ate5ist
at3i2m
ato1
atp4
a4tru
at1^^eb2
at^^fb2^^fe
a4u
au4kl
au4sk
au4sl
au4t3r
a1v
a1w
a1y
a1z
a1^^e0
2a1^^e8
a1^^e6
a1^^eb2
a1^^e1
a1^^f0
a3^^f0n
a^^f04tr
a^^f02v
a1^^f8
a1^^fb2
a1^^fe
a^^fe2l
ba3c
balta1
ba4sl
2b1b
2b1c
4b3d
bep4
be3s2
besi1
be3t2
2b1f
2b1g
2b1h
b1j
2b1k
2b1l
b2la
b2liz
3b2lo
b2lu
2b1m
2b1n
2b1p
2b2r
b3ri
2b1s
2b3t
bu4k
2b1v
2b1w
2b1z
2b1^^e8
2b1^^f0
2b1^^fe
car4
2c1b
2c1c
2c1d
2c1f
2c1g
3chi
2c1k
2c1l
2c1m
2c1n
2c1p
2c1r
2c1s
2c1t
cu4
cuk5
2c1v
2c1w
2c1z
2c1^^e8
2c1^^f0
2c1^^fe
da3b4
2d1b
2d1c
2d1d
de4k
dema1
de4pr
de4sp
2d1f
2d1g
2d1h
di4p
di4s
dis5k
2d1j
2d3k
4d3l
2d1m
2d1n
do3ri
2d1p
2d1r
dro1
dro2b
d2r^^eb
4dr^^f8
2d1s
2d1t
du2a
du4k
du5ka
du4sl
2d1v
d3va
dvi3a
2d1w
d4z
2d1^^e8
2d1^^f0
d4^^fe
d^^feio1
e1a2
e2a3l
eapi1
eat1
e1b2
ebe1
e3bl
eb3r
e1c
e2ch
e3d2
ed3ri
e4dro
ed3r^^eb
e1e
e1f
e1g
eg3ra
e1h
e1ie
ei4k3l
1ein
ei4sk
ei4sl
2eis3t
eist2ra
ei2^^f01
e1j
e1k
e3kr
e1l
e1m
ema5s4
2e1n
en3k2l
enk4la
eno1
ens4
4enta
enu1
e2o
e3or
e3o2^^f0
e3p
ep4li
ep4r
epra1
epri1
e1r
ere3a4
eri4s
ero1
er^^eb2
e1s
esi5s
es4k
eska1
e5sko
e3s2v
e1t
e1u4
eu^^fe3
e1v
e3vi
e1w
e1y
e1z
e1^^e0
e1^^e8
e1^^e6
e1^^eb
e1^^e14
e^^e1p3
e^^e1s3k
e^^e1t3r
e1^^f0
e3^^f0n
e^^f02v
e^^f0^^eb3
e1^^f8
e1^^fb
e1^^fe
2f1b
2f1c
2f1d
2f1f
2f1g
2f1h
fi4s5
2f1k
2f1l
2f1m
2f1n
2f1p
2f1r
fri1
2f1s
2f1t
2f1v
2f1w
2f1z
2f1^^e8
2f1^^f0
2f1^^fe
ga^^f03
2g1b
2g1c
2g1d
ge4o1
2g1f
2g1g
2g1h
2g1k
2g1l
g2le
g2lo
2g1m
2g1n
3g2n^^f8
2g1p2
3g2r
grai2
g3ran
5g3re
g4rei
g3ri
4g4rio
g3ro.
g4r^^e0
5gr^^e1
4gr^^f8
2g1s
4g1t
3gu
2g1v
2g1w
gyva1
2g1z
2g1^^e8
2g1^^f0
2g1^^fe
2h1b
2h1c
2h1d
2h1f
2h1g
2h1h
hi4b
2h1k
2h2l
2h1m
h2me
2h1n
2h1p
2h1r
2h1s
2h1t
2h1v
2h1w
2h1z
2h1^^e8
2h1^^f0
2h1^^fe
i2a
ia5g4
i3ai^^f0
ia3k
i3ant^^e6
i3ant^^eb
iap4
i3ar
i3b2
i1c
ice1
i1d
id2r
id3r^^eb
i2d^^ebm
i2e
ie4d3r
ie3g
i3ei
ie3kl
i3ent
ie4p5r
ie4sk
i1f
2i1g
i3g2l
ig3ru
2i1h
i1i2
i1j
i1k
i3k2n
ik3r
i1l
ilo1
i1m
1imd
4i1n
in4kl
5inv
i2o
io4g3r
iok2
io4pl
i3or
i1p
i2p1j
ip3ru
i1r
ira3s2
i3ri
4i1s
i5sa
i5si
is4k
i3sl
is4li
i5s4n
i4ste
isto1
2i3t2
i2u
i1v
i1w
i1y
i1z
i2^^e0
i1^^e8
i1^^e6
i1^^eb2
i1^^e1
i1^^f0
i3^^f0n
i^^f05t
i4^^f0v
i^^f0^^eb2
1i^^f0^^f0
i2^^f8
i2^^fb
i3^^fe
3ja.
jauna1
2j1b
2j1c
2j1d
2j1f
2j1g
2j1h
2j1j
2j1k
2j1l
2j1m
2j1n
jot3
jo4tv
2j1p
2j1r
2j1s
2j1t
1ju
2j1v
2j1w
2j1z
2j1^^e8
2j1^^f0
1j^^fb
2j1^^fe
3ka.
5ka3d
kak3
ka4kl
ka4pr
3kar
3kas
3kati
5kav
kavar1
ka3z2
2k1b
2k1c
2k1d
3ke
ke4b3
keren1
2k1f
2k1g
2k1h
k4i
5ki.
5kia
3kib
3kil
5kit
2k1k
2k1l
3k2la
k4lan
4kle.
k2lel
4klo.
4klu.
k2ly
4kl^^e0
4kl^^f8
2k1m
2k1n
3ko
2k1p
2k2r
k4rau
kris2
kri5st
k3ro
k4rov
4k3ru
5krun
k4ry
k5r^^e0
2k1s
k4sk
ks3l
k4s3p
4k1t
k3ta
3ku
4kub
ku4k
ku4pr
2k1v
k2va
k3vo
k2v^^eb
2k1w
3kyt
2k1z
5k^^e0
2k1^^e8
2k1^^f0
k^^f02ly
k^^f0^^eb3
2k1^^fe
3la.
lap4s3to
2l1b
lb3r
2l1c
2l1d
3le.
le3c
le4gr
4le^^e8
2l1f
2l1g
lg3s2t
2l1h
3li.
li4a
5li4o
3li^^f8
2l1j
2l1k
lko1
2l1l
2l1m
2l1n
3lo.
log4
4lop
4l1p
lpna1
2l1r
4l1s
l4sk
l4s3p
4l3t
3lu.
2lup
4l1v
2l1w
3ly^^e8
2l1z
3l^^e0
2l1^^e8
3l^^e6s
3l^^ebm
3l^^ebs
2l^^eb^^e8
3l^^e14
4l1^^f0
3l^^f8
2l1^^fe
m2a
2m3aid
3mas
mas3ki
2m1b
mb3r
2m1c
2m1d
me3c
meis1
2m1f
2m1g
2m1h
mi4gl
mi4gr
min4s
mi4tr
2m1k
2m1l
2m1m
2m1n
m2o
2mod
2m1p
m4pl
m3pr
2m1r
4m1s
2m1t
m3ta
3muo
2m1v
2m1w
2m1z
2m1^^e8
2m1^^f0
2m1^^fe
na3s2
na3t2
2n1b
2n1c
ncen1
2n1d
n3dr^^eb
ne1
neg4
nei2m
ne4o3
neor2
ner^^eb3
nesi1
ne3sl
ne3s2t
ne3t2
ne^^e1s3t
2n1f
4n1g
ng3l
ng4r
2n1h
ni4s
2n1j
2n1k
nk3la
nk3r
n3kry
2n1l
2n1m
2n1n
5no
2n1p
2n1r
4n1s
ns4ku
ns3l
n4s3p
nst3r
4n1t
n3ta
nt4pl
n3tru
nt2ruo
nua4
nu3b2
nu3g
nu1i
nuk2
nu4o3
nuos2
nu5s4
2n1v
2n1w
2n1z
4n1^^e8
2n1^^f0
2n1^^fe
o1a
o1b
o1c
o1d
o3dr
o1e
o2et
o1f
o1g
o1h
o1i
o1j
o1k
o3kr
o1l
olen1
o1m
om4pr
o1n
ono1
o1o2
o1p
o1r
o2rie
ori4s
or4tr
o2r^^e6
o1s
o3sl
os3le
os4lo
o3s2v
o3t2
oto1
o1v
o1w
o1y
o1z
o1^^e0
o1^^e8
o1^^e6
o1^^eb
o1^^e1
o1^^f0
o^^f02v
o1^^f8
o1^^fb
o1^^fe
pa3
pad2
pai2l
pai2m
pai2r
3pan
pap4
p2ar
parsi1
pa4r1^^eb2
pas2
pa5sr
p2at2
2p1b
4p1c
4p3d2
p2e
per1
pe2re
pe2r3im
per3s
pe2r^^eb
2p1f
2p1g
2p1h
p2i
p3ie^^f0
2p3k2
3p2l
p3le
p3li
4plio
p4liu
p3lo
p4loj
p4lu
p4ly
2p1m
4p1n
3po
po4g
poli1
2p1p
2p2r
p3rai
prau2si
p3ra^^f0
p3ri
pris2
p5ro.
p3rom
p3ry
4pr^^e0
p3r^^eb
p3r^^fb
4p1s
psi1
p5s4k
p4s3ty
p3s2v
4p3t2
3p4u
pusiau1
pu4sk
pu4sl
pu4tr
2p1v
2p1w
p2y
2p1z
2p1^^e8
p2^^eb
4p3^^f02
4p3^^fe
r2a
3ra.
ra3b
3rac
ra1im
rai4t^^e1
ra3kr
3ral
3ram
ras4l
ra3sm
rau4ka.
3rav
2r1b
rbo1
r3b4r
2r1c
4r1d
2reb
4rein
4reit
3rel
re4p5
5res
res3l
3ret
2r1f
2r1g
2r1h
r2i
3ri.
ri3d
3rij
ri3kr
2ril
ri2ma.
2r3imt
3rio
ri3p
risi1
ri3st
rivin1
3ri^^e0
3ri^^f8
2ri^^fb
4r1k
rk3ly
r3k4r
4r1l
2r1m
4r1n
r2o
3rod2
ro4gr
3roj
3rok
3ron
3rop
2r3org
5ros
2r1p
r3p4r
2r1r
4r1s
rs4ko.
rs4p
4r1t
rti5k4
rti3s2
r3t2r
r3t2v
r2u
2ruk
3rul
4run
3ruos
2rup
3rus
ru4sk
4ruto
4r1v
2r1w
2r1z
3r^^e0
4r^^e0s
4r1^^e8
4r1^^f0
r3^^f02l
r3^^f02m
5r^^f8
2r1^^fe
sala1
2s1am^^fe
san5t
sarka1
2s3b
2s1c
2s3d
s2e
se4kr
senat4
2s1f
2s1g
2s1h
si3auk
si3a2v
si3a2^^f0
si3d
si3k4
si3p4
si3s2
si5^^f02v
3s2k2
4sk.
s5ka.
4ske
5s4ken
5ski
5s4kle
5sk4r
5skub
sk3va
sk3vi
5sky
4sk^^e0
5sk^^e6
2s2l
3sle
s3li
s3lo
4s3lu
4s3l^^fb
2s1m
4sme.
4sm^^e6
4s3n
so4dr
3s2p
s3pe
4spn
4spu
4s1r
s3ri
2s1s
2s1t
s2tal
s2ten
4stin
s2tod
s2toj
3s2tov
st2rai
st2v
4st^^e6
4s3t^^eb
4st^^f8
s2t^^fb
su1
su3bl
su3d2
su3g2
suk2l
su3s2
susi1
su^^fe4
2s1v
s2ve
3s2vy
2s1w
2s1z
s^^e03
4s3^^e8
5s^^eb
2s1^^f0
2s1^^fe
t2a
2tab
ta3kr
ta5s
2tat
taura1
2ta^^e8
2t1b
2t1c
2t1d
2teb
3tem
te4o
te3t2
2t1f
4t3g
2t1h
t2i
ti4gr
ti4k3l
3tin
2tip
4t3j
4t3k
t4kl
4t3l
4t3m
2t1n
t2o
3toje
2tol^^e1
to3s2
2tow
2t3p
t4pj
tp3l^^fb
tp4r
2t1r
4trio
t2ri^^f0
4tro
4tr^^e0
4tr^^f8
4t3s4
tsi1
tskri1
4t1t
tua4
3tur
2t1v
t2vo
4tv^^ebj
2t1w
3tyd
2t1z
2t1^^e8
3t^^e6
t2^^ebm
t3^^ebmu
t3^^ebm^^e6
t3^^ebm^^eb
2t3^^f02
2t3^^fe
u1a2
u3ai
u1b
u2bj
u1c
u1d
u1e2
u1f
u1g
ug4r
ug5rio
u1h
u1i2m
u5in
ui2r
u1j
u1k
u3kl
uk2le
u3kr
u3kv
u5k^^f8
u1l
u1m
u1n
u2o
u3or
uo4sl
u3p
up4l
up3ro
u1r
urk2
ur3kl
u5ro1
ur3s2
u1s
u2s1al
u3sl
us3la
us3le
usva1
us3ve
u3t2
uto1
2utr
u1u
u1v
u1w
u1y
u1z
u1^^e0
u1^^e8
u1^^e6
u1^^eb2
u1^^e1
u1^^f0
u3^^f02l
u3^^f02n
u^^f02v
u1^^f8
u1^^fb2
u1^^fe
u^^fei2m
u3^^fel
u^^fe3v
u^^fe1^^eb2
3va.
vap4
va3t
2v1b
2v1c
2v1d
v2e
2vep
3ves
2v1f
2v1g
2v1h
viesia1
vi4s5k
vi4t3r
2v1j
2v1k
2v1l
2v1m
2v1n
2v1p
2v1r
2v4s
2v1t
2v1v
2v1w
2vydau
2v1z
3v^^e0
2v1^^e8
3v^^eb
4v^^ebp
2v1^^f0
2v1^^fe
2w1b
2w1c
2w1d
2w1f
2w1g
2w1h
2w1k
2w1l
2w1m
2w1n
2w1p
2w1r
2w1s
2w1t
2w1v
2w1w
2w1z
2w1^^e8
2w1^^f0
2w1^^fe
y1a
y1b
y1c
y1d
y1e
y1f
y1g
ygia1
y1h
y1i
y1j
y1k
y4k3l
y1l
y1m
y1n
y1o
y1p
y3r
y1s
y4sk
y1t
y1u
y1v
y1w
y1y
y1z
y1^^e0
y1^^e8
y1^^e6
y1^^eb
y1^^e1
y1^^f0
y1^^f8
y1^^fb
y1^^fe
2z1b
2z1c
2z1d
2z1f
2z1g
2z1h
2z1k
2z1l
2z1m
2z1n
2z1p
2z1r
2z1s
2z1t
2z1v
2z1w
2z1z
2z1^^e8
2z1^^f0
2z1^^fe
^^e01a
^^e01b
^^e01c
^^e01d
^^e01e
^^e01f
^^e01g
^^e01h
^^e01i
^^e01j
^^e01k
^^e01l
^^e01m
^^e01n
^^e01o
^^e01p
^^e01r
^^e01s
^^e01t
^^e01u
^^e01v
^^e01w
^^e01y
^^e01z
^^e01^^e0
^^e01^^e8
^^e01^^e6
^^e01^^eb
^^e01^^e1
^^e01^^f0
^^e01^^f8
^^e01^^fb
^^e01^^fe
2^^e81b
2^^e81c
2^^e81d
^^e8eko1
2^^e81f
2^^e81g
2^^e81h
^^e8in1
2^^e81k
2^^e81l
2^^e81m
2^^e81n
2^^e81p
2^^e81r
2^^e81s
2^^e81t
2^^e81v
2^^e81w
2^^e81z
2^^e81^^e8
2^^e81^^f0
2^^e81^^fe
^^e61a
^^e61b
^^e61c
^^e61d
^^e61e
^^e61f
^^e61g
^^e61h
^^e61i
^^e61j
^^e61k
^^e61l
^^e61m
^^e61n
^^e61o
^^e61p
^^e61r
^^e61s
^^e61t
^^e61u
^^e61v
^^e61w
^^e61y
^^e61z
^^e61^^e0
^^e61^^e8
^^e61^^e6
^^e61^^eb
^^e61^^e1
^^e61^^f0
^^e61^^f8
^^e61^^fb
^^e61^^fe
^^eb1a
^^eb1b
^^eb1c
^^eb1d
^^eb1e
^^eb1f
^^eb1g
^^eb1h
^^eb1i
^^eb1j
^^eb1k
^^eb4k3l
2^^eb3l
^^eb1m
^^eb3me
^^eb1n
^^eb1o
^^eb1p
^^eb1r
2^^eb1s
^^ebs3l
2^^eb3t
^^eb4tr
^^eb1u
^^eb1v
^^eb1w
^^eb1y
^^eb1z
^^eb1^^e0
^^eb1^^e8
^^eb1^^e6
^^eb1^^eb
^^eb1^^e1
^^eb1^^f0
^^eb1^^f8
^^eb1^^fb
^^eb1^^fe
^^e11a
^^e11b
^^e11c
^^e11d2
^^e12e
^^e11f
^^e14g
^^e11h
^^e11i
^^e11j
^^e12k4
^^e12l
^^e12m
^^e11n
^^e11o
^^e14p
^^e12r
^^e11s
^^e1si1
^^e1s3l
^^e1s2m
^^e1s2r
^^e1st2
^^e12t2
^^e11u
^^e12v
^^e11w
^^e11y
^^e11z
^^e11^^e0
^^e11^^e8
^^e11^^e6
^^e11^^eb2
^^e11^^e1
^^e11^^f0
^^e11^^f8
^^e11^^fb
^^e11^^fe
2^^f01b2
2^^f01c
2^^f03d2
^^f01ei
^^f0e2v
2^^f01f
2^^f01g4
2^^f01h
2^^f05ist
^^f0iuk1
2^^f01k2
2^^f01l
^^f02lij
^^f02lu
3^^f0ly
2^^f01m
2^^f01n
^^f02ne
^^f0no1
^^f0o2r
2^^f01p4
2^^f01r
2^^f03s4
^^f0si1
^^f0sikap1
4^^f03t2
^^f0u4^^f0
3^^f01v
^^f02vi
^^f04vyd
2^^f01w
2^^f01z
4^^f03^^e8
^^f0^^eb2j
2^^f01^^f0
2^^f01^^fe
^^f81a
^^f81b
^^f81c
^^f81d
^^f81e
^^f81f
^^f81g
^^f81h
^^f81i
^^f81j
^^f81k
^^f81l
^^f81m
^^f81n
^^f81o
^^f81p
^^f81r
^^f81s
^^f81t
^^f81u
^^f81v
^^f81w
^^f81y
^^f81z
^^f81^^e0
^^f81^^e8
^^f81^^e6
^^f81^^eb
^^f81^^e1
^^f81^^f0
^^f81^^f8
^^f81^^fb
^^f81^^fe
^^fb1a
^^fb1b
^^fb1c
^^fb1d
^^fb1e
^^fb1f
^^fb1g
^^fb1h
^^fb1i
^^fb1j
^^fb1k
^^fb4k3l
^^fb1l
^^fb1m
^^fb1n
^^fb1o
^^fb1p
^^fb1r
^^fb1s
^^fb4s3k
^^fbs3l
^^fbs3t
^^fb1t
^^fb1u
^^fb1v
^^fb1w
^^fb1y
^^fb1z
^^fb1^^e0
^^fb1^^e8
^^fb1^^e6
^^fb1^^eb
^^fb1^^e1
^^fb1^^f0
^^fb1^^f8
^^fb1^^fb
^^fb1^^fe
^^feant4
^^feants5
2^^fe3b2
2^^fe1c
2^^fe3d2
^^feen1
2^^fe3f4
2^^fe3g
2^^fe1h
^^fei3mu
^^feio3
^^fe1j
2^^fe3k2
2^^fe1l
^^fe2lu
4^^fe1m
2^^fe1n
2^^fe3p
2^^fe1r
2^^fe1s
^^fesi1
^^fe4sk
^^fe4s5l
^^fes3t
4^^fe3t2
^^fe2u
^^feu3s2
3^^fe2v
^^fe4vi
^^fe3vo
2^^fe1w
2^^fe1z
2^^fe1^^e8
^^fe^^e1s3
2^^fe1^^f0
2^^fe1^^fe
}
\egroup

