## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Kmr_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Kmr_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Kmr_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-kmr.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: kurmanji (kmr)
% encoding: ec
%
% This file has been auto-generated from hyph-kmr.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"E7="E7
\lccode"EA="EA
\lccode"EE="EE
\lccode"FB="FB
\lccode"B3="B3
\patterns{
.ka6ra
a1
al4a
6am^^eet.
4an
ar5a6n^^ee
3av
4avay
2ay
1b
b4a
2bb
2bl
2br
2bs
2bx
1c
2cb
2c2k
2cl
1^^e7
2^^e7k
1d
da6v^^eaji
2db
db^^fb6na
2dd
dda4
2dg
2dr
2dt
d4yo
4dy^^fb
e1
ea2
e4dy
ee2
e^^ea2
e4fr
el4a
erdes6
er6desta
e4tr
2ez
^^ea1
^^ea2a
^^eala4v
1f
fl4
f4l^^ee
4fl^^fb
f4ro
2fs
2f^^b3
2ft
2fx
1g
2gb
2gh
2gk
g2l
2gn
2gr
2gs
2gt
1h
2hb
2hd
2hk
2hm
2hn
2hr
2hs
2ht
i1
ii2
il4a
i4n^^ear
ire4h
i2s
^^ee1
^^ee2a
2^^eed
^^eee4t
^^ee2j
^^eel3
^^ee4pl
^^eesti6ye
1j
6ja6va.
2jh
2jk
2jm
2jn
2jt
1k
2kb
2k^^e7
2kk
2kl
2km
2kn
2kr
2ks
2kt
2kv
2kw
2kx
2ky
1l
6lam^^eet^^ea
2lb
2lc
2l^^e7
2ld
l4e
2lf
2lg
2lh
2lk
2ll
2lm
2ln
2lp
2lq
2ls
2lt
2lv
2lw
2lx
2ly
2lz
1m
ma4^^ee
2mb
2md
2mf
4m^^eet^^ea
2mm
2mp2
2mr
2ms
2mw
2my
2mz
1n
n4a
2nb
2nc
2n^^e7
2nd
n^^ea4re
2nf
2ng
2nh
2nk
nki4
2nn
2np
2ns
2n^^b3
2nt
2nv
2nx
2ny
2n2z
2o
of2
o2h
o2s
o2w
1p
2ps
2pt
1q
2qp
2q^^b3
1r
r4a
ra^^ee4
2rb
2rc
2r^^e7
2rd
2rf
r4fi4
2rg
2rh
2rj
2rk
2rl
2rm
2rn
2rp
2rq
2rr
2rs
2rt
2rv
2rw
2rx
2ry
2rz
1s
3sa
2sb
3se
2sg
3s^^ee
2sk
2sp
2sr
2ss
2st
sta4v
st4r
3su
3s^^fb
2sy
1^^b3
4^^b3a4v
2^^b3b
2^^b3d
^^b3^^ea4l
2^^b3g
2^^b3h
2^^b3k
2^^b3m
2^^b3n
2^^b3p
2^^b3t2
2^^b3v
2^^b3x
1t
4tav
2tg
tge4
2tk
2tl
2tm
2tn
tn^^ee4
2tp
t4ra
t4r^^fb
2t3s2
2tt
2tx
2ty
u1
ue2
u2i
u2k
urandi6
u2^^b3
1v
2vb
2v^^e7
2vd
2vg
2vh
2vk
2vn
2vr
2vs
2v^^b3
2vy
1w
2wc
2wd
2wh
2wk
2wl
2wn
2wr
2ws
2w^^b3
2wt
1x
x4a
2x^^e7
2xl
2xn
2xt
x4tr
x2w
1y
2yb
2yd
yda4
2yl
2yn
2yr
2ys
2yt
2yv
2yw
1z
2zb
2zd
z3e4z
2zk
2zm
2zr
2zt
2zy
2zz
}
\egroup

