## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Pt_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Pt_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Pt_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-pt.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: portuguese (pt)
% encoding: ec
%
% This file has been auto-generated from hyph-pt.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"E1="E1
\lccode"E2="E2
\lccode"E3="E3
\lccode"E7="E7
\lccode"E9="E9
\lccode"EA="EA
\lccode"ED="ED
\lccode"F3="F3
\lccode"F4="F4
\lccode"F5="F5
\lccode"FA="FA
\patterns{
1b2l
1b2r
1ba
1be
1bi
1bo
1bu
1b^^e1
1b^^e2
1b^^e3
1b^^e9
1b^^ed
1b^^f3
1b^^fa
1b^^ea
1b^^f5
1c2h
1c2l
1c2r
1ca
1ce
1ci
1co
1cu
1c^^e1
1c^^e2
1c^^e3
1c^^e9
1c^^ed
1c^^f3
1c^^fa
1c^^ea
1c^^f5
1^^e7a
1^^e7e
1^^e7i
1^^e7o
1^^e7u
1^^e7^^e1
1^^e7^^e2
1^^e7^^e3
1^^e7^^e9
1^^e7^^ed
1^^e7^^f3
1^^e7^^fa
1^^e7^^ea
1^^e7^^f5
1d2l
1d2r
1da
1de
1di
1do
1du
1d^^e1
1d^^e2
1d^^e3
1d^^e9
1d^^ed
1d^^f3
1d^^fa
1d^^ea
1d^^f5
1f2l
1f2r
1fa
1fe
1fi
1fo
1fu
1f^^e1
1f^^e2
1f^^e3
1f^^e9
1f^^ed
1f^^f3
1f^^fa
1f^^ea
1f^^f5
1g2l
1g2r
1ga
1ge
1gi
1go
1gu
1gu4a
1gu4e
1gu4i
1gu4o
1g^^e1
1g^^e2
1g^^e3
1g^^e9
1g^^ed
1g^^f3
1g^^fa
1g^^ea
1g^^f5
1ja
1je
1ji
1jo
1ju
1j^^e1
1j^^e2
1j^^e3
1j^^e9
1j^^ed
1j^^f3
1j^^fa
1j^^ea
1j^^f5
1k2l
1k2r
1ka
1ke
1ki
1ko
1ku
1k^^e1
1k^^e2
1k^^e3
1k^^e9
1k^^ed
1k^^f3
1k^^fa
1k^^ea
1k^^f5
1l2h
1la
1le
1li
1lo
1lu
1l^^e1
1l^^e2
1l^^e3
1l^^e9
1l^^ed
1l^^f3
1l^^fa
1l^^ea
1l^^f5
1ma
1me
1mi
1mo
1mu
1m^^e1
1m^^e2
1m^^e3
1m^^e9
1m^^ed
1m^^f3
1m^^fa
1m^^ea
1m^^f5
1n2h
1na
1ne
1ni
1no
1nu
1n^^e1
1n^^e2
1n^^e3
1n^^e9
1n^^ed
1n^^f3
1n^^fa
1n^^ea
1n^^f5
1p2l
1p2r
1pa
1pe
1pi
1po
1pu
1p^^e1
1p^^e2
1p^^e3
1p^^e9
1p^^ed
1p^^f3
1p^^fa
1p^^ea
1p^^f5
1qu4a
1qu4e
1qu4i
1qu4o
1ra
1re
1ri
1ro
1ru
1r^^e1
1r^^e2
1r^^e3
1r^^e9
1r^^ed
1r^^f3
1r^^fa
1r^^ea
1r^^f5
1sa
1se
1si
1so
1su
1s^^e1
1s^^e2
1s^^e3
1s^^e9
1s^^ed
1s^^f3
1s^^fa
1s^^ea
1s^^f5
1t2l
1t2r
1ta
1te
1ti
1to
1tu
1t^^e1
1t^^e2
1t^^e3
1t^^e9
1t^^ed
1t^^f3
1t^^fa
1t^^ea
1t^^f5
1v2l
1v2r
1va
1ve
1vi
1vo
1vu
1v^^e1
1v^^e2
1v^^e3
1v^^e9
1v^^ed
1v^^f3
1v^^fa
1v^^ea
1v^^f5
1w2l
1w2r
1xa
1xe
1xi
1xo
1xu
1x^^e1
1x^^e2
1x^^e3
1x^^e9
1x^^ed
1x^^f3
1x^^fa
1x^^ea
1x^^f5
1za
1ze
1zi
1zo
1zu
1z^^e1
1z^^e2
1z^^e3
1z^^e9
1z^^ed
1z^^f3
1z^^fa
1z^^ea
1z^^f5
a3a
a3e
a3o
c3c
e3a
e3e
e3o
i3a
i3e
i3i
i3o
i3^^e2
i3^^ea
i3^^f4
o3a
o3e
o3o
r3r
s3s
u3a
u3e
u3o
u3u
1-
}
\hyphenation{
hard-ware
soft-ware
}
\egroup

