## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Quote_fr 0;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Quote_fr::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Quote_fr> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/quote/hyph-quote-fr.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
\bgroup
\lccode`\’=`\’
\patterns{
2’2
’a4
’â4
’ab3réa
’ae3s4ch
’amino1a2c
’ana3s4tr
’anti1a2
’anti1e2
’anti2enne
’anti1é2
’anti1s2
’apo2s3ta
’as2ta
1d’
’e4
’ê4
’é4
’è4
’en1a2
’en1o2
’eu2r1a2
’ar3gent.
’a2g3nat
’i2g3né
’i2g3ni
’on3guent.
’i4
’î4
’in1a2
’in2a3nit
’in2augur
’in1e2
’in1é2
’in2effab
’in2é3lucta
’in2é3narra
’in2ept
’in2er
’in2exora
’in1i2
’in2i3miti
’in2i3q
’in2i3t
’in1o2
’in2o3cul
’in2ond
’in1s2tab
’inte4r3
’intera2
’intere2
’interé2
’interi2
’intero2
’interu2
’inters2
’in1u2
’in2uit
’in2u3l
’o4
’ô4
’oua1ou
’ovi1s2c
’ar3pent.
’u4
’û4
’y4
}
\egroup

