## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Tr_ec 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Tr_ec::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<Tr_ec> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/ptex/hyph-tr.ec.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% pTeX-friendly hyphenation patterns
%
% language: turkish (tr)
% encoding: ec
%
% This file has been auto-generated from hyph-tr.tex
% with a script [texmf]/scripts/generic/hyph-utf8/generate-ptex-patterns.rb
% See the original file for details about author, licence etc.
%
\bgroup
\lccode"E2="E2
\lccode"E7="E7
\lccode"EE="EE
\lccode"F6="F6
\lccode"FB="FB
\lccode"FC="FC
\lccode"A7="A7
\lccode"19="19
\lccode"B3="B3
\patterns{
2a1
2^^e21
2e1
2^^191
2i1
2^^ee1
2o1
2^^f61
2u1
2^^fc1
2^^fb1
1b1
1c1
1^^e71
1d1
1f1
1g1
1^^a71
1h1
1j1
1k1
1l1
1m1
1n1
1p1
1r1
1s1
1^^b31
1t1
1v1
1y1
1z1
2e2cek.
2bb
2bc
2b^^e7
2bd
2bf
2bg
2b^^a7
2bh
2bj
2bk
2bl
2bm
2bn
2bp
2br
2bs
2b^^b3
2bt
2bv
2by
2bz
2cb
2cc
2c^^e7
2cd
2cf
2cg
2c^^a7
2ch
2cj
2ck
2cl
2cm
2cn
2cp
2cr
2cs
2c^^b3
2ct
2cv
2cy
2cz
2^^e7b
2^^e7c
2^^e7^^e7
2^^e7d
2^^e7f
2^^e7g
2^^e7^^a7
2^^e7h
2^^e7j
2^^e7k
2^^e7l
2^^e7m
2^^e7n
2^^e7p
2^^e7r
2^^e7s
2^^e7^^b3
2^^e7t
2^^e7v
2^^e7y
2^^e7z
2db
2dc
2d^^e7
2dd
2df
2dg
2d^^a7
2dh
2dj
2dk
2dl
2dm
2dn
2dp
2dr
2ds
2d^^b3
2dt
2dv
2dy
2dz
2fb
2fc
2f^^e7
2fd
2ff
2fg
2f^^a7
2fh
2fj
2fk
2fl
2fm
2fn
2fp
2fr
2fs
2f^^b3
2ft
2fv
2fy
2fz
2gb
2gc
2g^^e7
2gd
2gf
2gg
2g^^a7
2gh
2gj
2gk
2gl
2gm
2gn
2gp
2gr
2gs
2g^^b3
2gt
2gv
2gy
2gz
2^^a7b
2^^a7c
2^^a7^^e7
2^^a7d
2^^a7f
2^^a7g
2^^a7^^a7
2^^a7h
2^^a7j
2^^a7k
2^^a7l
2^^a7m
2^^a7n
2^^a7p
2^^a7r
2^^a7s
2^^a7^^b3
2^^a7t
2^^a7v
2^^a7y
2^^a7z
2hb
2hc
2h^^e7
2hd
2hf
2hg
2h^^a7
2hh
2hj
2hk
2hl
2hm
2hn
2hp
2hr
2hs
2h^^b3
2ht
2hv
2hy
2hz
2jb
2jc
2j^^e7
2jd
2jf
2jg
2j^^a7
2jh
2jj
2jk
2jl
2jm
2jn
2jp
2jr
2js
2j^^b3
2jt
2jv
2jy
2jz
2kb
2kc
2k^^e7
2kd
2kf
2kg
2k^^a7
2kh
2kj
2kk
2kl
2km
2kn
2kp
2kr
2ks
2k^^b3
2kt
2kv
2ky
2kz
2lb
2lc
2l^^e7
2ld
2lf
2lg
2l^^a7
2lh
2lj
2lk
2ll
2lm
2ln
2lp
2lr
2ls
2l^^b3
2lt
2lv
2ly
2lz
2mb
2mc
2m^^e7
2md
2mf
2mg
2m^^a7
2mh
2mj
2mk
2ml
2mm
2mn
2mp
2mr
2ms
2m^^b3
2mt
2mv
2my
2mz
2nb
2nc
2n^^e7
2nd
2nf
2ng
2n^^a7
2nh
2nj
2nk
2nl
2nm
2nn
2np
2nr
2ns
2n^^b3
2nt
2nv
2ny
2nz
2pb
2pc
2p^^e7
2pd
2pf
2pg
2p^^a7
2ph
2pj
2pk
2pl
2pm
2pn
2pp
2pr
2ps
2p^^b3
2pt
2pv
2py
2pz
2rb
2rc
2r^^e7
2rd
2rf
2rg
2r^^a7
2rh
2rj
2rk
2rl
2rm
2rn
2rp
2rr
2rs
2r^^b3
2rt
2rv
2ry
2rz
2sb
2sc
2s^^e7
2sd
2sf
2sg
2s^^a7
2sh
2sj
2sk
2sl
2sm
2sn
2sp
2sr
2ss
2s^^b3
2st
2sv
2sy
2sz
2^^b3b
2^^b3c
2^^b3^^e7
2^^b3d
2^^b3f
2^^b3g
2^^b3^^a7
2^^b3h
2^^b3j
2^^b3k
2^^b3l
2^^b3m
2^^b3n
2^^b3p
2^^b3r
2^^b3s
2^^b3^^b3
2^^b3t
2^^b3v
2^^b3y
2^^b3z
2tb
2tc
2t^^e7
2td
2tf
2tg
2t^^a7
2th
2tj
2tk
2tl
2tm
2tn
2tp
2tr
2ts
2t^^b3
2tt
2tv
2ty
2tz
2vb
2vc
2v^^e7
2vd
2vf
2vg
2v^^a7
2vh
2vj
2vk
2vl
2vm
2vn
2vp
2vr
2vs
2v^^b3
2vt
2vv
2vy
2vz
2yb
2yc
2y^^e7
2yd
2yf
2yg
2y^^a7
2yh
2yj
2yk
2yl
2ym
2yn
2yp
2yr
2ys
2y^^b3
2yt
2yv
2yy
2yz
2zb
2zc
2z^^e7
2zd
2zf
2zg
2z^^a7
2zh
2zj
2zk
2zl
2zm
2zn
2zp
2zr
2zs
2z^^b3
2zt
2zv
2zy
2zz
a3a2
a3^^e22
a3e2
a3^^192
a3i2
a3^^ee2
a3o2
a3^^f62
a3u2
a3^^fc2
a3^^fb2
^^e23a2
^^e23^^e22
^^e23e2
^^e23^^192
^^e23i2
^^e23^^ee2
^^e23o2
^^e23^^f62
^^e23u2
^^e23^^fc2
^^e23^^fb2
e3a2
e3^^e22
e3e2
e3^^192
e3i2
e3^^ee2
e3o2
e3^^f62
e3u2
e3^^fc2
e3^^fb2
^^193a2
^^193^^e22
^^193e2
^^193^^192
^^193i2
^^193^^ee2
^^193o2
^^193^^f62
^^193u2
^^193^^fc2
^^193^^fb2
i3a2
i3^^e22
i3e2
i3^^192
i3i2
i3^^ee2
i3o2
i3^^f62
i3u2
i3^^fc2
i3^^fb2
^^ee3a2
^^ee3^^e22
^^ee3e2
^^ee3^^192
^^ee3i2
^^ee3^^ee2
^^ee3o2
^^ee3^^f62
^^ee3u2
^^ee3^^fc2
^^ee3^^fb2
o3a2
o3^^e22
o3e2
o3^^192
o3i2
o3^^ee2
o3o2
o3^^f62
o3u2
o3^^fc2
o3^^fb2
^^f63a2
^^f63^^e22
^^f63e2
^^f63^^192
^^f63i2
^^f63^^ee2
^^f63o2
^^f63^^f62
^^f63u2
^^f63^^fc2
^^f63^^fb2
u3a2
u3^^e22
u3e2
u3^^192
u3i2
u3^^ee2
u3o2
u3^^f62
u3u2
u3^^fc2
u3^^fb2
^^fc3a2
^^fc3^^e22
^^fc3e2
^^fc3^^192
^^fc3i2
^^fc3^^ee2
^^fc3o2
^^fc3^^f62
^^fc3u2
^^fc3^^fc2
^^fc3^^fb2
^^fb3a2
^^fb3^^e22
^^fb3e2
^^fb3^^192
^^fb3i2
^^fb3^^ee2
^^fb3o2
^^fb3^^f62
^^fb3u2
^^fb3^^fc2
^^fb3^^fb2
tu4r4k
m1t4rak
}
\egroup

